(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1305604,      24899]
NotebookOptionsPosition[   1298750,      24726]
NotebookOutlinePosition[   1299105,      24742]
CellTagsIndexPosition[   1299062,      24739]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Cascade Spectra", "Title",
 CellChangeTimes->{{3.6385392196837587`*^9, 3.638539227770125*^9}, {
  3.656975727748878*^9, 
  3.656975727875676*^9}},ExpressionUUID->"00cf4803-6d60-4869-b01e-\
89be371165d2"],

Cell[CellGroupData[{

Cell["\<\
This file describes the contents of the \[OpenCurlyDoubleQuote]Spectra\
\[CloseCurlyDoubleQuote] directory and further below examples of how to load \
them into Mathematica\
\>", "Subsection",
 CellChangeTimes->{{3.639076207803432*^9, 3.6390762404838963`*^9}, 
   3.639076317436984*^9, {3.6390765046563883`*^9, 3.639076514397648*^9}, {
   3.644586340142351*^9, 3.644586353618786*^9}, 3.644586384418253*^9, {
   3.644586441815485*^9, 3.644586484755768*^9}, {3.6445972985754833`*^9, 
   3.6445972995183773`*^9}, {3.6569757500214376`*^9, 3.65697575353046*^9}, {
   3.656975998022893*^9, 
   3.656975999366453*^9}},ExpressionUUID->"fa2c62c4-e5f0-4ba2-9772-\
0f700fb30a77"],

Cell[TextData[{
 "Supplementary material for G. Elor, N. Rodd, T. Slatyer, W. Xue, \
\[OpenCurlyDoubleQuote]Model-Independent Indirect Detection Constraints on \
Hidden Sector Dark Matter\[CloseCurlyDoubleQuote] (2015)",
 StyleBox["\n",
  FontWeight->"Bold"],
 "Contact: Nick Rodd <nrodd@mit.edu>\n\nUpdated in January 2018 to include \
neutrino final states."
}], "Text",
 CellChangeTimes->{{3.644586317093876*^9, 3.644586336763632*^9}, 
   3.657207983037204*^9, {3.726157087112405*^9, 
   3.7261570994886103`*^9}},ExpressionUUID->"8a9520e0-c165-4356-877c-\
86c5b3e176cc"],

Cell[TextData[{
 StyleBox["Overview: ",
  FontWeight->"Bold"],
 "Files within \[OpenCurlyDoubleQuote]Spectra\[CloseCurlyDoubleQuote] contain \
the \[Gamma], ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "+"], "/", 
    SuperscriptBox["e", "-"]}], TraditionalForm]],ExpressionUUID->
  "c57bf32d-aeb6-413c-a4ae-3774bfffa9df"],
 ", ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "962942fc-312e-4103-be53-fa540892af78"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", 
    RowBox[{
     RowBox[{"e", "/", "\[Mu]"}], "/", "\[Tau]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "5ec8ee8a-712c-4043-afea-21e8f067a1fd"],
 " spectrum of dark matter (DM) annihilations leading to 1-6 step cascades \
ending in ",
 StyleBox["e",
  FontSlant->"Italic"],
 ", \[Mu], \[Tau], ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quark, ",
 StyleBox["W",
  FontSlant->"Italic"],
 ", ",
 StyleBox["H",
  FontSlant->"Italic"],
 " or gluon final states. A separate .dat file is provided for each type of \
spectrum and final state. Note all spectra here are calculated using the \
large hierarchy approximation, which can break down in certain situations. \
The contents of these files are designed to be similar to the results of M. \
Cirelli et al., JCAP ",
 StyleBox["1103,",
  FontWeight->"Bold"],
 " 051 (2011), 1012.4515.\n\n",
 StyleBox["Mathematica",
  FontWeight->"Bold"],
 " ",
 StyleBox["version details:",
  FontWeight->"Bold"],
 " this file was written in Mathematica 10. It runs fine (but with some \
harmless error messages) in Mathematica 9. Due to the use of the PlotLegends \
function, it will not operate with Mathematica 8, but if these are deleted \
the files will run.\n\n",
 StyleBox["Content of files:",
  FontWeight->"Bold"],
 " There are 18 files of the form Cascade_{Final State}_{Spectrum Type}.dat. \
Each contains 8 columns and 1612 rows (the first row contains the column \
labels and all others contain numerical values). For all files ",
 StyleBox["except",
  FontSlant->"Italic"],
 " gluon final states and the positron spectrum from gammas, the columns are: \
\n1. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "f"], TraditionalForm]],ExpressionUUID->
  "544b6e16-86ba-40ab-abee-2e00736f5e9b"],
 " value; \n2. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Log", "10"], "[", "x", "]"}], TraditionalForm]],
  ExpressionUUID->"c4973936-8b1a-4d9f-87b3-6bcfc26f5863"],
 ", where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"E", "/", 
     SubscriptBox["m", "DM"]}]}], TraditionalForm]],ExpressionUUID->
  "ebd7efc9-3bcf-4ea9-9eb8-59c831deb4e9"],
 "; \n3-8. the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["dN", 
     RowBox[{
      SubscriptBox["dLog", "10"], "(", "x", ")"}]], "=", 
    RowBox[{
     RowBox[{"ln", "(", "10", ")"}], "x", " ", 
     FractionBox["dN", "dx"]}]}], TraditionalForm]],ExpressionUUID->
  "75714df0-0c04-4c53-a2ee-0e368e4063ee"],
 " of an n=1 (column 3) up to n=6 (column 8) spectrum at that value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "f"], TraditionalForm]],ExpressionUUID->
  "14c996dc-b363-4aa1-ae6f-d43b96839c43"],
 " and ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "e720046f-a7ce-4bb4-9674-a04797cc689b"],
 ". \nFor final state gluons and the positron spectrum from gammas, the \
columns are:\n1. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Phi]"], TraditionalForm]],ExpressionUUID->
  "52329404-11a5-436e-a9f8-f61a11ce8c53"],
 " value; \n2. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Log", "10"], "[", "x", "]"}], TraditionalForm]],
  ExpressionUUID->"37fca38e-4ad6-4fac-9fd5-4dd630eb450b"],
 ", where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    RowBox[{"E", "/", 
     SubscriptBox["m", "DM"]}]}], TraditionalForm]],ExpressionUUID->
  "7f534db7-0dd0-4351-ab0e-fb739c6df21c"],
 "; \n3-8. the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["dN", 
     RowBox[{
      SubscriptBox["dLog", "10"], "(", "x", ")"}]], "=", 
    RowBox[{
     RowBox[{"ln", "(", "10", ")"}], "x", " ", 
     FractionBox["dN", "dx"]}]}], TraditionalForm]],ExpressionUUID->
  "66f2491d-3fe8-4dbb-84ac-02911c94a60b"],
 " of an n=1 (column 3) up to n=6 (column 8) spectrum at that value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Phi]"], TraditionalForm]],ExpressionUUID->
  "d71cac55-7c8e-432d-82bb-f315388c0fc4"],
 " and ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "ae3755ee-ff9c-416c-ba50-f609ec183b27"],
 ". \nThe reason for this difference in the case of gluons and the positron \
spectrum from gammas is that we have to use ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Phi]"], TraditionalForm]],ExpressionUUID->
  "b6ab9190-dc14-426e-a77f-670ad61dbfa3"],
 " values instead of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", 
    RowBox[{"2", 
     RowBox[{
      SubscriptBox["m", "f"], "/", 
      SubscriptBox["m", "\[Phi]"]}]}]}], TraditionalForm]],ExpressionUUID->
  "ea7bce54-8eaf-4685-a546-f528b65b4411"],
 " as for these final states ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "f"], "=", "0"}], TraditionalForm]],ExpressionUUID->
  "7c066a76-7c60-4935-b75b-feedd52f24de"],
 " making ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "f"], TraditionalForm]],ExpressionUUID->
  "e87019d2-b6fe-4e74-8abd-e585db58f4e7"],
 " less useful.\n\n",
 StyleBox["Range of parameters: ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Log", "10"], "[", "x", "]"}], TraditionalForm]],
  ExpressionUUID->"0bdec07d-0581-4da5-a89e-126a48d421b5"],
 " ranges from -8.9 to 0 in steps on 0.05, covering the entire range where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "2"], 
    RowBox[{"dN", "/", "dx"}]}], TraditionalForm]],ExpressionUUID->
  "6375cd6e-43cb-41ca-8b42-7844568a471f"],
 " for each spectra is non-zero. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "f"], TraditionalForm]],ExpressionUUID->
  "9b3bacde-2d7b-4649-9ae4-d57da365ec47"],
 " is evaluated at 0.01, 0.03, 0.05, 0.07, 0.1, 0.2, 0.3, 0.4 and 0.5, whilst \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Phi]"], TraditionalForm]],ExpressionUUID->
  "aedd1b8a-bf52-486d-a28d-27df69ddccac"],
 " is given at 10, 20, 40, 50, 80, 100, 500, 1000 and 2000 GeV.\n",
 StyleBox["NB:",
  FontWeight->"Bold"],
 " if using a value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "f"], TraditionalForm]],ExpressionUUID->
  "1beecf2c-8d73-4230-a99b-102f0ee505b2"],
 " or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Phi]"], TraditionalForm]],ExpressionUUID->
  "74e4e4ea-c79f-4796-807b-dd9d117f500c"],
 " not in this list - especially if it is outside the range of values \
provided - it is recommended that linear interpolation be used, as described \
in the examples below.\n",
 StyleBox["NB:",
  FontWeight->"Bold"],
 " as we are using an interpolating function to determine the spectrum, it \
can occasionally go negative. This is unphysical can cause issues if the Log \
of the spectrum is being used, and so we set the spectrum to 0 wherever the \
interpolating function would send it negative.\n\n",
 StyleBox["Brief description of files",
  FontWeight->"Bold"],
 "\n",
 StyleBox["Photon Spectra:",
  FontSlant->"Italic"],
 "\nCascade_{Gam,E,Mu,Tau,B,W,H,G}_gammas.dat - photon spectrum from final \
state {photons, electrons, muons, taus, b-quarks, Ws, Huggs, gluons}\n\n",
 StyleBox["Positron/Electron Spectra:",
  FontSlant->"Italic"],
 "\nCascade_{Gam,E,Mu,Tau,B,W,H,G}_positrons.dat - positron (or equivalently \
electron) spectrum from final state {photons, electrons, muons, taus, \
b-quarks, Ws, Huggs, gluons}\n\n",
 StyleBox["Antiproton Spectra:",
  FontSlant->"Italic"],
 "\nCascade_{B,W,H,G}_antiprotons.dat - antiproton spectrum from final state \
{b-quarks, Ws, Higgs, gluons}\n",
 StyleBox["NB:",
  FontWeight->"Bold"],
 " electron, muon and tau antiproton spectra are negligible and so not given\n\
\n",
 StyleBox["Nue and Numu spectrum",
  FontSlant->"Italic"],
 "\nCascade_{Nu,Mu,Tau,B,W,H,G}_{nue,numu}.dat - nue/numu spectrum from final \
state {nue/numu, muons, taus, b-quarks, Ws, Huggs, gluons}. \n",
 StyleBox["NB:",
  FontWeight->"Bold"],
 " we don\[CloseCurlyQuote]t include electrons as these \
don\[CloseCurlyQuote]t decay to neutrinos\n\n",
 StyleBox["Nutau spectrum",
  FontSlant->"Italic"],
 "\nCascade_{Nu,Tau,B,W,H}_nutau.dat - nutau spectrum from final state \
{nutau, muons, taus, b-quarks, Ws, Huggs, gluons}.\n",
 StyleBox["NB: ",
  FontWeight->"Bold"],
 "we don\[CloseCurlyQuote]t include muons or gluons as these don\
\[CloseCurlyQuote]t produce tau neutrinos in any appreciable amount.\n\n",
 StyleBox["Direct Spectra:",
  FontSlant->"Italic"],
 "\nAtProduction_{gammas,positrons,antiprotons,neutrinos_e,neutrinos_mu,\
neutrinos_tau}.dat",
 StyleBox[" -",
  FontSlant->"Italic"],
 " Direct {photon, positron, antiproton, nue, numu, nutau} spectrum as \
calculated by M. Cirelli et al. These files were produced by those authors, \
but we provide them here for convenience."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwd0W8w0wEcBvCdk1CSmltjbMNpmvythSn3Q9yR/rjrumqVMRPtxsSZXeZO
q5P+uLOuF71YXF1Co3FK0Y6bliFC6OaSS5c0l/IGa6nf83vxvc+L5557Xny5
2YWZuU40Gk1IHrQqXh1b87URViMzGyrFnDzIXagugnXdzBuQM1FBORX75jOM
rPGbgwGmhu3r6DtL6PAKI0MBLeyeMvgrqEMNB7gBGljENUTbSQcDE/bB6Ufy
cRjqJZmCEUNsrz/YXRLtgOVapa+DdEsigwVrBlOkkLYr+iL8QmNrYeKy9C68
bxKNwK8W+ij0yRq3Qlb+yRmYIwhy+0tq7pBQ6vqjOLC12y0YVr32EMPhgqOU
tVn7H8Cz527VwzXv2G7YyA0xwXjHj9wNUmYOQwbpujAl1K9ZKK+JHvL+kRqV
C5SrVf7hlNKxSFj/+7TYwbIRrrcjZJA7+EwB2W1vmyGPH/MCdrk0vISF0n6z
ejf5J7fSCSjvM6RWkupOLKVD/+TNx6G3R0oe7OwMkkH3I3zKx+qychhzyk8F
6TNGNTykF2rgyHOjs4b0m+zjNsiTx9JhqDwsEJ4pvs6DnBUtH/or3CMgy7Xk
AHTVa4TQR80goKNyMQvKeCtiKteO5VNm7JRBY+Dey7ClOqkcNtadV8PpqNFK
aPV8Wg1Lda1N0EWyuAznVhgbsER1s9ceYiP49qt9sH3VcwiGSS9MwCc/++6k
xNmItNHmWigXD8jS4m1EsXheDuNUVT3sBBtRMKvqhVOpPDMU5BssUFfYPAGD
fXST8ANr3Z1L+m7TiCecNDCZdaTm9k/+8H1u0h4Yf08QDiVhB4VQsLo1HlZ8
n0+GCV2zh+Gwd3Am9MpuE8GWYVoj3WQjep3immBZnV0PLzWlG+B/z+XK/A==

  "],ExpressionUUID->"706c67f0-4ba3-4b4d-8bdc-f2391eccb4a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Photon Cascade Spectra of Final State ",
 StyleBox["W",
  FontSlant->"Italic"],
 " Bosons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"b3893059-38ed-4a2a-b0f0-ba6e84fe8521"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 
  3.6390763661398563`*^9}},ExpressionUUID->"147d167a-40b5-4220-8f12-\
9ddd42c9d42c"],

Cell[TextData[{
 "In this example we load the photon spectrums of 1-6 step cascade DM \
annihilations terminating in ",
 StyleBox["W",
  FontSlant->"Italic"],
 " bosons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"8965a68d-7ad9-4e23-835d-ccc78065fb56"],
 "."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.6569740152601748`*^9, 3.6569740215851297`*^9}, 
   3.6569741348752193`*^9},ExpressionUUID->"f877de5e-042c-4131-a3e8-\
7581907ae2a3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "\[Epsilon]vals", ",", "\[Epsilon]", ",", 
   "xvals", ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3",
    ",", "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_W_gammas.dat\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.12"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, 3.644257377150648*^9, {3.644257434361697*^9, 
   3.644257640256255*^9}, {3.644257707534048*^9, 3.644257735875279*^9}, {
   3.6442600032445927`*^9, 3.644260076895362*^9}, {3.6442601126335287`*^9, 
   3.644260125127042*^9}, {3.644260206635504*^9, 3.644260216755534*^9}, {
   3.644260257841144*^9, 3.644260300439433*^9}, {3.644576371341427*^9, 
   3.644576438767619*^9}, {3.644576479640806*^9, 3.644576479920644*^9}, {
   3.64457654220582*^9, 3.644576615392721*^9}, {3.644576776040201*^9, 
   3.6445767991854687`*^9}, {3.644576834719887*^9, 3.6445768523652887`*^9}, {
   3.6445769381615953`*^9, 3.644576938607382*^9}, {3.6445771076003437`*^9, 
   3.644577147245116*^9}, {3.644577743925811*^9, 3.6445777948429527`*^9}, {
   3.644578047110093*^9, 3.644578096858204*^9}, {3.6445782810736*^9, 
   3.6445783067921886`*^9}, {3.6445783514558153`*^9, 3.644578351709989*^9}, {
   3.644580871103026*^9, 3.6445809542044983`*^9}, {3.644583694406518*^9, 
   3.6445836945720377`*^9}, {3.64458372703931*^9, 3.6445837383126783`*^9}, {
   3.64458377711351*^9, 3.644583837531001*^9}, {3.6445838746916313`*^9, 
   3.6445839220568733`*^9}, {3.644585052730834*^9, 3.6445851006510973`*^9}, {
   3.644585166144863*^9, 3.6445851833791313`*^9}, 3.6445863844322357`*^9, {
   3.644597848860992*^9, 3.644597868618737*^9}, {3.644597923287142*^9, 
   3.644597929359888*^9}, 3.656974933701758*^9, {3.656980023633141*^9, 
   3.656980023762002*^9}},ExpressionUUID->"823b03b0-d97c-4bb1-b821-\
cd89dac6e730"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwlVnc8Vu/7J9lkVLL3eDyyKpmdWxpEJCRkhw8lGsoskmwlZI/sEQnZz9O5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          "]], 
         LineBox[{{-0.10784483773672282`, 0.}, {-0.10521419164175516`, 
          0.}, {-0.10043980860480803`, 0.}, {-0.09566542556786091, 
          0.}, {-0.09089104253091379, 0.}, {-0.08611665949396666, 
          0.}, {-0.0765678934200724, 0.}, {-0.0692379571576789, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004648308292625554, 0.}}], 
         LineBox[{{0.004223388606461563, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11176#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwll3k8Vf/zx0mWbPdasu+7e6MshXDGUtlaLCXKEkXWUElChCQSRSlrqERK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          "]], 
         LineBox[{{-0.06480210870813535, 
          6.735662430810301*^-6}, {-0.057470361272283894`, 
          0.000017656599774423908`}, {-0.05269597823533677, 
          0.000024334985374907678`}, {-0.047921595198389635`, 
          0.000030420006462747363`}, {-0.04314721216144251, 
          0.000035682594160109596`}, {-0.03837282912449538, 
          0.00003987931781853022}, {-0.03359844608754826, 
          0.000042751782957917614`}, {-0.02882406305060113, 
          0.00004402600835158153}, {-0.024049680013654005`, 
          0.000043411781610187476`}, {-0.01927529697670688, 
          0.00004060199259881555}, {-0.014500913939759753`, 
          0.00003527194400206335}, {-0.009726530902812627, 
          0.00002707863833235903}, {-0.0049521478658655005`, 
          0.00001566004065633793}, {-0.004435848449543454, 
          0.000014216103420490193`}}], 
         LineBox[{{-0.14567598052877068`, 0.}, {-0.13863487290038506`, 
          0.}, {-0.13386048986343793`, 0.}, {-0.1290861068264908, 
          0.}, {-0.12431172378954368`, 0.}, {-0.1151292546497022, 
          0.}, {-0.10790748427731348`, 0.}, {-0.09566542556786091, 
          0.}, {-0.09089104253091379, 0.}, {-0.08611665949396666, 
          0.}, {-0.0765678934200724, 0.}, {-0.07367380560722248, 0.}}], 
         LineBox[{{0.004435848449543664, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11176#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwVlnk0VW8Xxw2FTN1rLjJP94oihehuY4QQKiQyRBQNhpCpFEJRKRkLJUQp
871ydiVJRKZkKEOiH0UyRNR733/OWZ/1rLXP/p793Xs/Mu4nbY+ysbCwbGc+
/v8OOrwuJSFXBSXXrVzps/1Es1SZdjp0RwXDPXg/+cd/oskudSlszlbBCtVD
713rP9Hepd5ltN5WwbwNLWpOKp9pii1a46QUFXzcXuY1vGaI1rvTi5YWqYJF
psXS56aGaDvFXk7lH1JBz56qyxUjIzTS18LqQEcVPJq432qCfZT2tfzqBZOD
Kjh3tH37foVR2nVrJ7FxWxV0HR5d6j82SpuM/WlENVdB9yZP48LZUVrWvFRm
mbYKstqw+6eSx2j/OsL3PBNWQd9LFfy2UeO0HUQTt6ugCnb5JnWNPByn+T8U
amEhq2A1r4Z9Y+84bSCmxMqYVwUr3VNG4rZN0Go0B+zesqngzN5xFo7vE7RT
t3RdPk5T0eFvW+uZU//Rhh2Xz8y/oWJPQeGHf3XfaWK7d2umvaYi18qTRMH5
7zQbjevz2q+o2CGS8OCq6g9aPTc1JBypOF2oNPvszg9aBsMxgr2aigmO9b1C
l6dptptq48j3mPH0hf79rZ6hvRw6m6UaScX+4sbph82zNGXpSwmL56g4bi7z
J2lylpbkej3keSgVOfR8s/J5f9HsP5XY7w+ioqFYCz3Q+hftS/8wb8QJKpqU
cI01fvhF4/hgEdHiRMWKe4oJF37N0cxapVyOa1FxbkQrhstpkVbCq2q5fTsV
81gisnMuLNJIljt3/tOg4p3hLz6hDxdpvc32IjfUqJi0Gjjzd3WR5tN0+R1d
gYouOwYeHSj4TUt4+YvGLURFjY9/3+euWaa11L6WKpqh4KM18xNFyys0/7Gz
ypE/KOhQRgliqKzSyGRldbspCr7ux8lNh1dpB47FG66OU/DBl47iD7hKGxLZ
c3TfZwpmHvrGqpr0lzYX0Fy81EpBS0Kew3cDC0iotW43f0jBA2Le+lnDrFDv
GEGTKqLglzOdG5/+YwW3S6qmcwUUPJcUob20iQ0KBq445ORR0EzxX7DEITbY
mmh1bjadgulSJTeID2xgPNGGGfEUtNl+k17cxw4n8josJo9SsPHVlXSHdRxw
amrC/JoHBTM01Z5Yq3NAwI5/e7TcKLjklK51xZEDwppVzGKcKWib5uExWMwB
cbMXjcXtKGhxn6+o34YT8gy1dlnoU7Cr1XQ4rpgLPo5kqj3cSMHbj/10JdN5
YGDzU9V9YhRUu3DN5k0zDwwFN21eFGbq/TYc0bDCA1+556lGZAqu6Lkroxsv
zGlYKfVzUnCu1bljcAsfkGJYpHnmlXGjhGGO3iA/7JY7Sj7epozcV5cemumT
IRj1dum0KmObx8IQ22EyPDgs5MP5VhnLfH65ToaSgev2S8xvVMbEbP1jZhVk
aOaVPTXwTBmVfi0P7lQRAKuFT+/2lijjeNA2MyNZQTjwxiFp62Vl5OctG03f
IQyxXltr/sYqo1lSW36hozBUs3N9abmojKaqY37T4cIgRqvW9YlWxl0pZZGK
DcLQ91R4MvesMmqTXBSM94uAS1bHHkEvZdx94M736AuicPSkJeeCoTLOBJ7P
J/NshAVqAuWmvjJ61vndPqSzEeK/vrbQpDHjLZeumffeCMWHjVLO6CjjCeMo
I7HGjTBjsXPD9BZlLDpG0lOLFYdwZWWVCQll/K9Z/Uul8Ca4Psxu3beghAlT
QSW3dKVBPtvgdOicEkYGJXducZCGSoeoG2KzSli0bcv134HS0Nu2/OHAdyUc
GWvzJT2Whk31P490jiph9K4+5WsKMlCY8flMS7sSuuZjrqyELNTbMW7VFyvh
ruMWXk/U5eHqn8zOY4VKGNyavmhoLw8u+eEkwQIl9Mv/48R3Vh5WZ3cleOcq
YeO4qJDVM3nQu44RpNtK+OYxf8VlSwWgt7/ydL+khI+HboBesCJU7W3X4Dii
hKr9/y6m/laG2Pmyk2WHlTCt9JDMlCwFDmRfK3E6pIRd/E2P4/dSYH7KVvHx
ASU8NpJgfz2fAppJ3Rsc9iphd8dAxC9bKjxt7mMp3qmEz++zf5AjVKDUdOzd
XmEl5Dp1yc6sXQ2KDeO0pQWV8OXJyJx4li1QsIuSN0tSQifXQTOy+ha4u80v
KI1XCb23/9Jbvb4FUqXmxYfZlXA5TUhZQnUrhC2u8QmcVURz7+GrBn+2gtkD
efbMNkV0r/3vmGulBpjkNZ7wa1XE6RkzKY8ODTDMPtYDbxXx/m6SeMq0Buje
KCn60qiIyhT5K4ep20AtStNGrV4R1zrP2rHnbQPhg8bZz0sUMU+FI70yXRNG
ODy1Ji4r4uC9unfuJTtAX/pEWmIc83vtss/FOnZAjk7gotolRTRpG7Tg/r0D
HE9crA6KVsQoSa2qXGMtaH9/T4v9rCLe3KdSUjKkBfVZY1qSnopoKH4tLl5e
B9I1vLXtaYpY/S9cz3ZQFxYsTt5e1FXEwpGkRAUePbA/evZ3ho4iijT3Juvr
6AHpdlzNsCZTP8MhwPqWHsSuPtA+qaKIX4R3pA/Y7YLApgntBDFF7CBLrmEZ
pIGNi68Ozirgt7ZI7UYhA+hv3taYOKOAo+DO/UTNALy0Vm0P/lDARDHe7c/N
DOAcKeXEj28KGF4na2cbYQAFLyrvSAwrIMdlm2d6EwawqsjKEdqmgEuyESHr
XxlC8XRah3qJAvJWjh3VyTaG7c5urqtFCqj8+dMmxTpjwCbqVNMDBZT24y6l
9RtDd+6ztUfyFXAuTP3r5AYTYLEf1b6aoYA3LrGL7Uo3gYM1anf+i1fACk5P
BZ+7u2HN+VfH848qIGGr6nqrwwxaP6oLhnko4Gwg43PGghnc0sih27gpoIWN
n2/7xj2g/CV43V9nBdxqQHrZ5rEH9poqP3CwV0Dxt2UhSr/3wC2+xBE+IwV8
Kd4UG0q1AEqGjWOItAJ2swV6sVbvhdnZOhZrSWb+7+Nz0of3Qp0FpVBBQgHH
lho1jvNagdUq62KHqAKa9NArGe5WcOZIearqegVM85qd3ihgDXWKIu0jq/Jo
zhcwzU2zAavy/t17++Wxav3gs9/1+yCE+ujLXK88NtQXSer17YO83OgLWT3y
GCw/1Vswvw8WkhXqJ9/L48XYmJ2/NttCzomT2xOa5HFjwIlCv2xbmFZgl39d
KY8xD6b42GLtIOU2ldUgRR6v5agbpQbvB/r61ZyJK/LotmNqYEPafvgS26aX
kiiP7dTKe63V+0E7KDDkc6w8Pv90Mw2X9sPQvvrpiAh5fOUtVtcVdQDUeWw/
0X3lMeX6x+SzqQehIyKUoWkij1OfvQocRh2BYsYXu8ZIHjUDVrb5cDpBtECu
TZe+PGZI7HO6reIEag+axgL05NEi/pvMhUAnSGwXJZVvk0cDVmHLRK5DYCxX
5akuK488CX9Ey3Scoapplk/tnxxK7jr84OZzF+C7Edu7uiKHRWfPpxGTLuB5
eGN+67IcGp4N/iUp4goCswbafgtyaPLNQiHquCucFL/mXvJdDlNZzEe9eI+A
sv+WauoA89zyyqOf9UcgU/DEEaVaORyQ9Eix0nEH+5WjMk1Vcjgjujfsn507
8I65jhyrkMM7O/pvdfm7Q3iVnWfxYzmszHmpNXXPHZwddY+pFsjhoYjMKz0C
HiBxh/vUthtyuP9eVE79vAdkUYuiwE8OWZNIXh0fjoK9YL7+kK8cjpJ1YO/i
UeBdyWI9f0wO/bSUBGZFvCC8NSXmhQczv+carvQDXuB8KiTOxEkON2VcUDHv
9YJNVabJFqZyOL3zfMjciDfkGHzNOSgjhzonFrW/bPCFVJGYMHYpOQzvykvU
pPlC4qTUgccSctgqFCRU7u4LITcd+TjF5JDNeasPb4kv7PvWcq6KXw59H5HF
JvSPw5pr5Q7CK7J4ZP2bS8kBJ+D4ULRAZ48sVvmfM8JVf3Cv3PQjsksWLWbG
2NiUT4JDAv0NtUMWe+7uEA2xPQnGmnPRF1plseljWhRb4UmQjPeeVm+QxeTC
MI8W6ino2GLVkvJEFlW2n9a9OHgKtKPEY62SZJn32YYxt4NnwPlB6FXZBFn8
rrGkucf/DES1fbi1EMeMdykl0/zSGWiUSn2QEyOL2zZWKGeVnwF75H3zI0wW
Q26f2R9BDoBTrH95kn1kUaxWVVSnIwAKY4aute2WxatjYtl7vIOg5SEtI99Y
FrPDmvdcOR8E051ZeWcNZfFefKnpj8wg2CHvWC5Fk0X2mblsrvdB0NDwvuvk
dlnUG/0hkqsXDENrX4qS5GWxrX932ZjYWRCNv59twyqLm/8kl8pPhEDWO5+s
+b8y6JbOz1HBFQrSwmqZGSsyKB9IMHwooaCcV3X7y6IM2n3eG292PBR21r2+
EfJDBvVvmjJCZkLh8My3y3f7ZdDD/obHd9ZzkO+gFjxTKYNWhyTNpI0iQPnO
bODNchl88eacZMixCCgZqwrY+UQGDz4t/7h0JQIqzsDpiyUy+HqTmEz4xwho
TLI5IZYvg28b2G7EnImEb3jGXT9Fhnm/XdnZVRIFWyjVVim+MrjNJfMgu8x5
GHqhF3b4mAy699UELWueh+vOL+5TvWSw7OsPQ44952EuuXWlwU0G9aoe2Tuf
Pg/0hdHiJQcZPBFUO7fm5XnY3UDi9DCVwXglkw8HfS+Ai6svsV1eBl2l02y/
vo4B0tL0f2yyMthk/fJl2KcYeH49SKRdSgZnT33aoDgfA/KN0X6+4jKowX3t
1XPZi/Df5jTxOwIyGKW/s4c/6iIEL788y8Uqg5yq97TSdC/BlZubtvYPSuNI
AtuLhFexcHfvOtvQfmlUs9SpEh+Ohadr5wNEP0qj7NObLM0rsdAT1FJt1yWN
R0T6qiI140D6wDloaZbGs+2ha3jvx8FTkY9Wz6qlUcTxxQBXYjz0pqX63bkm
jelROspv/BJAPoPnoYeJNJapXtNfTroKQbSMcV4jaeS7f2bC5vFVaBxRlq/S
l8bphcSUpvdXwVtldzaXnjQ+HpQvFBdNhuK66ORSDWn84eaTvT8/GbZ+ng9Y
lJLGD8pSQaJuKRBshqEi81IYEas1IpF4De45+2QfdZXCt+Vbf70np8Jdi3Wn
uA5JoVsuw5RQSIXMnUWGDw9IoWxS8LpnOqlwXezb+MxeKUxyEP/d5ZYK57uO
aYTrSWHQZU4776ep4GJ57PX1DVI4Llb837UDN0FMz/sn0SmJxqshdJeHtyBR
/KjJRjNJFBcMo3dcSIcx7lPS5hs24Q/v53HhxnehOUXeOeWvOKrv3JfJKXgP
BrZbf/P4thGv95Do04aF4MZzuehp3QYU5P9hvKhdCqfPnmgWvSeG/kJHTnvy
PIE5QVfJ3wGiaDBWlexdUQ73216/PLpHBE/JxPbIbamCH2JDnTwmIiiuUijJ
ol0FO9x/jz7RF8FrW5ReD+hXQdOc8pq/WiJo6qy3Pc22CqY2JBjfUhTBgFMH
E/iDq0DT0/JVI7sIsgUEObyjV8GL3+2NSvXCyBjViBY1qAYew289rbXCeKxu
IS5kTzXYJ7KOB1QK41XtAJGP+6rh6yYNTiwRRtb7rv/S3KuB2+iGqUOmMPLU
mhwXj6mGfVf2N8WHCKPYoKs634tqGJLpe/NNQxjdM7gdemg1MPmgvlFdTRif
fxFMpprWwIJq/stQijCWxTeUCVvXAM/OE8/WSQtj8YXKbx9damCH7d8yCp8w
Omy+n6kUWQNJF2Rv+4wL4elVoyNb62pAa9TX61umEP5+wsqw3lYLhj7WHupp
Qsg5oSi7Z2ctWE5vOxJ6XQilHvXvpxnUgvufFcd1l4Xwhhkrscm6FpIEk/dS
goWwztD2R61vLYwYlWv62AjhoK1KT1JuLVy994ft2xoh9Ku5dz5yDR1+tbs7
nmcRwoJLvxXWcdPBYfXN4w0rgkhRz7h4bT0dZA/cdjb/JYg1TzIHMzfSoZJz
e9XDYUEU7d1pl7aVDgO+/j7+9YKY8OTNUxYnOhikdRMcdEGcwW2u9S50KHip
J3KnUhAfHwyvCfKgwykJnpdtJYJozvpyX+cJOrC/eyChnimIse/GlvZH0YGq
Ptz266wgBrn+fFmfT4fkw2aKSQGCOOn+O0i/kA5zlx+Hy58URHbNtblECR3q
RyIo+70E0eabbHllJR32pW6MqbIXxKHjp5eFX9OhCs9/tLIRxD93OD/1N9Nh
4/eJLeMWgji9tdsm/R0dvphUD4gaCeKdph0yq910CFm02xGqLoiSzXS+s1/o
MCjHSCKrCmLnVnFZrgk6GNrIjhYpM/NVGS1PnaQDb9FMcp+UIJ4oiHmZO0uH
u05XvunyC+L2N58LbrAwYG3cHHStE8R41q7vXGsY4Ft+6NaJtYKYVyGceI6T
AZq8VKPsFQF8uNjd6MDPgNfPGrP+/ieABjHfS6bFGVD4IkC59KsADi/KxuhK
MSDhtXTFoREBdG6qFo2RZcCJllbg/iSAh/LYxUCBAVbvw97WfBRAmtXxP11K
DOj6orZ8pkkAE3u9eAfUGTDEk3Zw/L4A1lEfBLQbM+AFyXj0Zq4AMi58zJAw
ZUC+8E9/42wBPEWUFxzdwwAvKYvY3FQBnIh6uGF6LwO+a/yrOBQjgC/b8vcM
H2DAO60Sfe4oAdwsJPJMxJEBZXqOLTVhAnhjYvKf2SEGXDfgcPAOFkAb85hX
Zw8zIHB3+ajwGQE05IkqzXNlwAGLIycb/ATwqe9jwzduDNCy4ftzxkcAN/J6
eaZ4MEBsPz1W5qgAPod61T+eDFh29BZoPyKA7LOrD529GDDgIpQT6SyAA987
wyu9GfDM4zlF1UEAj/8+r8Phw4BoP3GDBGsBtIo2f3HtOAM4z7edNKYJ4KO1
f7pcTzFg4lL4n1kdAfwW1D0We5oBzQmUuNztAjhz5UVL0RkGXE2Nyfm7WQCv
p9kFfAlkgFChVmuNuADGFn/k1gxlwELJFwdvUQH0ft70Uz+MAR+eXPsiLCiA
/W7zkhbnGJDBmPxzhpuphzo4cyCCAeF4O06GQwBrVMN0HSIZcPiViWA7qwBG
3WUTORDFAFrzbE7kKhltronL2kQzQLrtDlV1iYybO0onTc4zgK3Lsqp/jowv
eDLp/BcYMNq7ZJAwQ0b28A/xwOSGwYJW7SkyTgyohnoxuWDEznF8nIzOLju3
X2Ry/DjL2M1RMgbOc7unM9l3qvSU8WcyDp/LuFPAZMufTiuzfWSMmzaJL2Gy
6gJnfG4PGX3v6pY9ZHK71nmW2fdkJD+PbMxncmDocohhKxkNUoJ33mSyKCPg
5/UmMk7y1jyMZjJ9Zcpn9CUZ9QLulP4/Hxea18g2gox+ZQaNpkxmjf7sdJFO
xq7afX7yTL733KGzq5KMX52WuFeZes3YOywUnpDxHPf9hfdMnjK2aAgqIaO1
/YugfCYnxzboNT4go8SRU/TTTO5ZV63qnUPG+ivqc2uYHGaxtaA6nYzhDR5D
b5j/c9OVIkmum2R0+e4ckchkT1LW+qJEMlaZd2exM5nLVjh+KZaMKb1y+rXM
ejy8cZXF/AIZm9TMOnyYbNXNGZoRQca8I6OWJcz6zYqc//lfCFP/qqFbCLO+
Nx2WfXQDmfpZ9Pu0wxmgnREwkniSjE87ijN/MP0Rtcmrc7MXGfdPc3nsCmGA
rOtniwg3Zjzg4e4NZkDjXYeGVmcy8li36BwPYgCvvEWlvx0ZgQc4I5l+zKBu
TSvTJ2NyjPQhrxNMv5woWs+qR8bm0ZqEHl8GDJfKxu/TIuMTTakII6b/ldWF
Q2dVyfi7VTZSiNkvb89c/WlIIWPZMRcihNlP/hWcvjfkySjwKlOhz50BlVrL
TpriZOa8yn5yg9mfDqEBnRdFyDhOMtaeZPbvCn3KoptMxk+OMnk0ZwbcWTna
oMDHrJ+EtM0VJwYY0j7rBXORcY1+9fskBwZ8jXKobGQn4/vs+ILv+xlw+fl7
VdF/JCyjCuUb2jH9ZNwgWTNPwkZrtu4W5nwJjN2VxvWThG3PFXrZLZh+aqpa
7zhFwhc6jCwNM6Z/LIpYlkdIKFHBnhNmyPTDvqsjuu0kpJk8MWnawexvV4cC
opiEGtbqlAZJBqwxtQ85UsBkQu/8FHOesm2xMWfNI+HuTG1VgQ0MYBG1lMjL
JmHK3uRmTREG/P1r+sMwnYT2DQUDdoJMvV+NcDSVhOU8p976kxiw9A6uX0wh
Yf4r86ftvAyYy9Ha0RhHwjSf/CbKWqYfYrdxeceQ8PRMlrEZKwOm/bf0cUaR
MMR0vZ/LKh3+oylF7gkmocgpOyJwng5Dn0QaWzxJSGVLTXAeo8OnRoHbfkdI
eOn6fLnFMB36H/H78juTcHNrcLrWIB16Ijn4bexI+KXPbC8nc1+1SC7s7zQg
YdOmw+zJDXRo5phVCtxFwjPFJ3j8kA6vf3xfEtIhYVRzWOqeOjq8qB/LPrCV
hEI2DXdWy+mABcMnF1VIuHDYKK/rMXOfXh00uK1EQhXrJLmih3SoC/4oqCNH
wqms0rywB3Sodeke+yhJwrghrgtmzP1ctft9ddhGEv5bOVBnlUOHCrXWy+Ii
JDw+I/SWmk6Hx38bVA/zkTA53Y70+iodLHb5TOLiekxy0+srCKWD/DMlnndP
1mO/SKJIlhUdPtTdM59QWI+arRryV2Zr4QDH9iY/ifXYcMVk28nJWuiyfmXy
S2A9zvUm55l/qYWOkTH9v//4kfMOw/dndy20cClpCfXx41nB8v+Ea2vhhX2R
nP5Vfhw4TP21PaoWHk2VrqQt8KEEG+cMbbUGVHfQwjZ950O1+XM+lXM1UBL1
bjFvlA/paZsWVaZqoEhgera0nQ/zqG2q4v01cE9767eXxXxoc7v26LraGsi4
+LR72oUPPT882bxwugZiJaofmb7mxUdtj85p91RD7VPLz371vFiaZPNJpbUa
psxG1qdW8uKWwI4MmYZqsA3iOz2Uz4ua52anBJ5Wg+Q7j22h0bwYGd7y9HxS
NVRHkWqKdXhRDncW+ulWw8SIz3O+Eh6sEf3Kuz6jCsyLJLo6U7ix5euF2Aqt
SvAJ9M8KO8qFD4a2+orteAon735qFuXhwBq+6a2lcaWQsJRLH+5lx4ORZ4UV
NR/AmeglhnMbOy7yq76r2fAAnDj3Pfvwih0FXfnPn/pXAFRhFmx9yo5sZd0f
bd8WQPNWl1e1Sew4OJTgN+dZANzHNrZf02fH4/013bEZ9yGh5/qYQSEb81yk
9jLHPUgsjyHlnWVFOn3WSntjLpyY9Arf48+Ky729tMvsuWAlZz4x48mK0Yf1
tWen7gLpBgnBlhW3dpbGC+JduHUm++TgZlb8yOLq+sL7LuSpV78TG2FBxc3R
6T/O3YHax/8lJVuyYL/dmJ7zXBZkjLf+3mHEgoGRoxSjliwIl3ri+UmHBdNO
nq05eS8LaMln9VSVWPCR/ZHMvP1Z0OC/ZqqZlQUjt5Qw7jIy4e4hvVu8/v+I
VA11rdu3MqDtYL7AsuFfYtetjKjOfbdh+UigTYL6X0I/q7HntfptUPQ1ubpR
+i9RFfFU6B/5NkSGj6/TXV0lbg488NHqTIPNuSqs4dWrRMORH6/eOKRB/H/l
06sqq8TXzJOx5h63wCCioYVVeIV4cUlyqTgpFU7E3uS+zr5C+Dz+amRyOhVu
J3uZyc7+IWYiHulsOpAKM7lcDYZtfwjD2j6dC9KpkNNoyYi5/Icwina4mV1x
A5bXdxet/btMtM8l9Xn3XofyvLHYdeNLRIK13h9t02vwNWf8rEzXEmF8GlTW
qF0Dscxvx3SeLxHtUtKOPwWvQeSN7+Y+mUuE7mKHOg6mgPnFef431kuEy0QU
4RGQAkNH16bF1/wmglgRsm2SgZei8IAzYZHYGmc+JnUkCTwfe75eqzpPdD1l
v7eHMw5YTE5LuorPE/d5ruWSRmIhsy8iqGbdPOHI0hIg/SwWOtamyR3/OkeE
UZ5dlgiMBX3nN1Htd+aIXn83t0tjl0B8nZp2psAc8QnVz6a0XIQO98XCrb9n
iWVSzclnuRcARBISDr2cIXo45doGLCPgHd+jKr6nM8SlQ8di1wpGgPPajhHi
7gyRZif398LHcAiZ26ArHzlDlKUU67xzC4cnHUWTU9ozxOaowsNJ/udgt+SN
9BXnaSJ6bqNGWGoo8JMEJA23fSdYZ0wd9wkHA/WfY3AB6TthYmnQ7DEQBKY/
ct9x/5gi2iBxU3F+EES3qEd1Fk4R7xfKVz5pBMFs/L4hT8kp4qV87hpd+0Do
Yb2WF7dukrjR9buz6d4ZuPNrvVLr5wli94un1BPd/tDcVDumT58gMkOENml7
+cNctse9itQJYtPz/X1li35gblYtk7VngmjiWXP/hYQfLGS5SBwvHye0Nl/m
4jh1HKx2l5LXxX0lyt6VsVrSjkGo+MH2cLevROjkImWi3xvuzbAkz+h+JSSV
h/Qcw7xhOcOet3dmjLjBKxic9NQL7k//4XjgNEbMXVjZvSB1FFZum68Yq30h
ioJTORal3UHJf45ew/WF+F4qPUl55Qa2Rjmhm0dHCcpFyvP9vm5Q+P3nguDt
UeJxaa7Gg+ojYG+Y/nOEdZTwlyjt+lnnAg8nx79Gdw8TX7/Rp3sSHaEHr92f
ezxMeKy/Yxc34QAst3Q9jyUMEwPMIUA1dYAD+snD1jBMPG/j04riPghsN3cM
SBYNEaHtSzY9xfZQEc6dH7r0iZju5PlP7JANlCTF13iVfyLuOy7vZ3tjDfez
ON7Z+X0izH4/uSQ5ZAW36tiWVIcHiVV9KucW8b3QFB/vKhE6SPje7PSvfGsB
ISvLViNNA8QNo0G1uzf2wCneUM+2CwPEyX85PkcrzMBHYjG0Tm+ACGXf17Hh
oyk46f26d6usnxgqEV3IU9sNeuGTy+a3+wj7PtpuU14j0EzyIWnb9hF+Ynez
Mq0MQTVrXEGBt4+odnEXPn7TACTrRm3+RX0kllmEWB9u1QeRFjevKZ2PBL/r
ti2u3ADrBz6f+/irl1iTktn9qG4XsKz0F5R79xK/F7cpWu3Shd88TnV3ZXqJ
yuudi8U8O+GneO/7K/0fiO63C5Rjo9owotu14m39gbBcF2L989EOWOL4b+c6
iR7CpsLz53tbDfjUH/hkaGMPwSM1nZtrpQFQtz7V6Hk3scNi/d6Atepwn9FQ
2C7ZTSRb29o+i1OFnLeG9c96u4jHDT0BPmUqcKsfO4uvdxF7RLWiE79RIO5P
3d+LHF2EweeZmtYrihDNoyt0BjsJsHTm37okDyHitRTXsE5iMvIDf1KQHPjo
Vtrr/OggTssWaITlSoO7xTZfxcIOwoi5A4zyJMHp0JMoQfcOQnf2u2m/nARY
nCst/t79njB86W1dcEUUjBNVsC/5PSEwEXflVpAw6GUWdb/e855gT1ae3R0l
CJoPlSYr2N8TtVOh/n7FZCjxz51OyW4n1m5TjgoK5wfFt3IiyWfbiYHvG0Z2
vOYFyf5clXD1doKldzXKa3gdqPbAhY6eNuK7geIHYicnSC7olpaYtxGZVPLb
qfdrYL2Idm9s/TsiftNUl+99NmDZocnupvGOULLA1fhyFnBQe8gys6+VWLti
OV/6YZnWeVP54vSVFoLKetPkAcscraFS/vEb1hZCjOPTZ5c9P2gV3dJ9+UFv
iUjfw/lsxmO0+/MSayO/NRM51znkbo98pP2yTPAMu9hMqD4qWJyObqX9D0EC
HRw=
          "]], 
         LineBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAB6Px+x19ur+tizL+ryfFPqUALIKH
fbi/SKx1Yy3r3T40bCunokS3vyRiDPES/OQ+wtcqzL0Ltr+dKngD3/7qPlBD
KvHY0rS/aylWgMZz8D7frikW9Jmzv2enUPcZT/M+bhopOw9hsr9ACTLNrwT2
PvyFKGAqKLG/75RE8P+G+D4U408Ki96vv7mTZLCrx/o+MbpOVMFsrb+0uBLM
dLf8Pk6RTZ73+qq/JQ9pLjRG/j5qaEzoLYmov7Mkf1vQYv8+hz9LMmQXpr9q
A7iIM/v/PqQWSnyapaO/Yu5hXkH8/z7B7UjG0DOhv5av/F/MUf8+vImPIA6E
nb+xmmf4iub9PvY3jbR6oJi/zzIkJwyk+z4w5opI57yTvzOdxcurcvg+1CgR
uaeyjb92to+Mhjn0PkiFDOGA64O/9WJlqtq87T53ww8StEh0v7NK89Swi+A+
rihVAFMrcr81jRsyEOzdPrNXuzw=
          "]], 
         LineBox[{{-0.1982962137644341, 0.}, {-0.19592746934375058`, 
          0.}, {-0.19115308630680344`, 0.}, {-0.1863787032698563, 
          0.}, {-0.18160432023290918`, 0.}, {-0.17205555415901494`, 
          0.}, {-0.1672811711220678, 0.}, {-0.1625067880851207, 
          0.}, {-0.15295802201122644`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.1151292546497022, 0.}, {-0.11234333272685708`, 0.}}], 
         LineBox[{{0.004435848449546153, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11176#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwVlnk8VV8Xxg0hM/deU8o8iyhj6S6zQkgiEQkZUoZkCKmUuZJkChFlSCUy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          "]], 
         LineBox[{{-0.25518122653047426`, 0.}, {-0.24874335632164116`, 
          0.}, {-0.24446638544752458`, 0.}, {-0.240189414573408, 
          0.}, {-0.23591244369929143`, 0.}, {-0.22906303436899367`, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.11956510309924583`, 0.}}], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA2zSDL2dWvL+4mh7gF+KdPogpLThR
77q/R8UoCdLrsD6lACyCh324v2IB/Hy2zsA+NGwrp6JEt781FHEfSfDEPsLX
Ksy9C7a/oWw36oP5yD5QQyrx2NK0v8azi2WD3Mw+364pFvSZs7982byMQUXQ
Pm4aKTsPYbK/niz1Der50T78hShgKiixv2ged6Xpg9M+FONPCover783o1WY
b9rUPjG6TlTBbK2/Onsgxyb01T5OkU2e9/qqv8x1cUUwx9Y+amhM6C2JqL/a
fyrCHUnXPoc/SzJkF6a/oLbvvutu1z6kFkp8mqWjv2P9XZX7LNc+we1IxtAz
ob/gjXNIDXfWPryJjyAOhJ2/PqiUIDlA1T72N420eqCYv+DiihDpetM+MOaK
SOe8k7++pdHh0RjRPtQoEbmnso2/lCjsTNgVzD5IhQzhgOuDv7gPiN3ZgsQ+
d8MPErRIdL9gHbMD+a62PhInVQBTK3K/7HN7NnN/tD6dXsED
          "]], 
         LineBox[{{0.00443584844954651, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11176#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwVlnc41e8bx42EUsQZZoSDc4xSRNS5jaiQlRRpKGRWpEK0lFAhlZVNKkkh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          "]], 
         LineBox[{{-0.2126328996767897, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.34102533656076384`, 0.}, {-0.33428277380397264`, 
          0.}, {-0.3300058029298561, 0.}, {-0.32572883205573955`, 
          0.}, {-0.32145186118162294`, 0.}, {-0.3128979194333898, 
          0.}, {-0.30862094855927324`, 0.}, {-0.30434397768515664`, 
          0.}, {-0.2957900359369235, 0.}, {-0.2786821524404572, 
          0.}, {-0.27440518156634064`, 0.}, {-0.27012821069222404`, 
          0.}, {-0.2615742689439909, 0.}, {-0.24446638544752458`, 
          0.}, {-0.22150459657587682`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11176#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVlnc81d8fx62sKPPei6yyhaKs6r6NCGWEZCVECJHMKFKEBslIIoQiGoR7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          "]], 
         LineBox[{{-0.3392531333116301, 0.}, {-0.3300058029298561, 
          0.}, {-0.3128979194333898, 0.}, {-0.2786821524404572, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.4560811638023718, 0.}, {-0.44976098740512027`, 
          0.}, {-0.44548401653100367`, 0.}, {-0.4412070456568871, 
          0.}, {-0.43265310390865397`, 0.}, {-0.41554522041218767`, 
          0.}, {-0.41126824953807106`, 0.}, {-0.4069912786639545, 
          0.}, {-0.39843733691572136`, 0.}, {-0.38132945341925506`, 
          0.}, {-0.34812483021071716`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$11176#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.11577016129161738`}}, {{-13.815510274069974`, 
        0.09530989591002416}, {0., 0.11577016129161738`}}}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.12}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.12}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, 
   3.6390767166598787`*^9, {3.6442574366310177`*^9, 3.644257640914957*^9}, {
   3.644257708990077*^9, 3.6442577371366043`*^9}, {3.644260004751333*^9, 
   3.644260077952415*^9}, {3.644260115987558*^9, 3.644260126350301*^9}, {
   3.644260188124305*^9, 3.644260218133224*^9}, {3.6442602591886263`*^9, 
   3.644260302050921*^9}, 3.644316648114072*^9, 3.644576451074027*^9, 
   3.644576487542392*^9, {3.644576549658166*^9, 3.644576621616087*^9}, {
   3.644576764562796*^9, 3.6445767820862637`*^9}, 3.6445768574554853`*^9, 
   3.644576945003827*^9, {3.644577113369245*^9, 3.644577140083241*^9}, {
   3.644577753012301*^9, 3.644577802627615*^9}, {3.6445780569311028`*^9, 
   3.644578103866412*^9}, {3.644578289753704*^9, 3.644578315580659*^9}, 
   3.6445783615710917`*^9, {3.644580938831132*^9, 3.644580960697556*^9}, {
   3.644583691767996*^9, 3.644583700885569*^9}, 3.6445837471615887`*^9, 
   3.644583847010324*^9, 3.644583892827443*^9, 3.644583928512251*^9, 
   3.644585111858407*^9, {3.644585173229665*^9, 3.64458519082297*^9}, 
   3.644585513469898*^9, 3.6445863990953827`*^9, 3.644597859482862*^9, 
   3.64459793577026*^9, 3.6569749437404423`*^9, 3.6569800300558558`*^9, 
   3.726157282226954*^9},ExpressionUUID->"f145e1e0-95ae-485f-8a31-\
e9cf236ef123"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Positron Cascade Spectra of Final State ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.06"}], TraditionalForm]],
  ExpressionUUID->"ea3bed07-19c5-4899-b617-3a196995b743"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.644597670763866*^9, 
  3.644597688717393*^9}},ExpressionUUID->"70cfd546-a43a-461e-81c5-\
150e154e86c6"],

Cell[TextData[{
 "In this example we load the positron spectrums of 1-6 step cascade step DM \
annihilations terminating in ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.06"}], TraditionalForm]],
  ExpressionUUID->"be67b221-5745-44f2-bcf7-267dd8822cfd"],
 ". As this value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "f"], TraditionalForm]],ExpressionUUID->
  "6e272fba-e41d-400d-b903-0b537a4ee8ee"],
 " isn\[CloseCurlyQuote]t one of those provided, we use linear interpolation \
to get to this value, which results in a slightly bumpy spectrum."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
  3.644597777558477*^9, 
  3.644597832058378*^9}},ExpressionUUID->"222d28ed-06db-4940-9b6a-\
dc3f4cd51239"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "\[Epsilon]vals", ",", "\[Epsilon]", ",", 
   "xvals", ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3",
    ",", "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_B_positrons.dat\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.06"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Epsilon]vals", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"xvals", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"flux", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Epsilon]vals", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"xvals", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"flux", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Epsilon]vals", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"xvals", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"flux", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Epsilon]vals", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"xvals", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"flux", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Epsilon]vals", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"xvals", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"flux", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Epsilon]vals", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"xvals", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"flux", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.06"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, 3.644257377150648*^9, {3.644257434361697*^9, 
   3.644257640256255*^9}, {3.644257707534048*^9, 3.644257735875279*^9}, {
   3.6442600032445927`*^9, 3.644260076895362*^9}, {3.6442601126335287`*^9, 
   3.644260125127042*^9}, {3.644260206635504*^9, 3.644260216755534*^9}, {
   3.644260257841144*^9, 3.644260300439433*^9}, {3.644576371341427*^9, 
   3.644576438767619*^9}, {3.644576479640806*^9, 3.644576479920644*^9}, {
   3.64457654220582*^9, 3.644576615392721*^9}, {3.644576776040201*^9, 
   3.6445767991854687`*^9}, {3.644576834719887*^9, 3.6445768523652887`*^9}, {
   3.6445769381615953`*^9, 3.644576938607382*^9}, {3.6445771076003437`*^9, 
   3.644577147245116*^9}, {3.644577743925811*^9, 3.6445777948429527`*^9}, {
   3.644578047110093*^9, 3.644578096858204*^9}, {3.6445782810736*^9, 
   3.6445783067921886`*^9}, {3.6445783514558153`*^9, 3.644578351709989*^9}, {
   3.644580871103026*^9, 3.6445809542044983`*^9}, {3.644583694406518*^9, 
   3.6445836945720377`*^9}, {3.64458372703931*^9, 3.6445837383126783`*^9}, {
   3.64458377711351*^9, 3.644583837531001*^9}, {3.6445838746916313`*^9, 
   3.6445839220568733`*^9}, {3.644585052730834*^9, 3.6445851006510973`*^9}, {
   3.644585166144863*^9, 3.6445851833791313`*^9}, 3.6445863844322357`*^9, {
   3.644597692813653*^9, 3.644597756499536*^9}, 3.656974927480833*^9, {
   3.656980006348371*^9, 
   3.65698000687496*^9}},ExpressionUUID->"ee73126e-e183-4b54-a14f-\
8fdf385b30c9"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwVV3k4ll8TtmTfXoTs+x4houiZUiF7CJVCIUoR2Yki+5aUnSLLq82vBYme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          "]], 
         LineBox[{{0.004435848449543689, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11945#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwUV3k4lG8XtpN1zCCRfSdKG0VzkCRKQkWkBWXvV2RLpYhS2fd9nRkibSjR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          "]], 
         LineBox[{{0.004435848449543689, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11945#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwUWXc81e8XNzIzrntt2ZuIUhq6B2WEJFSUZGRrWBlRRGZ2dvjGHRktilK6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          "]], 
         LineBox[{{-0.11061973303514572`, 0.}, {-0.10521419164175516`, 
          0.}, {-0.09566542556786091, 0.}, {-0.09089104253091379, 
          0.}, {-0.08611665949396666, 0.}, {-0.0765678934200724, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11945#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwUV3c81d8bN7JKXPe6F5G9V9JQyGNEVhKys0KJUpKiYYaUHYoyLveW0s78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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQzfVU41jQtqv7GaBg6e4jKy7IIfjzTjvt23vjCpw/
7faBy6smIfjtv/f8a2FD8Bu4rUWKDlyG8yukd2rGVyH4mdZbQyzfXYLzvavX
rnp79SKc79KtfeBWP4JvM3vl1eOeCL7u7qUMi/ZegPPlvlmvXeN1HuH+rzKs
dS9Pwfk5q+dM5/ZF8E0SZbRmbjgJ5x86I+2/pfwEnH9/sdTMV6zH4HzJIAnd
cKWDcL7hLr+Qgzlr4Xy/ib7zvv9aBednZfi80O1cAecvEfOqmbV0MZxv8KzL
4/meyXD+RJNQhmDtIjgfAHNCcfI=
          "]], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11945#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwUV3c8lf8XN0IDufe6XCN7rzKKrGNEipSRnZCdIjtRITMjfQup5F73StEk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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQfdn0bmOg1N39DFBQwFOZcr7pDpyfKfO9co8Ngh9l
83nJtA234Xybmte/vGbcgvNNejIFLIIQfN05z1VVeRB8uT2PA/7X34TzGf7c
XrY5/Qacf7j6TJCM+TU4f0+3Vwbnx6tw/pbZJ2q/rULwl+4+suKCHILf/nvP
vxa2K3C+d/XaVW+vXkSo/yrDWvfyFJyfs3rOdG5fBN8kUUZr5oaTcP6hM9L+
W8pPwPn3F0vNfMV6DM6XDJLQDVc6COcb7vILOZizFs73m+g77/uvVXB+VobP
C93OFXD+EjGvmllLF8P5Bs+6PJ7vmQznTzQJZQjWLoLzAaDTes8=
          "]], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$11945#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwUWHc81e8XN0I2WfdeieyVSNk5IjNJyFYUilTKnhklM1K2iHtv0zcyiobP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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQffTJ9gIvzUf7GaCgQcxOg/f3Qzh/9evnzxquIvjX
Dkxc+mU9gs8wzTolowvBD3Pof+hvj+AzTTW7I7fyAZy/pYZrceXPe3D+mp6O
HWmbEfylc9jOBeci+NP2MP3UfXgXzq/488vv0Yk7cL5NzetfXjNuwfmHq88E
yZhfQ5j3VYa17uUpOD9n9Zzp3L4IvkmijNbMDSfh/ENnpP23lJ+A8+8vlpr5
ivUYnC8ZJKEbrnQQzjfc5RdyMGctnO830Xfe91+r4PysDJ8Xup0r4PwlYl41
s5YuhvMNnnV5PN8zGc6faBLKEKxdBOcDAFMdd1M=
          "]], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$11945#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.05007673491884507}}, {{-13.815510274069974`, 0.09530989591002416}, {
        0., 0.05007673491884507}}}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.06}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.06}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, 
   3.6390767166598787`*^9, {3.6442574366310177`*^9, 3.644257640914957*^9}, {
   3.644257708990077*^9, 3.6442577371366043`*^9}, {3.644260004751333*^9, 
   3.644260077952415*^9}, {3.644260115987558*^9, 3.644260126350301*^9}, {
   3.644260188124305*^9, 3.644260218133224*^9}, {3.6442602591886263`*^9, 
   3.644260302050921*^9}, 3.644316648114072*^9, 3.644576451074027*^9, 
   3.644576487542392*^9, {3.644576549658166*^9, 3.644576621616087*^9}, {
   3.644576764562796*^9, 3.6445767820862637`*^9}, 3.6445768574554853`*^9, 
   3.644576945003827*^9, {3.644577113369245*^9, 3.644577140083241*^9}, {
   3.644577753012301*^9, 3.644577802627615*^9}, {3.6445780569311028`*^9, 
   3.644578103866412*^9}, {3.644578289753704*^9, 3.644578315580659*^9}, 
   3.6445783615710917`*^9, {3.644580938831132*^9, 3.644580960697556*^9}, {
   3.644583691767996*^9, 3.644583700885569*^9}, 3.6445837471615887`*^9, 
   3.644583847010324*^9, 3.644583892827443*^9, 3.644583928512251*^9, 
   3.644585111858407*^9, {3.644585173229665*^9, 3.64458519082297*^9}, 
   3.644585513469898*^9, 3.6445863990953827`*^9, {3.644597709149899*^9, 
   3.644597727397072*^9}, 3.644597767321594*^9, 3.656974936784327*^9, 
   3.656980015420948*^9, 
   3.726157283305929*^9},ExpressionUUID->"3a17b959-d286-41bc-8390-\
d8cb22136b52"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Antiproton Cascade Spectra of Final State Gluons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "\[Phi]"], "=", "50"}], TraditionalForm]],
  ExpressionUUID->"c67bb843-be27-4ba1-82c0-21b428aecb44"],
 " GeV"
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.639076412252461*^9, 
  3.639076429227652*^9}, {3.655488386909247*^9, 
  3.655488387753139*^9}},ExpressionUUID->"13b88807-aea3-4df3-8e3c-\
47d9623cd486"],

Cell[TextData[{
 "In this example we load the antiproton spectrums of 1-6 step cascade step \
DM annihilations terminating in gluons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "\[Phi]"], "=", "50"}], TraditionalForm]],
  ExpressionUUID->"0a26f985-75ac-464f-a9e8-4b9552a5dded"],
 " GeV."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.6445980312314053`*^9, 3.644598048158736*^9}, {3.65548839460959*^9, 
   3.6554883957627993`*^9}, 
   3.6569741280149107`*^9},ExpressionUUID->"8664e545-b68e-4425-ba8e-\
3d059a1d8129"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "m\[Phi]vals", ",", "m\[Phi]", ",", "xvals", 
   ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3", ",", 
   "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_G_antiprotons.dat\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m\[Phi]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m\[Phi]", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.04"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, {3.639076434207601*^9, 3.639076487532075*^9}, {
   3.639076690007765*^9, 3.6390767031080008`*^9}, {3.6445771538368177`*^9, 
   3.644577154500536*^9}, {3.644577235378191*^9, 3.644577356050426*^9}, {
   3.64457739648755*^9, 3.644577513568507*^9}, {3.644577544232073*^9, 
   3.64457754799872*^9}, {3.644577605357257*^9, 3.644577624050283*^9}, 
   3.644577673866103*^9, {3.644578087963068*^9, 3.6445780888099413`*^9}, {
   3.644578251564781*^9, 3.644578254195959*^9}, {3.6445808713366413`*^9, 
   3.6445808713648157`*^9}, {3.644580921951578*^9, 3.6445809266978807`*^9}, {
   3.6445809743232603`*^9, 3.644580978731881*^9}, {3.6445810985910177`*^9, 
   3.644581141708456*^9}, {3.64458119834447*^9, 3.644581198567319*^9}, 
   3.6445837383232327`*^9, {3.644583956159071*^9, 3.644583973382719*^9}, {
   3.6445848902302*^9, 3.644584890748803*^9}, {3.644584932860217*^9, 
   3.644584948499735*^9}, {3.644584996744629*^9, 3.6445850332899446`*^9}, {
   3.644585191186246*^9, 3.6445851953794117`*^9}, {3.644585405650796*^9, 
   3.644585428326337*^9}, 3.644586384471479*^9, {3.6554883904755487`*^9, 
   3.655488390913857*^9}, {3.656974151600212*^9, 3.6569741518050528`*^9}, {
   3.656974868342043*^9, 
   3.656974892887167*^9}},ExpressionUUID->"37cfbac7-4a10-4970-9b69-\
3e844a028b3f"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwVl3c4l+8Xx81k7723jxWywue+RaJkS2YyQ0pJmZUou0iSkPGRohRSSPQc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          "]], 
         LineBox[{{0.004435848449543462, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$12583#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwVlXc8198Xx80IZWZvPnzMskJ0r0QZGSGVEYVCQiSUShEyvkaS7WNnVLJS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          "]], 
         LineBox[{{0.0044358484495436315`, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$12583#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwVVnc8l98Xt0cUJbL3+nxEVpFxr1DJXl+VLZSVTZGVTSqjbD4hFCotRXiO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          "]], 
         LineBox[{{0.004435848449546622, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$12583#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwVlnc8V/8Xx8neM3vvXcke9y2FSmUke0SUlVWREVIhoyGbDyEj9I3ICN1T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          "]], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA3zSDL2dWvL8KQWQ8mJB+PogpLThR
77q/8kEGyrbzkT6lACyCh324v0sIifKl0qI+NGwrp6JEt79iSKHz3ACoPsLX
Ksy9C7a/hdydykQ/rT5QQyrx2NK0v30o41CkO7E+364pFvSZs79m/mhLZsiz
Pm4aKTsPYbK/yRBGdg45tj78hShgKiixv39E01Luf7g+FONPCover79+KwLC
eY66PjG6TlTBbK2/a97Rsz1VvD5OkU2e9/qqv7mYFITWw70+amhM6C2JqL/t
5vQB5si+Poc/SzJkF6a/9jCWHwlSvz6kFkp8mqWjv1HfGEfNS78+we1IxtAz
ob8IQjZSpaG+PryJjyAOhJ2/vr6TId49vT72N420eqCYv1qU19CSCbs+MOaK
SOe8k7+TuHOEoOy3PtQoEbmnso2/5PAEzpnNsz5IhQzhgOuDv72IGkhzI60+
d8MPErRIdL/4h3LTqzmgPuUoVQBTK3K/EOvvuWtYnT5qC72C
          "]], 
         LineBox[{{-0.1708554000562921, 0.}, {-0.1672811711220678, 
          0.}, {-0.1625067880851207, 0.}, {-0.15295802201122644`, 
          0.}, {-0.13386048986343793`, 0.}, {-0.1290861068264908, 
          0.}, {-0.12431172378954368`, 0.}, {-0.11956510309924588`, 0.}}], 
         LineBox[{{0.004435848449546105, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$12583#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwVl3c8V98fx0n2+lBG9vjYkdDX7B5JCCErJCMjM0JKEVGShFDG52NHiJQK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          "]], 
         LineBox[{{-0.2258255160195356, 0.}, {-0.21880456020282513`, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.11956510309924577`, 0.}}], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA1zSDL2dWvL8eFrIZE+hnPogpLThR
77q/pjtBqOkSez6lACyCh324vzcCYC5X5Io+NGwrp6JEt7/EqY1/OsCQPsLX
Ksy9C7a/Tb2S7s/6kz5QQyrx2NK0vwPDb4TPFpc+364pFvSZs7/GKC7haAia
Pm4aKTsPYbK/MRRVFhDDnD78hShgKiixv9pji9V1OZ8+FONPCover79gTxGt
v66gPjG6TlTBbK2/yZWzBR+QoT5OkU2e9/qqvwkrwWrzOKI+amhM6C2JqL8U
M1Wb5KCiPoc/SzJkF6a/tCsm/yK/oj6kFkp8mqWjv7XK5N1iiqI+we1IxtAz
ob9NPilt1/ihPryJjyAOhJ2/MiCqsy0AoT72N420eqCYv8033oAOK58+MOaK
SOe8k7+Yb09p6VqbPtQoEbmnso2/ELqJPeB3lj5IhQzhgOuDv8U/00quaJA+
d8MPErRIdL8ZsfUClCWCPhInVQBTK3K/748vxfVlgD55d7Rp
          "]], 
         LineBox[{{0.00443584844954651, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$12583#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVV3c8V+8XNxKJfD62hr1FpWR2j4yIbImK7BGpjKKIUjLKKPMTKlIR36bZ
uEdGykw0qOy9Z5Hx+/z+uff1ft3znPd5zng/zxVzPm3pxsTAwHCU/vj/O9B+
Q0LMfQUcahsS6ifeEYcUJo8eu6uATn9bv06efkeIL7ZKbc9UwKRS05uG998R
jUn3XjekKWDUf6xr/etIQrpedZCSoIB813686Gwiie8a7kTqJQV8Myh6Obsc
CQ3ByrGcYwpof/xOfXr4e4Iy8LgkwE4B39/SyA/Kek8MvIy7on9EAbnyxsci
37wnbpkdFRy0VMCFpvOdyovvidHIaV15IwUUPLJL6XNAJZExL3LnmZoCPit+
seATWEWstYQcfMungHNm9b6/MmuIvWQt+wkeBWxlluY6WF1D+D7hrWegKmDW
VhGzv2M1xM+IAlM9DgW8ZXkoWmLfB6J0z0+rOiYFfO24o72s6wNxJkXT4cek
PDqZrNwyUPlIdNst+c1/lMe+ghVNL/56QvDAgT2pH+QxEWcUJQzqCXPlW/Nq
1fIYYL3DZmdQPfGOXT4oBOVRddDV/UBHPUF7bRfKXCKPDho1/GdyGwjLbWXX
qQ/kca76a1LJwSaisut8huIleZQL9+dZ9v5MyIpei/lzke7fqe0/rqjPxI0T
t4IqguUxSqnvnvGDz4T17wLrw4HyeN3OcL/2r89EX0c3R6iPPBYtJj0xsGgh
1n8zDq0/Ko9xZjPPuHW+EIYNIg7eqvLozFikF2XYRhRwKB5SUZFHn84TcXdP
thGUQxoaa8ryOEFVtRm70UZ8/2TNf1tJHqvkhmtlWtoIr9roxnIpeaztKRDY
eeIrEVM5S7DzyuOxxtDh1ohvRH3ZB5G8KTkUnl75eXTxB+Hbf1720oQcjmf/
1zEp1k5QqbK7rMbkUIU4x1dp1E7YeEbprAzK4YuShmqpzHaii/+gm0WnHD4/
dOvngF4HMef/KX+xQQ63vNsSXXDvJ7FVqUHF6IkcGkfaFK6P7STe2YUSInly
qJpyVIPyppNwuqZoMPdQDlsWZx64jncSD3/etM3KlsPb8vGj52W7iJ2xphdn
0uXQQNpjtuFmF6E31IS0KDmMZTrnW36im/DJbjEedZNDdp3bm7eL9xJnxoaM
El3kcNo7k8VQp5fw37t2UNWJzh8PjWnOvcSFTwqGEcflMMzaRLM9p5e4PnNV
b4uVHLrnmF/rku0jsnVU9xlry2FapfK2Fa1+4kfPHaUnm+XQmddNxyJxkPi5
/YWihaAcPrjdZXWvdJDoOle7/Q+fHBqG1JyR7hokBtjn5XWpclh21efi7I4h
Yk7ZVKaDVQ77Y9tCM1uGCEoEg+jGeVkcYfXzTJEcIQ5IuFG9m2TxibpzOa6M
EedQa596gyy+2PU3IV5+nHhkz+vFWieLyaWlfNlHxgm2tErMqZHFuor6X7df
jBOfOMTP/HwriynBM3rF3hOE6cLvRpMCWbzuAPetRicJm4+2N3ZGy+KnpK/D
wwnTRKT7ztLVSFlctQ43H3oyTZQws/XVX5XFxQ03zLg+TBOCRImmV7gs+unG
b/q+Mk20v+AbvX9eFoPrbsKxUzOEQ0bLQR53Wez7ks9gYT1LuJ0+xLqgI4v2
7wVnRXXniQX5GLlkbVlMDXJssnGfJ6IGPhjvIWTxrGRecXX0PJFvr5vgp06P
x4zKZP55npgy1hCa3CGL27aK1Ym4LBAhsrIKQ1tl8b++0vSbiX+IW93MZu0L
Mhh32kv35bYlQjJz/9ngORk8+vXQ+SeGS0SRbdhtwRkZ9H1TZzPgv0R8b1r6
ZjMugwN/BSY465aIbe+mHb/0ymBW4CPvByH/iMe0Tr/6Zhl0PXwl7dj4MvHO
6nXKu3wZdNs3oN/DzABx/+588XwsgzJz5yujtjGAQ04IheehDD5Q6t97RJUB
Vmb2xXjcl8FHRhWbTnkzgNYtDKWkyWD2XdnOiDYGKG+udnW+JoNSlAyH1OeM
UGzSrLzeUQYdLu0TOBnDDJHzz04/s5fBU5UG28LymMEmM7Hg6DEZnGAKsquq
ZYb5MUvppzYyqN8RcbeLdR3sudEmZGsig36bPRw9o9bBi0/tDPkaMlgSm7e/
5hYLFBr0N5rwyaB2p5B7ZSMr5OtcVxPlkcHdQV9V2qZZ4eE+uewZigw+41A0
FeJjg3u7TwWmcsig5O42S/XjbJAkMr+lm1kG8yzVLerG2ODCn3VeATPSqLmZ
t9lBgB0MH0ky32mSxoIWh4L6ZA7Qz67xOdUgjc/Xn1/JIDlAJ9PzK9RJI49Y
2vyDYQ7QvF2Q11cjjXW0kHpDghOUwvaYK72TxtFXOqqOI5zAd0Qvs6JAGu8q
NaWJm3JBz3pX1aFoaTz5Ut9GQIIK2qI+qbHXpdF/ZmQfG0GFLPWAP0rXpJFV
3odF3I4Kdj5XSwLDpVFIeMHsczwVmj8/UGU+L415l3sjpdeo8C6jX1XYlc43
UXpmsJ8b0pU91KwJaex0j7vW2coLC8an0/5oSqPeS5e1Y/O8YO12/i9NXRqD
gmvSNvDzASXtemn3HmkszR88sXiEDyJXHqmdVpDGHboq4bt/80FA7ZBajKA0
ymq59hFz/GDucFIdZ6RwoLFT8bOBEHR82l0TOyWFbBf17pr7CIG76orlkQkp
5HIZFGNOFIKLlASfiWEpvO9hYsvUIQQP3xfd3dothbu5D24+c3YzrEgzrg9u
kkKm73tWch9tgfzJ1JZdBVJYy0rpy98nDCrHnU6s5EnhtXPZlxY9hQFr5cdq
H0kh7q3rj0gShrb7b1kcc6Sw/OCeP1pjwsBg3asWR5PCFjXuD4ZZInCkVOnu
SJQUtnuf+7EWKQrrLld757hJYXQF5fE2LnFo+LGL54KLFBaFh68py4pDinJW
ubmTFHKLbH3itV8cZPvObVg9LoV12ve/aAaIg4mB7CNbayk8JJ2nGNxBt+eM
7eHUlcJH7BrNV59JgBzN3C5IVArtU3aLPAuUgpmZNwxmwlJ4/mfcmOZtKXhj
LPdYaqsUZl79+XHimRSYrjD+aRGQwpvnIu9+GpMCP8eXSYpcdGxWvs7JXRre
SPM396xIYo7+iQA1JxkwfdlxwKRDEpWqOJiXAuUgSP6/vrnvkthS78H43x05
yL4ffiXjqyQapOiUpVbIwUK81LvRz5J4KqYzmXOTPGT5nFaJqZXExPAbPrF5
8jApxSz5oUgSw8W22gyPKEBCmjzj/gRJzJ+PsFdPU4JyrpWsoZuSuLQjpIy/
Wgn6Ipu0EmIlUbdy2nz3jBKoBQYEdUZKYszPT8cUTHZAl8W7ydBQSSxw/dXO
zrwTdm20/F1+UhKFb4W+fVyxE1pCg1/v0ZdEhtpC/se2yiBnyBm5TlcSl9ey
WC6dVYZw7vvmrdqSmHvMcZ17jDIoPart99eSRKbey4HJb5QhtlmA8nK3JKqP
OnScF98NehLFrrvEJbGh8R7X+bndUFw7w6m0JoH5cZ1HDV6oAOftyO8ryxL4
uoplwKBJBVztN+c0LEmgTeOK8qkxFeCe2a92akECTbutFqVl9sLpLYnOBeMS
ODQ542aftRdkfXeUyP+UQP+K2SPrklThDo+Po0yZBK5bjHdLzVAH62U3sdpi
CTS6fzDRvEIdOPpP9Hi+ovN1inVpDqhDSLGVa/5TCbTrit6Sv1MDjttpeio+
lMAHaRH84x80YOtd9jO7b9P59u6c1mfQggz5vDA4JYE8ywy3FlIJsObJ0e46
KYEjXutJy0oCOJYzGC97SuDZ64KhwxMEhDQkRLx3kcAoEZ83Hw4AHD8TdF3/
qARuVw4eNlkE2FZsEG9sIIGpPYoHnF5pQ9b+gawjYhI4V/S621pTB5L4Iy4w
i0igYaMg4WqtA7GjIjZPt9LjVZzgSjqlA0HJdpysghIo0RSstvOeDlgM118s
3iSBLX3tJ8fW68K6xJe2fMvieJ3tVex/7brg3RXO/eWrOAawsVzalaEPzkXb
Ji61imNDNeXgqTJ9sI0p/yjfIo76aeUijV/1QW/PXPiVBjpmyutfox4A4SiP
yV1V4rggs8dMPuYAtOwwrU94Lo6H7PaHf7xsAGphWyJNb4jjzXWqO9njDsLx
R8Fx4jHimMRhcvZH4UEIa/qWsnBdHBnd3NkaGw5CjUjSo6wIcbSv5JuX2WQE
1sjxceKCOC7ZiN/ISTCCM4yrG+O9xDHzfZjmmwxjeBzRldh0QBwjJ8eX1382
gfonBC1HTxyDaBcf5M2bwOSXjOzzOuJo06BdeG6zKeyVtHspQohjuNK1awmu
plBV9bn1tIo4btaJFf+wZApdLJUCFElxdP1rdkxPwBwEonIzzRnF0bQqZuO1
YxaQ0eiVMb8qhoLrD/Pa+lmAKJ/SHdqyGBr/eyJlEG0BstnFaX1/xHD0cmJ2
cIkFaLz5cDtoQgyHIqL5xnktwX5qOPpehxhS/TwE1rVZQo6t0rmpIjGkD1Zc
iLc1yN6dCUh+KYbhA93crdesoaC/2F/juRjuu8uQZXTPGl75wdmrBWJ4Ms/z
SXKbNdTcMPcRzBFD/olL2Xn7D8Mw+jlrJ4ih8AJVaU7EBnbIlZgmnBTD5Vfz
yp1zR6DrvdYFe08xdPntIANUW7h1/H2uvLsYSvKkKr1TtIW5+IblKicxvNlz
U3Szhy2UL/TmL9qKYYp4V4dJhy0cqKKwuhjQ/cUshZAf7cDhxElSRVIMj6VZ
Bdm8PQaUxckRJnExLA5N1S38dQwqbgXyN4uI4W3e4Fnp1WMgWRN+6uQWMXzS
uhIbAcdhZHvqlrvcYriyGl3RV3kczi1VnmdjFMPdC5tkS1vs4Wbytp0dv0Sx
PKcgX5PFEe6ZbLAM7hDFfM6eQEkhR3jBMu8v8EMUWSNpfyUUHeFrYH2JVSvd
HhpMPA47gqjNRaj/JIpaPfu52x7S7fl/mL4tEcXwP3dTYk2c4Htq0qm7iaJ4
K7FR+3OBM4yYhcfvixdFl+sJ9SGVzrDC6vO844Yo1pbsz9RudwbxIN15gShR
bNww9pXK5gLetjMhCZdEUcAiZarT1QVWBc1vXPYWxUtOXpVmEq4gSdv4xEVf
FAM69Nw5X7pBIEEb5NAVRd8fZ/a41btBTY+sZLG2KNrrFz/41u8GHgoHMtm0
RJH5+isKp5A75L8Jjy9UFkWJPUvc78LdYWfnvP8fEVHkLNf1MD3sAecMMZh/
XgTzC+q0Rale8OC4V6bbCRH8ujuNjPzlA/eMN5xhOyaCRF+1/9N/PnBHI0/n
iY0Ivl6+OTkrdApuCQ4PTpmIoFasz/eXNqfgcquncoiWCKZ7il7913wKHA55
frglJILe5V3HSz/5gqCWxzT5RRijr2e0fPY6A7Fb3PQ3GwojWL8s+3zHDwwN
Pq87oSuMn2m/d3996gfr/fdV5RDCeMoxine80g/CP/HpKqoI40S4U5blmB+c
C67R1hYXxp+6IT4MhD84f5PRcl/ehokLHcRSnz+o3R5RfvFsGxozq4MDBEI/
+xlRI6FtuD2pb1+5QhAs/3RQ7+TdhpJ9YlrvdIKA96mJZQBlG54wdSJb7YJA
z0rhahbrNgyQ9d6kHhUE2XcGBmfmt6LpWbYrpv1B4LDd/umdlq04cPRAgU92
MHw3MSLGY7eiQoPJ2xfyF+FTguTxhNUtGJChX7nd5xL8VDEbdhnejN8kHRk2
f7oCThuj8168EcKvoUGlZprX4ex5n08CDwSxaemejk5rLMzxnBD+6y+Afga5
36KSEyC36UOl20F+dOdUe3NZ5zZ0ibV/HFbmw0i9qcEHT5Jh9NG7ml1KfGhS
n+NZW5QMC4o5lcFyfCiinCmcRSbDRg2ftxtE+fCG2fn9xJdk2Gu5+kyOkw+1
5160HV1KhhtXxNO8BnnRYMkwRccwBVR7T7oP3+FFZo1nWXe7UkDHy8xlVyov
7jqoMlY3nAKHJnc7Bt/iRZUT0VvnZ1LA+d+y3YZoXgx6XK0PLKlwgyfeRO4c
Lw5v3yNRJpcKPbov93iZ86Lg7WtZdn6pEPfgH9PwOl4M5yx/Jf4vFWabne0u
M/Di0vek+VGmNLBd+fhUaJkHNcp3dLxgTwNxm7TjRrM8eOT54mf1zWlQxKpS
/KSbB0WODm/arp4GP0/6evm+48HAUXXZyYA0kN/V3TR7ngdVNBQy8vvSIN7e
UPqGPw8+coiWjBpNg7nopyGSp3lwj53fSeeZNHjXEyp32J0H47fP3eBgSAeL
pM0RxdY8yMf6U61nczoE/bHaG7yLB381JsxvOJQOH97WZKyOcGNloJPSlfx0
ePzeX7ZwgBvHn4pVyzxLh5gPoq+O9XBj9NxeSm1ROph+vlBX+oMbt3WJZa3D
dGjtU1ryq+XGTYp6yUNf0qFrY+qRwVxuvGhbMey9lA7vKXq9yfe5scm7dURi
LR1y+KZ99TK58dXglb3fmGngLmIceT+JGyMtbcV3ctJgXHnt1bEIblzzi5Ir
EKHBkp0Hd7MjN77m4FPW0qHBTwferEvHufGwmf8VtgM0eOtSIadoy42Pr/uV
1B2kQfipLftjzLjRptwiXc2CBqyXm07rEdx4xEfoRckJGvA+Vm0o3cJNn0+T
h4kXabBQ0GfrIcCNtqZ/dOYv0eDb88Q+Ph5udNpbWGd1hQa016P//Ni5kVIW
AozRNAjBtOti67kRfbnbzG7QwL5an6eZkRvl3Kbz0uJpINp0V15xkYqvCrVe
CKTQgKn1UHHHHBVHd7LUKaTToPf74v6YKSp2mz+RJO/Q4GGPld3gIBWbGP60
V92jgeICa9T9r1QMeVOWfDSfBs2qlxlmPlORx2uB+FlAg4DgpSCdBiq+TAwu
sX5Kg/LlMa/eSir27a5j3v6KBobMLcZSz6n4qI1DOOwtDcb0jKsCC6iYWbAr
/j1Jg/jIKq2aR1T88Pmx71oFDb5uKFH0yKLiSZ+aArcaGlww3vmwJJ2KJk6K
C3G1NNh2M0+YLZm+fuOP8OefaOBKyeDKi6Wi4MCATncjDdgs+aIWI6lY6t76
fLyZBk9uxzEYXaHiN80tjdMtNDBtYw2mhVLx4dr83uRWGszwX54eCaKijqfl
cHMbDZJtl7w0A6gY21havPqVBmo0/57Y01SUOMhlJ/KdBmHb3L9sd6fHo0EM
aLbTQPxEp3GoExUdBRsk1TtoUHPPtqrhOJ1PdsdvhZ804JA0LvK1oufr0BmO
uV/0+snvTH2mTUXvpEaObd00IHzyuBi16OtTLm9qpePuQvEoC1Uqijx2GY/o
oYHsLr7gGUUq7qms+dXYS4M6v7hpHTl6fhIXOU/20cD3FevJ25JUtGeWslml
4yLVpaN7tlCR/cxiOHWABrbB/l+u8lPxjahRczwdL5ePGbdRqZiT1MK5fpAG
d5fdqqQ4qfjllW6BPx3rEJ1a59ioeKTVnS2djgfCbItqmKlYf+S5gjIdR1d8
VhRYoyCzFXnjDd3fdmbjhx5LFHwHOfNqdNysVyVcOk9B6yNG8o/76f0RuS+V
bZqCGq7lg+x0LFBbzGU3RsGEfQd6nejxOhjnMSz1UFDwUwAxSd8v003xYKPf
FLyme7Ndmo5zG+9M035QkG17k8Jhen7GLOJ6NJspWOl8fyC1kwYJt1mP3aij
oHm2lnzhbxrsbgv/8rOGgnp8v1rL6fm+YOtfFfqWgu3DZ1yQXh/WE7YPyXw6
3/dK4/PfaLDOwDrI8SEFJ9jSBtzp9WbaYW7EmE33v//wVzN6PzAIHNqanUnB
5TKRil30flldNZjQSafgD9PkvRxf6Pkc0MXeJAq+vhv73+/PNFhshFtXEyiY
U91fvJHefwvFmq5SNyhodpRtDzu9P+eyVPfWXKfgwnG9nH919P6L3M3mEUHB
pCMLL7s+0mDSd0c7axgFy6fsKOUfaDBCyFw6eI6Cc0ssaocqadD1m7+m3pW+
H9+8hNUyGvyu4U475UhBtdc7T6eU0KDjv00nNx2n4L5HzEPSRfR5urR+k7kV
BfUjtwrufkaDeuGFw1/2U/Bs9dbctVwafFo/IxOwj4I2G2qaXXJo8GFifJFX
nYIppwvXv6fP//t3/Zk2O+n5rKKw+9D1AR92n/6jQMFZB3PHkjQavIv7tT9N
hoI/tYaa/iXT4M25HzzqEhTktl7fp3abBmUObf0/hCno0ZW5yTeBBsUHPpdc
2EzBk+f4OSfoevVKqSF6Cz8FY01PbNSj69nT1SpFe04KUn4zKX+8TAPjfV6j
+IcLFz9kDRr70UDyrczGxudc2CUxvaGUrqciN0WecuVx4Wray7HrJjTYbC9g
ZXGPC7mfj0ha0vWXurL+TmscF/6Wtphr06bXT2tAvsOb/r094UL6Drq+vnlg
NCTFhRuKHmTEsNLAZr1K7amtXFh1xrEglpEGrWbV+rPcXBhwdWEs/F86tPT0
a6+ubcLllb/OxpPpUM8mo8rbvgkvmizNBHylny/WeRLacZtQ4DBDUFROOuzP
Ur9ffXUTxlXJaFIy0wEHPwobX9yEgSvmzokp6fD2woiQjecmfFl2IiQ0Oh1K
7ylQfHQ2obEX02MH73T4b6xwOXWBE8d+UUP2b08Hxb3EhW3jnHhzLeCFumQ6
FIQ1/snu5cSZqjOc27emQx735ExhMydqfywaZOBIhwdqO4cr8znxWdrDgbP0
85l29UXbpAMn+rjYi4c8TIPIrSX/GXzgQJcA22sRG9Og7MWhzlPvODDCizPC
in5fGDPs4Uoq4sCBrx/viy6mgmUg59muHA58XP1L+vlAKgg3uuwODudA9dEw
HlVMhZIwSmm+OgcKOYRklvqkwlCPVwVnwUbctrhlov59ChjlbW39ksCOI2PF
ZaE6yXBuat9p6Sh21K8PT8hVSYYc1RPswWHsGGp7qrZWNhmWq+9rC/uyo5qO
ZN06rmT4r0e60NOYHRdzKvs9O5KAe+uuyBUWdqwBu42uAUnQHqevJnNxA8pr
zPZVZt4GrwDfjAtubPh4oJB5/FsinL73+5PAxvVos7IxbioiFmIW75d3f2fG
s178B9l6IsAvfPH18SZmvDplWyPyPgKOslq8/VbNjCymRWWO2REgz8eADS+Y
8fNT5WgXlwj4tNOhuuwGMx4um5sKH7wC7J6bmxO1mXFfDvfdhpnLEPP1Vv/+
x0yYmXm36jJnOPjZjwy8yWLCIgOfHY7dYXC0b/+QajITOuuUxAs/DgP5makR
xStMWL7AQnu9Nww+cZpNCR1nQha29rVMi0vArr/x3zQXEzJLTzWOXQ6B2JcR
lOzzjPhgHZcYSAWDz6h7yEFfRsyNJ89yTgWBqYTR0JQrIzotpP7Z+joIKLcp
CJaM+P2SuTyXZRCk+GWe/rWdESN77E48iDgP2btKGgV7GPBd7gNvjr+BUPZ0
5Eb8IQY8aDZW6bTJH2iDDX/36tKxu/Q82eUHISLPXX+rM+DrYLGIoJd+QMSf
11KUYcD28kJgOuoHVb7rxj4xMqCP8oeywidn4d4xrRQO3zVyp96Dy0LOZ6Dp
SA73ks4q+Vqkwjm71huWHAPMY3atklJn5n4eivAG6ZP6cZtFV8m+StZnuYQ3
XAoZ3KC5skJanXL+7VpyErbfV2AMKVkhd8SPfNj03AuiRl5OriiskKYnOYx8
8z3g1exVxbjNK2RI6BpvgpcHdC4f9hbesEJqXSt6qCnnAXu5/g4QA8tkcXvz
Uch3h77dWr/D7i2TfY2nftnQ/w/3h1bVM/Itky6/9XJrel3AJzKZ/RbzMnls
Ry/nuwIXSIt3NxSf+UfeM/hOszvnAlP32ap0mv6R4xFW/oEbXSCr5tDriOh/
5GWxSmuHvc6wxNWWx7K6RMqvTkfeiXWEl9n9kRsGF8lPNbT4Ov1jMJA1eF6s
dZEc38vRkzd6FATvDHuqVyySjFu4/TLjjsKl2+NGXncWyderJQ/7GuzA6Or8
po9miyTF88jvRVtb6HJjSY0q/UsKzPTX/n54GHicWaPu5f4lR18WpSjYHIYD
DhuCS2/9JY8zWwq+WX8YnthwHhvy+UtKnHrs8MjbGs4Z8IkYiv0lWavPVHvr
WQGHnNQj1pg/5GiXZN8/BgsAKZk0kfN/yGf/LpXFl5uDn5hctKrrH3Kh9vhh
6UBz+Cak6O1B/CG1Vw2OdLSbQTa7yo4PMwvkMLNBxM02E1Ab0yuJPLZAGjvz
i97YbQTeQwceZxkukEkPc337aw9CVp9herHKAilbE8mi53gQmH8dujjAtUDe
lLy38chNQ2hssIYDVfOkIrM89W/bAXB96vqBRXGenBRL9WAs0QUG/bPCJ7bM
k7XncreLOunCnfbQwNIN82QztU+6hUMXWlhSJbwH5kjWH1sVpj11QPv4x7Dm
u3OkevTmv7O798OWDUpqd7jnyBUeU1JrZB8UZ2nEzzHMkc9f3rz/2XYfWO4x
GDCZnCVDXIouPP6oBVEnHJMY6mfJaHvuV3ovNGGh6NaU27VZcl6P/6vcPXW4
ZXzXgPSfJd2zKnZUi6mDYveTLEHnWfJoaFr971w1cOWoPlRHzJJOygd604pU
ocX5z+Odf2fI/wzP9KjPqoDvX2aGmIEZkilEvrAzSgU2xFGO9LbOkEsXF3KW
RFVAu0yOJeX5DPmlwzbxtO0eKOQ67vTv5AxpyzFf6dejDIa5nqXWdjNkhWvO
mstFZejTCOT6z2CG3PPRP2gdvzJsdo976yg5Q467vqdP3i6IeoNCNb+myfjz
OQ6vi3aApGXDGZH6aXJh65i+8rodQA7++BBUPk3urLDyPGujBAvcs4EKqdPk
aYv2TLf1iuDqJdWSYD5NnrvCz0JLkgeGtV1yI8Q0uWvjNrFmRnm4k0SE6ypO
k2q/pHl++clBC3lEaWHDNLnhv6Mv7R1lAfhjYo5VTpFqN08y5XhIQyPnf8Wc
L6bIB3/zA27OScFxlpYe8t4UuXbKSfnZVSkImhPSlLw0RW4NFv1cmygJz1vy
RsfUpsgN7txQlScO2p8aBO7KTJENJ88bCO8Vh8aKaV0L/inSWCPrDne1GLQ6
+at5D06S/ZPlYT0jonBA+Hb68vFJcs1Z4oF8oTA4c3ZMO2pMkllGc2cuTG2D
sGVxo2qBSVKhOddiu/o2KG1/sXSzZYI0N7226377FpBPbTkmYjhBfqJxR2Yc
F4IDkZtfRUhNkB16V4baPwqCS6AzxxDTBOlnZ9HLpCUIGVYzb569HSdPbhV2
uqUkAJso3MI6u8fJfckD1CFmPpBfszv3kDJO9tz/IhV6lhcMJu43sk+MkfZZ
vtbuPTwQXr8r7MvjMVLk+rsk+0ZuyHgd/E01cowsv6t2OvQgN5TlV+zIcBkj
CxZoX3lrqTATZdHlKjxGRrxPvFzRRIFNQelqH/+NkjZvDTQ6bSmg4NGdoPhj
lIwP+xfLXscFrvpn9y/cHiWbJ9hefePeBF8ZE7Ovbxglk+MoFo8W2GFm6vvS
6MAIqRysZPRTmx24ukStzKtGyPcKIg5NiRvA8N0zZqGwEbL0nFJBiAEblF9o
ds2fGyYH9Y5RalZY4KuX4NtNLcNkduMdx/ZgFpi1deTzfzpM3rA+F9nzfR1s
V52q1jw5TCbajLY7xDHD3VkumYbOIfI0496LuxQY4VNtWb92+RDp1FJeKJfI
AHOZLg9eJQ2RUmE9g35/1wgjwxKxjINDJB6IPh1UuUIEbnPq4pIcIp+9fzF+
unSZuDfDfjdidZCs3czFU1byj1jIcNjq/XKQDIsrNFJsWyTE/Ng6ft8cJK2f
pW/ZP/uXOGTwIt3Sc5BUquEJPL/lL5E9zSKgsW2Q3Otiz98evUA01DxtK/wz
QH73tUh+0zRP/L1jlyTWMkD++6BvoygyT5geKKRuuD5AcsbwPf/yY5YI3nKk
OcRpgMyuY8y7rDdLPJhiiJ/SHCAZSzc2FpbMEEs0a47vU/0ki4KmkNWFaULq
zOon47p+8pVgYTZn4xRhrv84msztJxe7LcyWZaaI3Ml/6x8d7ScZHw/aifwa
J5qrcqs3q/ST8QMZaQHFY8RSutnVOK5+kuO1hvLBjFHCXC+H8VxVHxlKG83S
uzlMXBQyweGsPnJP8JKTXtoQ8XBi4ZJ9cB+pvyx/L+DpILGcZrSsp9RHcl89
XFHFOEDI+M6Vl7L1kVpL4o8uafUTlrpZwdt7e0m32qQdGVf6iFBBQ7V7b3vJ
i192Gn350ks8Hp9e4EnrJR2paW1NO3qJL+/vFF336yWdMiLFdqf0EKup+gH/
DvWSlUe0fW6v7yGsddKnexh7yRZPudNezN3Ek9HBgfC2btLB2irs+d3vxFdM
zJ172k267eFvlZb+RjCkaLp6xnSTZXOmz0JftBE22vHdZtBNKt5yKFn51UIw
Je/9KZzXRbLRKiMuUesIxZNdtFsRXaSwWLG8y81awhZi7NY7dJF+arm354Rq
iP+Gf30d5+4idz+4xlbkUUG8CmHPCV78TR5mdJA2bX5OFNyIKnV/+Zt0eKgk
eO5MAZGbsb7R6tRv0voKI9bdyCWyCq72asv8Ju8Unmd6OZlJpLxhWlTs/kXe
dmOrf+ORSLA9JZ58rPhFZrI43n7KEEX8D7m4YNc=
          "]], 
         LineBox[{{-0.3392531333116301, 0.}, {-0.3300058029298561, 
          0.}, {-0.3128979194333898, 0.}, {-0.2786821524404572, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.45608116987576464`, 0.}, {-0.44976098740512027`, 
          0.}, {-0.44548401653100367`, 0.}, {-0.4412070456568871, 
          0.}, {-0.43265310390865397`, 0.}, {-0.41554522041218767`, 
          0.}, {-0.41126824953807106`, 0.}, {-0.4069912786639545, 
          0.}, {-0.39843733691572136`, 0.}, {-0.38132945341925506`, 
          0.}, {-0.34812483021071716`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$12583#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.036788257053311395`}}, {{-13.815510274069974`, 
        0.09530989591002416}, {0., 0.036788257053311395`}}}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.04}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.04}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, {
   3.639076469427896*^9, 3.639076488218067*^9}, {3.639076704542169*^9, 
   3.639076717305942*^9}, 3.644577159564115*^9, {3.64457729122045*^9, 
   3.6445773608921213`*^9}, 3.644577402036332*^9, {3.644577432209478*^9, 
   3.644577519554563*^9}, 3.644577554891653*^9, {3.6445776113653603`*^9, 
   3.6445776301037283`*^9}, 3.644577679022887*^9, 3.644578222132937*^9, 
   3.644578262695685*^9, 3.64458100205402*^9, 3.644581163799165*^9, 
   3.644581226672163*^9, 3.6445840561751328`*^9, {3.64458488311733*^9, 
   3.64458489793933*^9}, 3.6445849846531363`*^9, {3.644585180434134*^9, 
   3.644585201868363*^9}, {3.644585409788192*^9, 3.644585435218499*^9}, 
   3.644586406127926*^9, 3.644598056429336*^9, {3.6569741460690603`*^9, 
   3.65697415907928*^9}, 3.656974827319139*^9, 3.6569749001614523`*^9, 
   3.7261572842700768`*^9},ExpressionUUID->"b2095047-0ea2-4171-baa7-\
7af9d8343feb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Positron Direct Spectrum of Final State ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.3"}], TraditionalForm]],
  ExpressionUUID->"8e2cf91e-a63d-48c0-b586-f6ea79ef0d1d"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.639076412252461*^9, 
  3.639076429227652*^9}, {3.639076546090394*^9, 
  3.6390765590298443`*^9}},ExpressionUUID->"3d078262-5ed0-4d5a-ae7e-\
6de0c6f07a8b"],

Cell[TextData[{
 "In this example we load the 0-step positron spectrum for a DM annihilation \
proceeding directly  into ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.3"}], TraditionalForm]],
  ExpressionUUID->"672309eb-1f18-4a54-8dd0-ce904bdc8d5b"],
 ". For other final states, replace the 14 in the flux row with: 5 \
(electrons), 8 (muons), 11 (taus), 14 (",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks), 18 (",
 StyleBox["W",
  FontSlant->"Italic"],
 " bosons), 22 (gluons), 23 (photons) or 24 (Higgs).\nNote for certain direct \
spectra, like the positron spectrum from final state electrons, or the photon \
spectrum from final state photons, the spectrum is actually a Dirac \
\[Delta]-function and it may often be easier to just use this analytic \
expression."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.644598060861582*^9, 3.6445981089747334`*^9}, {3.6445982623169527`*^9, 
   3.6445983408554983`*^9}, 3.656974193760705*^9, {3.656974233478744*^9, 
   3.6569743216982307`*^9}},ExpressionUUID->"37bc1077-7933-4ac8-b51e-\
0fdb159f0e9b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "mf", ",", "mass", ",", "xval", ",", "flux", 
   ",", "loadspec", ",", "dNdx0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/AtProduction_positrons.dat\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mf", "=", "4.18"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mass", "=", 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"in", " ", "GeV"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xval", "=", 
    RowBox[{"10", "^", 
     RowBox[{"(", 
      RowBox[{"load", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"2", ";;", 
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
      ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"x", " ", "=", " ", 
    RowBox[{"E", "/", "M"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xval"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "14"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"mass", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xval", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx0", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"loadspec", "[", 
         RowBox[{
          FractionBox["mf", "\[Epsilon]"], ",", "x"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["x", "2"], 
     RowBox[{"dNdx0", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.07"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Darker", "[", "Gray", "]"}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", "\"\<n=0\>\"", "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.639076588298305*^9, 3.639076666827195*^9}, {
   3.6445840003231363`*^9, 3.6445840120261393`*^9}, {3.6445851269240093`*^9, 
   3.64458514902188*^9}, 3.644586384478674*^9, 3.656974862833619*^9, 
   3.656974915776977*^9, {3.6569800476470346`*^9, 
   3.656980047766233*^9}},ExpressionUUID->"1c4ae216-afd0-4fdb-bbc4-\
5a8e6a326263"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
          0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`]], 
         
         LineBox[CompressedData["
1:eJwVlnc8V98fx+29997jg0hKZucYKSNCEjILWUlKUZRKFEKyyR6ZKdHCfUsK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          "]], 
         LineBox[{{0.004435848449543597, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$13221#1"]& ], {}}, {{}, {}, {}}}, {}, {}}, {
    Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.059898924253009626`}}, {{-13.815510274069974`, 
        0.09530989591002416}, {0., 0.059898924253009626`}}}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.07}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.07}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"n=0\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                 RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.22222222222222227`, 0.22222222222222227`, 
                    0.22222222222222227`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.33333333333333337, 0.33333333333333337, \
0.33333333333333337]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.33333333333333337`, 0.33333333333333337`, 
                   0.33333333333333337`], Editable -> False, Selectable -> 
                  False]}], "]"}], "}"}], ",", 
           RowBox[{"{", #, "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.639076611805574*^9, 3.6390766683190613`*^9}, 
   3.6390767190461483`*^9, {3.6445839842947693`*^9, 3.644584014261587*^9}, 
   3.644586407561598*^9, 3.656974333286442*^9, 3.6569748645354233`*^9, 
   3.656974917386509*^9, 3.656980049533836*^9, 
   3.7261572863106117`*^9},ExpressionUUID->"57fc1499-099a-47b1-b160-\
ec82b890d272"]
}, Open  ]],

Cell[TextData[{
 "NB: recall \[Epsilon]=mf/",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Chi]"], TraditionalForm]],ExpressionUUID->
  "b37a3e00-4e3b-4acb-999b-dc6d849299f1"],
 ", so above when we specified \[Epsilon] and subbed in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"mf", "/", "\[Epsilon]"}], TraditionalForm]],ExpressionUUID->
  "a6951e9e-a248-4f53-97c3-d1ba72776ea6"],
 ", we could equally well have specified ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Chi]"], TraditionalForm]],ExpressionUUID->
  "ba36a67f-130d-4864-8d3a-27153bd6ad86"],
 " and subbed it in. An example of this is shown below"
}], "Text",
 CellChangeTimes->{{3.656974350305602*^9, 
  3.656974455523155*^9}},ExpressionUUID->"2792ed7b-95db-4dc7-8bd4-\
3bd092109799"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Photon Direct Spectrum of Final State gluons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "\[Chi]"], "=", "25"}], TraditionalForm]],
  ExpressionUUID->"e361c597-0d76-49c8-bca6-954f9fc5960a"],
 " GeV"
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.639076412252461*^9, 
  3.639076429227652*^9}, {3.639076546090394*^9, 3.6390765590298443`*^9}, {
  3.656974478721797*^9, 3.656974493337208*^9}, {3.656974618027175*^9, 
  3.656974622130679*^9}},ExpressionUUID->"673ad48c-d40c-437a-b13a-\
8002f2e2295f"],

Cell[TextData[{
 "In this example we load the 0-step photon spectrum for a DM annihilation \
proceeding directly  into gluons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "\[Chi]"], "=", "25"}], TraditionalForm]],
  ExpressionUUID->"859db0c1-fc5f-42cd-86d6-1e534dcada72"],
 " GeV. This is an alternative to loading via specifying \[Epsilon] or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Phi]"], TraditionalForm]],ExpressionUUID->
  "ef9f65d2-75a6-4a5e-acb7-f87c65d4e660"],
 " (the latter being appropriate for gluons). Note for a direct spectrum ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "\[Phi]"], "=", 
    RowBox[{"2", 
     SubscriptBox["m", "\[Chi]"]}]}], TraditionalForm]],ExpressionUUID->
  "31dd7de3-4e3d-4131-9040-c1d8b1e55c17"],
 ", so specifying one fixes the other. See the previous example for further \
details."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.644598060861582*^9, 3.6445981089747334`*^9}, {3.6445982623169527`*^9, 
   3.6445983408554983`*^9}, 3.656974193760705*^9, {3.656974233478744*^9, 
   3.6569743216982307`*^9}, {3.656974466867167*^9, 3.656974473993824*^9}, {
   3.656974505592162*^9, 3.656974570188876*^9}, {3.656974608285205*^9, 
   3.656974615178609*^9}},ExpressionUUID->"1c102689-3ccd-4f6a-8a2f-\
44bf00185d46"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "mf", ",", "mass", ",", "xval", ",", "flux", 
   ",", "loadspec", ",", "dNdx0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/AtProduction_gammas.dat\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m\[Chi]", "=", "25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mass", "=", 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"in", " ", "GeV"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xval", "=", 
    RowBox[{"10", "^", 
     RowBox[{"(", 
      RowBox[{"load", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"2", ";;", 
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
      ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"x", " ", "=", " ", 
    RowBox[{"E", "/", "M"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xval"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "22"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"mass", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xval", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx0", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"loadspec", "[", 
         RowBox[{"m\[Chi]", ",", "x"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["x", "2"], 
     RowBox[{"dNdx0", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.25"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Darker", "[", "Gray", "]"}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", "\"\<n=0\>\"", "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.639076588298305*^9, 3.639076666827195*^9}, {
   3.6445840003231363`*^9, 3.6445840120261393`*^9}, {3.6445851269240093`*^9, 
   3.64458514902188*^9}, 3.644586384478674*^9, {3.656974575860723*^9, 
   3.6569746061487617`*^9}, {3.656974644414455*^9, 3.656974675490058*^9}, {
   3.656974854999372*^9, 3.656974855427026*^9}, {3.65697490323083*^9, 
   3.6569749048837137`*^9}, {3.6569800420167007`*^9, 
   3.656980042142832*^9}},ExpressionUUID->"149ae7aa-78df-4225-84af-\
78dc3e18f432"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
          0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`]], 
         
         LineBox[{{-13.815510274069974`, 0.}, {-13.81124385995431, 
          0.}, {-13.806977445838644`, 0.}, {-13.798444617607313`, 
          0.}, {-13.78137896114465, 0.}, {-13.747247648219329`, 
          0.}, {-13.678985022368682`, 0.}, {-13.674718608253016`, 
          0.}, {-13.67045219413735, 0.}, {-13.66191936590602, 
          0.}, {-13.644853709443359`, 0.}, {-13.610722396518035`, 
          0.}, {-13.60645598240237, 0.}, {-13.602189568286704`, 
          0.}, {-13.593656740055374`, 0.}, {-13.58939032593971, 0.}}], 
         LineBox[CompressedData["
1:eJxFkosvFAAcx+24ke2SRcnr1Fr0SxEq4VdEqCRdXZLzOHfnlFcvkVJiGLOG
5RGHIk7Krukhj/hJ51KLmrTe3Y1JkZgOo5G2tr7bZ58/4PNdGRbLETE0NDRg
gb8uk/s+DBkH0vi34wXOwe9+AjlG8Z1r+XMu0pQM9rkfQA2C4sUlt8zwc0yv
0nQYKFLxbZVeEaCPV6QgdBBo5lP6RLChE6baN6xmDADV1IqtVYmu2MTWHKxU
AZmxNoyI9D3Qaro44utHoNuJpelJ0j0YMjC4NvM90I2K1if51/dhwUu7YXgL
1Odhk5P6YT9q3XwWHdMLtJlp6OW29BCqAmZOqruAukpKjyr6gtHI09OhUAFk
q/Txi0wLRT+7PLWjHKjy8UAVt4yPrbqQcJ6AXtz/IZPJBaiejNtq3gok7Ujm
LX8lROv+9pm2ZqCOX2fHel6LUNDDauE3AmU6jXYY94RjcXNAkmYDkLlLwSKL
VjG+klZtq7oHJLzPmZKtjUCdK+PznvVAbezTj4Jmxbg9GduHZEAT4wq3yQdi
PBOVmZJVB3Ssy167hSfGusN97ta3gBjTgSFzI+E44LGS2V0D9L7HaIlxRDia
bIzujK0G4rpqzp/tFiHHrDFD/wbQQdbu/kILEWYuYu66ex2onsuY+x0sRFL7
6XLLgTblW77bkSXAKZXk+aQEKL87mWVQGYYbuoeyi4qBCg0r9NbX8lHU5ODr
VATE8XLXCroWipLqZL2P+UCiNh9HFisEdS8a5bFzgdS8nWtO7D2CbpHCA+2X
gSjX+5RS7o8J/ncMBNlAUTZXmVqWXBy08S6szljoFW/C4PH2oZnplcPeaUBP
h8embe/twoM6yhXfU4DS1wXWaKvdsUMZL1l/Aah83mB0i8QWrSzSsqbOAV36
cjRnVr4M4+o73+xI/P/HP0MaO4o=
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQLcP/YzKvndYBBiho8GNtum6N4D/pFSpYaInge5yV
j8s2R/DX8Oj6mJoi+AI+Vlb/jRD8G6dCxCbrIfiZJzrP7VJF8LsOf7bjEkHw
z+w8Lr/ygyacn/e0XKPuHYIvKKhhGPwGwQ/L6HD6+xzBfyDmmRp4H8H/Unxq
1c+zCL6M3llTr9UIfs6iS96vUxF8N+VUwezzGnB+ar4P+zcnBP+bVpfmVAcE
v+PZcW8TOwR/VazzhCJLBP+Dt5Xke30Ev4m9wrpPF8EHAHa3WGg=
          "]], 
         LineBox[CompressedData["
1:eJwtl3c4V+//x+2RhpG9394DpQhRnHNbFYpEn9KQEaKEZFWKzIzskFAyk6Ls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          "]], 
         LineBox[{{0.004435848449543597, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$13808#1"]& ], {}}, {{}, {}, {}}}, {}, {}}, {
    Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 
        0.09530989591002416}, {-1.1129817557349512`*^-13, 
        0.20130980826428754`}}, {{-13.815510274069974`, 
        0.09530989591002416}, {0., 0.20130980826428754`}}}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.25}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.25}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"n=0\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                 RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.22222222222222227`, 0.22222222222222227`, 
                    0.22222222222222227`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.33333333333333337, 0.33333333333333337, \
0.33333333333333337]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.33333333333333337`, 0.33333333333333337`, 
                   0.33333333333333337`], Editable -> False, Selectable -> 
                  False]}], "]"}], "}"}], ",", 
           RowBox[{"{", #, "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.639076611805574*^9, 3.6390766683190613`*^9}, 
   3.6390767190461483`*^9, {3.6445839842947693`*^9, 3.644584014261587*^9}, 
   3.644586407561598*^9, 3.656974333286442*^9, {3.656974662384239*^9, 
   3.65697467701595*^9}, 3.656974857335136*^9, 3.6569749073246927`*^9, 
   3.656980043778796*^9, 
   3.726157287979579*^9},ExpressionUUID->"eec8ae7b-fbf8-442b-b889-\
ca217feb859e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "e"], TraditionalForm]],ExpressionUUID->
  "dbe25c11-4bee-4ce5-b4f1-1adf3ff2c8e1"],
 " Cascade Spectra of Final State ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"2e06a854-c30f-4817-993e-43c5358e864a"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.725895997927475*^9, 
  3.7258960182383738`*^9}},ExpressionUUID->"8f94fea6-5425-446e-b8d4-\
f5e6ec68fc92"],

Cell[TextData[{
 "In this example we load the nue spectrums of 1-6 step cascade DM \
annihilations terminating in ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"33f02373-9a72-4dad-8d82-dd0a25741be3"],
 "."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.6569740152601748`*^9, 3.6569740215851297`*^9}, 3.6569741348752193`*^9, {
   3.7258960226274014`*^9, 
   3.725896033581571*^9}},ExpressionUUID->"253067c7-4248-4aca-8eb7-\
095df4447504"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "\[Epsilon]vals", ",", "\[Epsilon]", ",", 
   "xvals", ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3",
    ",", "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_B_nue.dat\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, 3.644257377150648*^9, {3.644257434361697*^9, 
   3.644257640256255*^9}, {3.644257707534048*^9, 3.644257735875279*^9}, {
   3.6442600032445927`*^9, 3.644260076895362*^9}, {3.6442601126335287`*^9, 
   3.644260125127042*^9}, {3.644260206635504*^9, 3.644260216755534*^9}, {
   3.644260257841144*^9, 3.644260300439433*^9}, {3.644576371341427*^9, 
   3.644576438767619*^9}, {3.644576479640806*^9, 3.644576479920644*^9}, {
   3.64457654220582*^9, 3.644576615392721*^9}, {3.644576776040201*^9, 
   3.6445767991854687`*^9}, {3.644576834719887*^9, 3.6445768523652887`*^9}, {
   3.6445769381615953`*^9, 3.644576938607382*^9}, {3.6445771076003437`*^9, 
   3.644577147245116*^9}, {3.644577743925811*^9, 3.6445777948429527`*^9}, {
   3.644578047110093*^9, 3.644578096858204*^9}, {3.6445782810736*^9, 
   3.6445783067921886`*^9}, {3.6445783514558153`*^9, 3.644578351709989*^9}, {
   3.644580871103026*^9, 3.6445809542044983`*^9}, {3.644583694406518*^9, 
   3.6445836945720377`*^9}, {3.64458372703931*^9, 3.6445837383126783`*^9}, {
   3.64458377711351*^9, 3.644583837531001*^9}, {3.6445838746916313`*^9, 
   3.6445839220568733`*^9}, {3.644585052730834*^9, 3.6445851006510973`*^9}, {
   3.644585166144863*^9, 3.6445851833791313`*^9}, 3.6445863844322357`*^9, {
   3.644597848860992*^9, 3.644597868618737*^9}, {3.644597923287142*^9, 
   3.644597929359888*^9}, 3.656974933701758*^9, {3.656980023633141*^9, 
   3.656980023762002*^9}, {3.725896123119398*^9, 3.725896124813836*^9}, 
   3.725896175201226*^9},ExpressionUUID->"532e6a49-4a35-4ab8-a8c6-\
e25712d4f65b"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwdlnk4Vd/3x00ZMl3zPN17TVdkzHy2VAiJDElCAyFRZqIkSZIUmTPfa4iP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          "]], 
         LineBox[{{0.004435848449543578, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$14400#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwdlnc8le//x0XZ45xj72M7R0Qps/sSiRJZSRlJhFKIQpFVMhoqSpLCQUQy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          "]], 
         LineBox[{{0.004435848449546493, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$14400#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwdl3c8lf/7x0mSFeccq2yOcYjKiKL7bRMZycfO3mkRUaRSdlahKOucMlKR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          "]], 
         LineBox[{{-0.22582266087696415`, 0.}, {-0.21880456020282513`, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.11956510309924583`, 0.}}], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA2zSDL2dWvL8HkEVTDu6BPogpLThR
77q/vOwwPi9OlD6lACyCh324v6gByGJBK6Q+NGwrp6JEt7+kflS/VyCpPsLX
Ksy9C7a/8xvc5Tf4rT5QQyrx2NK0v0LSU6MbUbE+364pFvSZs7+UnuKoToaz
Pm4aKTsPYbK/JM+/EEyStT78hShgKiixv+KKKGAYa7c+FONPCover78N95mD
Hwa5PjG6TlTBbK2/qWCNiC5Yuj5OkU2e9/qqv43AISBtVbs+amhM6C2JqL+d
zP/oVvG7Poc/SzJkF6a/jUG5frQevD6kFkp8mqWjvw8w10yUz7s+we1IxtAz
ob9x3b0jQ/W6PryJjyAOhJ2/STB/jUSAuT72N420eqCYv9eppuBKYLc+MOaK
SOe8k7+wk/sOL4S0PtQoEbmnso2/i0snLujZsD5IhQzhgOuDv6jfPHAFnag+
d8MPErRIdL+liXAEXjibPhInVQBTK3K/5VfHp/CYmD7R8LhE
          "]], 
         LineBox[{{0.00443584844954651, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$14400#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwVl3c8198Xx0lIZH4+VmWvD9Eis/eRTUglKxkZIYomslpWKiI74WNEm29W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          "]], 
         LineBox[{{-0.2126328996767897, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.34095191550393816`, 0.}, {-0.33428277380397264`, 
          0.}, {-0.3300058029298561, 0.}, {-0.32572883205573955`, 
          0.}, {-0.32145186118162294`, 0.}, {-0.3128979194333898, 
          0.}, {-0.30862094855927324`, 0.}, {-0.30434397768515664`, 
          0.}, {-0.2957900359369235, 0.}, {-0.2786821524404572, 
          0.}, {-0.27440518156634064`, 0.}, {-0.27012821069222404`, 
          0.}, {-0.2615742689439909, 0.}, {-0.24446638544752458`, 
          0.}, {-0.22150459657587682`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$14400#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwVl3c81e/7x83s7HOM7GMdUZKsvu/LCEVmKqTICgkppSWlzIq0kMQ5lZHK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          "]], 
         LineBox[{{-0.3392531333116301, 0.}, {-0.3300058029298561, 
          0.}, {-0.3128979194333898, 0.}, {-0.2786821524404572, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.4560811701545825, 0.}, {-0.44976098740512027`, 
          0.}, {-0.44548401653100367`, 0.}, {-0.4412070456568871, 
          0.}, {-0.43265310390865397`, 0.}, {-0.41554522041218767`, 
          0.}, {-0.41126824953807106`, 0.}, {-0.4069912786639545, 
          0.}, {-0.39843733691572136`, 0.}, {-0.38132945341925506`, 
          0.}, {-0.34812483021071716`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$14400#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVlnc81f8Xx82MCIV7LxnhmlEZWfU5IjPJHpEQkkhRUhGVkFFI2eNeTZRS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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQ3REZMZ/17cP9DFCwpYZrceXPe3D+mp6OHWmbEfyl
c9jOBeci+NP2MP3UfXgXzq/488vv0Yk7cL5NzetfXjNuwfmHq88EyZhfQ5j3
VYa17uUpOD9n9Zzp3L4IvkmijNbMDSfh/ENnpP23lJ+A8+8vlpr5ivUYnC8Z
JKEbrnQQzjfc5RdyMGctnO830Xfe91+r4PysDJ8Xup0r4PwlYl41s5YuhvMN
nnV5PN8zGc6faBLKEKxdBOcDAOuPWr4=
          "]], 
         LineBox[{{-0.6863396858154165, 0.}, {-0.681066414329966, 
          0.}, {-0.6764829338664331, 0.}, {-0.6673159729393673, 
          0.}, {-0.6627324924758344, 0.}, {-0.6581490120123015, 
          0.}, {-0.6489820510852358, 0.}, {-0.6306481292311044, 
          0.}, {-0.6260646487675715, 0.}, {-0.6214811683040387, 
          0.}, {-0.612314207376973, 0.}, {-0.5939802855228415, 
          0.}, {-0.5690550419507858, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$14400#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.043247171786663804`}}, {{-13.815510274069974`, 
        0.09530989591002416}, {0., 0.043247171786663804`}}}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.1}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.1}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, 
   3.6390767166598787`*^9, {3.6442574366310177`*^9, 3.644257640914957*^9}, {
   3.644257708990077*^9, 3.6442577371366043`*^9}, {3.644260004751333*^9, 
   3.644260077952415*^9}, {3.644260115987558*^9, 3.644260126350301*^9}, {
   3.644260188124305*^9, 3.644260218133224*^9}, {3.6442602591886263`*^9, 
   3.644260302050921*^9}, 3.644316648114072*^9, 3.644576451074027*^9, 
   3.644576487542392*^9, {3.644576549658166*^9, 3.644576621616087*^9}, {
   3.644576764562796*^9, 3.6445767820862637`*^9}, 3.6445768574554853`*^9, 
   3.644576945003827*^9, {3.644577113369245*^9, 3.644577140083241*^9}, {
   3.644577753012301*^9, 3.644577802627615*^9}, {3.6445780569311028`*^9, 
   3.644578103866412*^9}, {3.644578289753704*^9, 3.644578315580659*^9}, 
   3.6445783615710917`*^9, {3.644580938831132*^9, 3.644580960697556*^9}, {
   3.644583691767996*^9, 3.644583700885569*^9}, 3.6445837471615887`*^9, 
   3.644583847010324*^9, 3.644583892827443*^9, 3.644583928512251*^9, 
   3.644585111858407*^9, {3.644585173229665*^9, 3.64458519082297*^9}, 
   3.644585513469898*^9, 3.6445863990953827`*^9, 3.644597859482862*^9, 
   3.64459793577026*^9, 3.6569749437404423`*^9, 3.6569800300558558`*^9, 
   3.7258961352719097`*^9, {3.7258961730712137`*^9, 3.725896176681426*^9}, 
   3.726157289706244*^9},ExpressionUUID->"63b7eb60-4864-4d45-a81b-\
aaa053a936a6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "\[Mu]"], TraditionalForm]],ExpressionUUID->
  "5b5290d7-3fa3-449e-a6bb-7b70354637ca"],
 " Cascade Spectra of Final State ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"78ef26cf-ac80-46c7-871a-689e2c297499"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.725895997927475*^9, 
  3.7258960182383738`*^9}, {3.72589615227571*^9, 
  3.72589615252754*^9}},ExpressionUUID->"2b087bd4-a0d5-4b80-b051-\
04c3b5272272"],

Cell[TextData[{
 "In this example we load the numu spectrums of 1-6 step cascade DM \
annihilations terminating in ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"06966182-5cdb-484b-be93-d7ea75b70146"],
 ". Note that, as expected, there are more muon neutrinos, because charged \
pions produce two muon neutrinos for every electron neutrino produced."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.6569740152601748`*^9, 3.6569740215851297`*^9}, 3.6569741348752193`*^9, {
   3.7258960226274014`*^9, 3.725896033581571*^9}, {3.725896206328569*^9, 
   3.7258962401454277`*^9}},ExpressionUUID->"32b45602-0eee-4cac-90e5-\
86f0280f8081"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "\[Epsilon]vals", ",", "\[Epsilon]", ",", 
   "xvals", ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3",
    ",", "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_B_numu.dat\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, 3.644257377150648*^9, {3.644257434361697*^9, 
   3.644257640256255*^9}, {3.644257707534048*^9, 3.644257735875279*^9}, {
   3.6442600032445927`*^9, 3.644260076895362*^9}, {3.6442601126335287`*^9, 
   3.644260125127042*^9}, {3.644260206635504*^9, 3.644260216755534*^9}, {
   3.644260257841144*^9, 3.644260300439433*^9}, {3.644576371341427*^9, 
   3.644576438767619*^9}, {3.644576479640806*^9, 3.644576479920644*^9}, {
   3.64457654220582*^9, 3.644576615392721*^9}, {3.644576776040201*^9, 
   3.6445767991854687`*^9}, {3.644576834719887*^9, 3.6445768523652887`*^9}, {
   3.6445769381615953`*^9, 3.644576938607382*^9}, {3.6445771076003437`*^9, 
   3.644577147245116*^9}, {3.644577743925811*^9, 3.6445777948429527`*^9}, {
   3.644578047110093*^9, 3.644578096858204*^9}, {3.6445782810736*^9, 
   3.6445783067921886`*^9}, {3.6445783514558153`*^9, 3.644578351709989*^9}, {
   3.644580871103026*^9, 3.6445809542044983`*^9}, {3.644583694406518*^9, 
   3.6445836945720377`*^9}, {3.64458372703931*^9, 3.6445837383126783`*^9}, {
   3.64458377711351*^9, 3.644583837531001*^9}, {3.6445838746916313`*^9, 
   3.6445839220568733`*^9}, {3.644585052730834*^9, 3.6445851006510973`*^9}, {
   3.644585166144863*^9, 3.6445851833791313`*^9}, 3.6445863844322357`*^9, {
   3.644597848860992*^9, 3.644597868618737*^9}, {3.644597923287142*^9, 
   3.644597929359888*^9}, 3.656974933701758*^9, {3.656980023633141*^9, 
   3.656980023762002*^9}, {3.725896123119398*^9, 3.725896124813836*^9}, {
   3.725896165850692*^9, 3.7258961662792797`*^9}, 
   3.725896199962973*^9},ExpressionUUID->"44eeced5-73f2-4ab2-aeee-\
d972455c02ab"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwdl3c81d//wJWyxzWyt4t7iSgzeh9EiUgIKSuUGYmsEiWkCCkyQ2ZCxg3J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          "]], 
         LineBox[{{0.004435848449543562, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15038#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwdlnc8lt//x2kYUe7bjrLXbZUiCtexksyMpJKVmZEPErJCZkWSrJIIiRT3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          "]], 
         LineBox[{{0.004435848449546452, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15038#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwdlnc8lv/3x0mLZNy3VbI3H4oI0XUkKjNJUpGRTWVmRIgklKISiUrIqIw7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          "]], 
         LineBox[{{-0.22582266087696415`, 0.}, {-0.21880456020282513`, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.11956510309924583`, 0.}}], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA2zSDL2dWvL8HkEVTDu6BPogpLThR
77q/vOwwPi9OlD6lACyCh324v6gByGJBK6Q+NGwrp6JEt7+kflS/VyCpPsLX
Ksy9C7a/8xvc5Tf4rT5QQyrx2NK0v0LSU6MbUbE+364pFvSZs7+UnuKoToaz
Pm4aKTsPYbK/JM+/EEyStT78hShgKiixv+KKKGAYa7c+FONPCover78N95mD
Hwa5PjG6TlTBbK2/qWCNiC5Yuj5OkU2e9/qqv43AISBtVbs+amhM6C2JqL+d
zP/oVvG7Poc/SzJkF6a/jUG5frQevD6kFkp8mqWjvw8w10yUz7s+we1IxtAz
ob9x3b0jQ/W6PryJjyAOhJ2/STB/jUSAuT72N420eqCYv9eppuBKYLc+MOaK
SOe8k7+wk/sOL4S0PtQoEbmnso2/i0snLujZsD5IhQzhgOuDv6jfPHAFnag+
d8MPErRIdL+liXAEXjibPhInVQBTK3K/5VfHp/CYmD7R8LhE
          "]], 
         LineBox[{{0.00443584844954651, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15038#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwdlnc8lv/3x42URNZ9G0n2Lh8VUXQdm4hkK4WiKLQQIkrZZYVkRbIL961B
6jqFSEYhqZSRkcjKTvrd398/1/V4Pq73POe8XteROHbG0o2FiYnpFOPxv7fv
kfXx0TlKqHHySudTlyFiv9LkocPZSrilNXvD8/AhQnKpU2ZrphLGhCtwMpUO
Ea237j5rua2ENp7+EvoLQ4Rss/oIT7wSPr99CN/FDxPde04QqZeVMPLjZauj
70aIPUK14/cOK6GTFUYbXvtJ8AwXPvFxUEI605fXCxU/iWH6zasGdkooZM6l
Md/7k0g8cEhoxFIJ0xRSWnq0xoix8Gk9RRMl/FJm4+G0PEZkzImll2sw9utV
Ki6/9ov41x607zlVCZ0X7RsmPaeIXWQjhxO/EiZnl9y5FDNFeJdQmpl4lbB3
MU8WiqeInrBSc31OJZQSlvrn/WOKeKraY/WWRQlDRcR7gk5OE2dTNI9+mlTE
9+FbKwrPzhD9Dsvn594oohbr8to3FbOEkKGhamqDInqt9VPl7Z4lLHYkzmnU
K2Lv5ZOtWauzxAsORf8gVMRfBuWKsfvniDvPHIJZnyhiXAoXvWZsjrAUrYrg
zVPE3w86aXnqC0Rt38WMbZcV8XiS6AMhjmVCXvx69MIlRRwS/XPv3a5lItYp
0f9lgCLa+azNaTu+TFh/K7W28VXEhb1vtAteLBODX/o5gz0V8eEN1TMTF/8Q
az+aBjcfUkTKDn61g0srhHGL2NHT6oooHh/S4y/KBKWc2/arqSni561+AUsa
TMCzf8+efzsUUTJ0y2iBNRN0N1kLJCkrIlIEAuNimcCjMaq1WkYRA2W1WBJX
mSC69jfBQVFEm4UKxeIxZmiuahArmlLArfFt5oLjrOA9dFH+8oQCsmwSv67J
tQZ4eeW3W40roKXPveRk5TVg6x6p+3dEAT8v5ueNn1sDfQL73A72KmC9Wb6I
yp81MHuhqXipRQHTZsrOOgithc3KLWomJQoYx2rgrhLCDi8cggmxIgU8GEcr
rSxgB5fr24xm8xnrVcg7Bb5jh/yeG/ZZuQrYfmy8+K3kelCJMb80k6aAZazW
EglN60H/RxveiVTAdW/2lA/KbgDP3HbTMTcFjIn8LpBP3Qhnx3+YJBxXwNe7
zFgPmm6EC7v+7VN3UcC3dgXGDlc2QmCTknGYowL+lFmEaxMbIWLmmr6IlQJu
qvS2PdDCDbm66ntNtRVwDeeSzqVWHvg0kK5cskkBHZNrt9nW80HPVtq2g0IK
GDp9TTdlmA/6/Bq3LlAVcGpK6SYHOz8Mc8wp6vEqYFFc8ttsU36Y3WEu92Wd
Aj4iK/+L/MAPPGFM4hvm5HHz0KsfJbMUMJRy4z3dJo++lRy8PccEwQ+19u5u
kUc2G8vJXVGCUHCE4rHurTzySe/vby0TBPbbtXjvtTw2XemMffJXEJo4Jc/2
PJfH71f/9fhlCIH5/LdWs1J5vJ+5sMw6LAy2b+xjVaLkUcDwxNGrJZsh/ITK
09VweczlvBOh+nkzPGFlH2y+Jo+ttLYIlfWiIEQ80fQIlUdWsTWf17mLwmca
dSznojyO8LJbaitsgaMZ7fv4T8jjDc+ZEuVqMXA7s3/dvK48ko+uhZrHSsC8
YrRCsrY8+knYUHhLJCByuMFUlZDHIs3lyXVNElB8RC/+/G553Ocw15zELglT
pnuEJ/+TR7G4GaltkZIQJC+v9GOzPD7q+7p0NkEKEvtZD3yel8Mu7X2Wd9pk
QDpT51zArBwuH9usEDEnA4/sQ5KEZuTQ5H3oYZqILHS3LX+0/SWHBp071jxx
lwXRF9POHd/lcHJha28TmxwU3uk93/xODpMbruaH7peHF1bPUl4Uy2GHTtn6
2Y1KcPNPeod7oRwOP6+MpWkpwdF7QTz8+XJ4Uvhh8rNTSvB3Zm/0yRw5VPyz
uK2sQQm0EjGY57YcTggnSChe3wrV7+pdj12Xw9WT5bpfNirDY7N3O9Y6y6FT
uKfd5zIVCJ8rP1N+RA4L2Y+qvX+rAraZCaWHDsthUuVdmBtRgblxS9kyWzk8
IFwxWy++HVRjPwjbm8lhemRXdMKt7UBr+sxUvIfBXyzuTl/bAQ+MhlrNqHJ4
Kf4j57toVSjWjdAQ55dDi8MJ2neLVSF/r0LuDI8cKnAnvs9uUoW7O718Uznl
0O9n4BrlDWpwS2xOpJ9VDmFmJDT0phoELqzx8JmRxXOuNduUsnaBcYE0a3qb
LFL+Hjt4dVADDHJfe3q1yGJh4bWgxxy7QTfTvQveyuKXG/Iu4tt3g2ZSadHg
a1nsSRFVjLq8G5RDVC2UX8hi9deGL2yb9wDVTj/zZSljPnnfb8lFEwbWuqr/
iGKsv4l757wIAdrinqkxEbIovH7t2WgzArJ2+ywoX5fFieQTfp4hBDh4Xnvi
GyqLMx3jwyKDBLx7n6fOelEWnw0MhuyqAHiRMaS+xVUWt51gpbo90Ia0HSc1
rAlZ7HcT+/rbTxfmTc/cXtCUxSDW7lPsybpg7XZx8c5uWdy8S67alK4LPLcj
nvaryqJ5pfYLpyldCP9boHFGSRZBPFy83lMPfBp/aEQLyeK+Z6flHnnrg8XR
U7txRgZjJ3vsg24bwpemna9jpmQQnu0/51dtCCfU/1raTchgd2/g1pweQ7jE
E+85MSqDPVe4Q6MkjCD/1aPszf0yaBrxirf0gRH8lWVeG9Amgx9uYxJLmzEU
T6a2by+VwYmizdnOu01BzdHF6W+RDK7xv+P61cUUsFFxvLFABh9QlOSSok3h
Q85zNud7MsjwYpnsHlNgsv6ucfOODC5m1cvphO0Hu6fK2T8jZfBA/VXejC9m
sOZK/el7bjI4/T4o7/QRC2j5tJ0/8LgMZi76+M77WEDKjqxqCxcZPOf/mjcn
1gLkB/3WrzrKYIPMpVO2NRZgZiRfYG8tg4fE+usNRQ9CClfMAJeeDJJ6iQkn
hg6Cwh0LB39xGSw+mEYNiLOCmZkapgNbZNCIm2feoMQKakwVCmU2y2DV/Zzf
6g1WYP6XeaFdUAbXCggLxf6zgvPO9FvbuGVwcPehB8vnrKFGVuDdwF9pTBPn
s9l81AbM6V8Mzb5IY8dHw3t/rezAX/Hh4Gy3NJYSt4OvX7SD3JzQqxld0ljH
ZCqpnW4H83EyL8beS2PeGfNR8+92kOV5Ri26URoLHnIwf/a1h0kZVumGR9II
IkuXavMcIP62IrNOvDTW79+kvKLoCNXcf7N+3JBGy/yRQ/tsHGEwvE0rPkYa
7zR2jb8PcQQNXx//3nBp5K/3NU/54Ah9B19MBgdL4xZpEZ3xsCOwfYPlt+pT
0vg1UCLv3NhRaA8OeKZqII0bu06oHZlzBgVjrvA1etJYlH6Yt47TBUL5ciw6
tRnjOSx690q7gHJB49AFLWncEWTxMNrKBWLeCfLQd0oj01Ox+Rt0F9CXeuy6
XVIal5++4XAJOAaPG2e4lP9J4SWftotrRV2BKym8+++KFK4NZqZZaLiC65FN
91qWGbz50ESNlSvwzehoeM1LYUsMi8pKtCucEUk4VvpLCrnv+XKK/HEFee//
nij2SCHvm/uXmAfcIJ3f01muSgq9Dlzob2w6CdYrbhKNj6VwNCy/QOvXSeAc
chpwr5TC85c4dL9xu0PQYyvX4jIp1P1t8LvExh0cHTTdt+VLod4bk7mL391h
czbH2Z1JUrhJgy2Rmf0UZCgWhYCXFKp84ufJ9vEEa/572n2npFD2/evnIpme
wLmSwXzFXQpv9dYptdR7QlBLfNir41L47FGEVJugFzie9Y8wOCSFP44Gt1m/
8ALRx0ZxpkZSaD8Vx9FAOQNZOsNZdhJSaFX4ULVz7izcEggLZBWTwtzQ1iEK
1zmIGROzLdsshQbmRxzOS58D/2QHrnVCUjhcO+ntanUODo42X3q8UQo7S08M
Z9POwZoEuj11RRJFL/fdzfU7D6f7Qvk6uiSxLE/V0pfqA8ceiU5c7pTEV4my
u11UfMA+uvqNYrskrpmpt/Iy9QF91dnQqy2SuOLeOzB8xQe2RJ6c3F4niV0B
R9xdp3yg/T/z5vgKSfy54p5a2uELGiEi4eaxknjtSUa3FP0iOBYE3JSMlsQY
X7VWuXcXIaTtY8p8hCT+ruK6YvrrIrwWu1WQFSaJW10fF87I+YM1cr6ZCJTE
Wjkjr9osfzjLvLohzkMS+Quiuk8lBkBhWF9Cm6EkWiT9Prg34RI0lxB37ulL
ImF60NmcdgkmOzJyL+pKIhyDnKsdl2CXtANdjJBE5xSUsREIgrq6951n1CQx
UiwnPi8zCPrYagV5pP93398vdWjBIBh5P9OCWRIPteyI8J4PgYxWj4y5VQlM
emv3J547FMSpyul3ViRQ5+mfI8zSoSCf+/j24IIEjroZ7pU1C4U9NQ1J/hMS
iLe17fXuhsKRqdGou18kMI0Hn901uQL37JX9ph5JoDTXa1aOiqvwn8IT8/hT
ElgtwNawt/469L3SCjziLoE3/ngcffr1OiQ6vrqveEICy0rfupjMX4fZuJaV
OhcJrHTvFHkkFw7V89+Ll+wl8Gy55brCmHAwrONZd9xIAu1yL37ntY+Ao06n
SDVpCez8JSCuyxwFN5JFVb58Fcd/qB9mmxELd83WWwZ8Eccss7ePjzyPBRrb
3AXBT+LY8Mr7+rVvsdDl2/zEqlMcvfIqRlQkboC4LSPmTeL4eiGkkFZwA2gC
n8yfPxHHjsbuiWdVN6E79ZZXdoI49uSKZ4wExoP0nQ0lxw3Ekf2wfazNYCL4
EndGOPXE0b/w+F1YTITXA/LSj7XFUetEssIeziQ4qWSYya7FOF+U64qzahIU
14TGPdghjjpfWOouXk8Cld65CwtijPnJ/+reKd4CP2MMEJgTw1TbAv6GkGTI
c/TIdHMSw1n1CONY+9sQI+JmsMl4Cxp4W/6zN8yCIY6z4ibConj4rMeQRG0u
NMVLO8avimCnpOsOpzP50KN2YPT46CbkpgiqblMoBpcNUUW0GmEsKM/XLZF4
CHxpnITFU2Ec1bzl3/HfQ3glG9/+iy6M9vPK7xb3PgRJ3dQ/8iXC2Fu0Kq11
6CF8979vlp0mjHmKWYYPEh+C2/DL6Rg/YZTM3YYnWMvA4+XybjcVYTSb/xi8
tq8Mzl30bBLME8Kwpocn4GU5DOrUmNplC2EWh9tmjsZysOXkbEm5I4TKCeM7
OlrLYU9OSRs1QQgb5881OfeUA8vbn538l4VQp1f8p8dCOSRu8ejlthfCna7M
rixbK4BW7za7jlMIf4ts1P8YVwHS8Y98jdYJ4bmbdleYUiog5RDbQjiLEMY8
OOUkl1EBgZN5S2xLghh+SWm7V2EF6AoPrrIOC+LfqbbeUbICOjyPrWdCQWTr
SHdi/1UBs/xOWxYvCKL65037VfRp8P3xbKfZGUE8ukXblbqPBu0O0TH3Tgni
aMCpyFkzGpRlP1o0dxHEz2YbHHLtaHBKibPjvrkg5vl6rdadokGfblWElYIg
nisP+no4ngZtQ+ZEkbQgCsgnrmNOpsGLyMHZVTFBlHJ12nkvjQbprdzHigUE
8d/52yLfcmlge+iEFvMaQTTITKFMVtKg+Rz/9MNvAvhkzVjd7g80eEYpKljz
WQCvvXZ4pviJBsVPiKOHPghg2/xeG8GvNIj46/GWrVkAORPyzwwO0kA3Cu87
VgnglMbKOatZGmzfautIqxTABieiT3aRBuJtY3zs5QJoWefFtfCHBn8pgqH0
fAEsNpPzvsFKh6d3vQ5x3BLAug323Tf46FCgx8rrHCeAWSunCSkBOqQM3254
FC2A5d7lh44L0+HC1jpVlysCWBt817xZjA7KTzdxP/UWQKm9mzXMttLhfltD
rds+AUx8dGbfYX06TAj1dWwwEMCyz3X1QkZ02HVs8XuFtgCa/bHd3bGPDo2z
8mtW1QWwy8CXCgfoMC4crZ8iK4CGnPMfpxzooHY811pLUgCTW8aCbznS4XJp
teuAqADyyJwWV3WiAw+MXVOmCqBEbefbjuN0UHXdX/+aVQCrB9frS3vSIfiB
6wfPf1R8HjHVKe9Nh9fzQUN8f6jYH3BzSO4sHeyjHrA5zVCxtrPjg4APHS49
3Gi40Mf43si0Hi/R4dXiu9dyL6jI4TaudDqaDht0R7taqqioZLbVfkcsHaxj
mEcuPKJi7HZCjtFgQGan8IJwBRWDP9S5P46jw7DojnVYSsUd+1q+nU+gw38n
TQRPFFIxPYljr1ISHfzLj8lx5lHRze9awetbdHi5FKhOy6aiw+fCgJVkOnDo
JRnZp1ORxWzgumIqHaxiS+xWU6gYF7VG6+BtOmR8qD2Zl0jF0bgR9nNpjHy4
z0ZMRVEx5K1+VGY6HQ7esGmM9Kei5jPbsspsOtzp8upW9qGiZ0ZU9cO7dBgQ
C//ReYaKWnkKxXk5dPChPWaXOEnFNFlWlev36HD7o+C+KhsqVkqLTIsW0KFf
XMXB6SAV6zHGbYXBiqeMPdjMqEhe1er8WEiHmhX/qIP6VDTpwVPXi+nAZpiQ
tgBU1KBcsbcroYN5XFFRpiYVE+y+NsmU0iG1+2WVnjoVmRPEr04xuE/i85vR
HVSUcTL878kDOowVvHi9XZmKTkthN88+pMP8tnu1AQpULC6VOFzOYKbKCHwp
zYjffoumYQZv2OP5fL04Fc+Od/lSyugggBbVB0Wo6E0uzuxmsLih2pM0ASry
vfj+3o7BSs3Clf28VBzQFcr0ZvAuy9VyBS4qLtq/6b7MYJ3ugQfn2Km4L1CN
JYrB+482FFexUrHj4sLNGwy2HSwpYP5HwW69A+OxDHY5FZ+3b5mC2tbHLkcw
2HPKJydhjoIPLS5kBzPYz88h69MUBenPebLPMPjKyt50iXEKTlvteXmEwbFX
JW97jFAwpyxorzGDU9nXJVcMUHA3CyvxH4Nzb44lLH2loLdX1jc+BpdS3t3U
+URB5tJXSr8Z939ypzImqpOCS0UXJd4x+JV4WuT7NgoKl0BxEYOb84OvC7+l
oFv6dGYIgz9uPXbV5TUFfSQj8CCDB2iGIUUvKajP/Q3FGDyuoRQ0XUPBdWWe
6qOMfCy84A7Y/ZSC7OtVLsUzmMVg1vcKnXHe3sf8VYz8cb7tPv/mIQUX2AQ1
uhn5Fjz4/AxvMQWla27emGDUg+THHE+H+xR84hFeuVJEB/Xvp06MpjPuJ1Tf
w8KoH12PA8e3p1Iwpk+UeSWfEe/Jnc4BiRR0sCI1J+/T4difFYf1URSs8rce
qmfUZyx/nJmCH2O9P/QwYNR3atoFk3PnKNjK57eWmsWIl5i9UZUnBQ9/rD89
ksGIj5KEzr7jFDxRUbEv7A4jPhVsRMJRCrJWybXuZ+inWf3nnk8OFBzflWLC
z9DXgB5d1cOCgp+0lM+lMPT4603q9gpTCgabKkVaMvS6eCBIecmQgsR/gt4c
DD2zdDkr6ehScCe/uFgGQ+9cjgbyUXspyOR6nl7M8AOhAQWZ9xoUtB1y/VnG
8AtJ942SwqoUfCwS7FMaQwcNn48iRYoUXF/SrnAzgg56y8+EpmUoyNfQmOZz
naGf0LvU3RIUlKleHLQOo8PxWA/uN4KMeGc26bOF0OFm3h+W0TUUfPb3WtYO
Pzr8fnfM4QoTBT1mr7wUYfib/d83ZcIr/Cicu+zHcp6xv+1tR5Pf/EjfBbve
eNHh0Tq1xyX9/Gi6/lDgXjc6bFLN4NT/yo8HXP0nKAx/vezMerynmx95kL9u
1JkO32NPVfl08uPdPqHSZ0fpYFz1npvrHT8mGq/qRTP8+sGQxon7b/mx45lM
ptAhOvDx3a3Z28CPi29r/+nY0aHnlLeH9wt+NFRTqQ0+yNBb6gdybTU/SgXu
s0gwp0N+rZZA9iPG+QJEn2WZ0uHs5g21baX8GK6Sb1ZkQAfW1oLN29P5cUi1
lS1mN8OPtve3/b7IjyNLz0Q7xOkQd8RYNvYCP74cdX1bKUqH2aiyIOkz/Lj1
SNTKrU10eDEQrGBzgh//ej07bEGhgxT3UMgvF370i9wqoMRLh0jN/V3Xj/Cj
pU3zKdaNDD+9tSnssTU/Lq3WChiso8NjvPLJ3IIfM8K0Hnkx/qebfv34b8SU
H6vUmv7d/EeDQYMnPYJ6/Og/KMj/YoEG/gtWuwK286P++Xtnv43QoOH564zV
n3y4/w51lLmABoWvLsg/GObDQzZTSv8Y/UJ0g3jl4QE+TGb7z3Y5iwbm7wPf
Pv3Eh47e9OpHjH6jc1B5+XwjHy6t5e4ousroTzak2o3c58OL2rdVfx2mwbLD
Sb53znwYaRsSrslJg56jlKzLjnwYZvEoPXMtDZ4ff6mwzZ4PE12LuP8w0SDU
S0Qn+gAfcn0culQ8VwHrrrSd0Sf4sM7IYPrntwqgFKq3PBXhwwPn89baVFTA
tvl1kTldvFgZf+7RnoMV8E79CtPMe168bNU6pm5SAT4By/66Lbw4pKS/uFOv
AqpXxj2+1/KilpGBkJJaBRiztpvKVPCi5eN1FtLCFeDKk8FdFMOLEvZBBtf6
y+GOokpquTYv1tmr2L4/WQ7rnOzzyWIeDGiVS25reggfa/JMfshw403FTreR
7GII3/zkoVEDJzaLbyxN+3wfTIo2d3bEc+Crmym2eC0HPHy8MwLd2LH0bT5f
tnI6nLn7rUlww1r0EN2yKtOYBJ0PMmfMWdZiBE17ZPFBEmg8c9wUvsSGIcMy
0UNJScDU9dljdoQNm8u0hvmckyBxw0f293Vs+NFEx/znUiI89mszjL7MhobH
Xw/fVU2Elf34amV6DbbcqCtkqY6H6KWc6v5uVnSudDpz6kcMnA9deubYxopN
Dq1s2dUxcGjdwecf61lRX+FOjfyNGFCkMmELjRVDchqP6eyMgSaVo/VVsawY
LMy1OTMsGjjcN71L0GZFduNdoiNKURDdlTikU8iCvd7N2RLR4XD+yM/hmiwW
bN/6OrHsWDgcGtT5oZ7Mgg1cYl3xmuGgODP1c9tVFszK2PnbaOI6NHEdmBJ2
ZMHKrdvzJSyvA4fBhj/T3Cx4w1b/sKbANYihh/HkXmTGQpO9e6bar4Dn2Img
fd7MuMfy3F3ZsitgLmXyY8qVGcsbqTY3Yq4ATxIPgiUzymUaKM3rX4GU85ln
vm5lxu1JTR/9q0Mhd/uTVqEBJpx0WOdSfzwEqsp+xsbtZ8KQZ51+tqGX4M5I
y+IuPSYUvpl6y1zvEgSJVbh+282Er52y2si1l4CIu6i1TY4JYZ/vL+G4QKjz
XjPexMyE92oJ+6n7AXD3sFYKp/c/knNbz5sf4xehze4e37LuKmndypYQmOAD
y84+FtHbV8kVjuHBqGM+IHvK4OYm8VVSvb/OjF3VBy4HjazX/PuXFH3oRVp1
X4CtOUrMQU/+ksqtO9tEZC9A5E/65F+lv+RLk4kkg7pzoBNc18xMXSHd9VQv
2lh7g2d4Mkci6wq5V6FutnmdN9yOO2EsOfOHfCli/Jq3xgumctjrdNv+kOJe
kpxLsl6Q9Xr/s7AoBne1VU+tnIZl7g9FbKvL5K7LQxXs9z2AnjsUvn5kiWwM
3ME3HuQGw1kjFyU6l8hvhbLpWZpuIJQ+6r775RKZ+u9rs92iK1xO+mXikb5E
1qaEOBp7uYLJtbmNbw4skZ9/i+VyOh2HPje21Mini6SkYVyP4AkX4D+2LvLu
/UVS6/LexhhFFzA8uj7gaeIiSZd46fVu0hlKbLkO//BcJEX3nN3YHOQMfkZU
MWOJRfJRr5xIh7YTcCrIFKyLXiBVTpZVVH46DCAjd1vs4gJ5wCpwt/KZw3Be
QiFK3XWBpNFOCy2yHYaPwttOnyQWyMCdFI/b6ocgl0Ptv4aZedLAXJalqMQe
NMb1n4QfnieDjH41uX+ygdM/DAuzjOdJxwATgdTrNpA1aJz2WG2e3FxU8UN6
pw2wft1/aZh7nvQNLb2844Y1tLZYg2HdHMmjWRU7qGYFrmWuDWzb5khz5741
fKQFMBmc2+IkMke2vm2Yzgu0gPTPwb5P18+R91bb52zULaCdLVXq9PAsOWw1
D4ruB0Db8U3Iu+xZ8v7TB7umfc1AZL2yRjrfLLlx58pwSts+eJy1J26WaZb0
iLUMu++wDyxVjYbNJn+TKkSe/OEhY4h0cr7F1PybjIyKOtvDbAzzjxKn3K7/
JotG33uvHjCE9mMLhSqLM6TwYV96nb4eeC+yMkUPz5BGn/SjGsZ0Yf1NHrvv
nTOk6jml5txbuqBdpcCWUjFD1q4/b9UypgMPuB1d/pyaIV/F7xLNfqgNxvfd
n1o7zJCH46vvgL02DO7x5X5oxBjf+PmZIqs2bDpx87mz9AzZdmWheKmKgMga
FH79dZp83Hp+8rKuFkhbtpwVa54mbwRw6TeXaAI58qnBv3qaTEuKYuUQ0oR5
vt++SqnT5MKuRY/zS7vB1UOmPd5imjwWsGbUp08dmP5tV/hJTJPu5Ry3m1zU
If0WEaq3bZqs3nMlWHZ4F7STdsrz66fJEq/KM70LagAC0dGHa6fI5NJBPR9C
FVq5Hj7mok2Rbx7s3yL7aSc4srUPkHenyLlKcsrLbyf4zwprSl+eIjcZfC1s
zt0BFe1FY+MaUySPh+aju39UQLupRTBbbopM8+UU5U1VgdaX03oHBaZIsxEf
er6qCnS6XNA4PTJJugyFdz8YVwbDLUlpK46TpOwp1xUv+a1wjOvLtPOeSfJW
WOqFK1eVIGRF0qRecJKcMnCK4uhXhKefacs32idInoSza8+UKIBiavthMeMJ
ciGxU+i2jxwYhm+qDJOZIFM854ngaVk47nuM8wfLBFmQE2EUeF4WMqxmasqf
/yJjbO2d7UJlYCMP3xbdnb/ISKHHjgfjpEDxn4NfPs8vctOuyoGnnFJgNJHT
yjExTladvlcwESsJoc3bQzoKx8ky6JL+mSwBM5EH+1y3jJNv34t0/0wWg43+
aRpv/oyRJ4UDb1mQW0DpZH/8tk9j5PljKp+eTIiCq8E5nfmkMXJWuf7lLafN
0MWckBuxfoyc9F7aoh4lDDNT3ctjwz/JRGuO3pMDQsDdJ25lUfeTdHietMFV
RwiMX5SzCof8JKnBuwRO8AhCdeA71+LZUbIpOmLOeJICXR5Czze2j5LZ8+O0
vAsU+G3vTL1QNkrmZytI+fTxw1b1qXrNU6Mks7eRzTSdD7J/c8u19P4gwy+4
WsdH8EBTY9WQdvUP8kbVcvvBeW6YzTyeV3nrB2mknOqcObwRTIyfSGTs+0Ea
z93bXTHACb6iLn3c0j/I55YyauETG+DuDEd22OoIGSibEnCTdQPMZxzdfJo+
Qs6MiV0X37ceJM6zf/l2Y4T8d3R/SEIAO+w3oqVZujPGv55KY6Wvg9xpNsE9
oiOkSa7P90vaa6HlddmHBwvD5PKK1Jc9t9hgMd3hlkT7MJl2Jq339NQaMDd8
wLs+YpgMkt/BbvKSFQJE7N4FuQyTndNMOy6qsULeFFPclOYwaZM0UEmtYIGs
4/lGHzYNkxq/9t1sV2KB5TvWnN1TQ2RcVIpi61VmkDm72mT6dojsPJl9fPNX
JrAwKIwi7w+RYuE/JSu0mOD+5J+1BYeGyDvrvifXCq4S7+ru129SGyIVuMJN
ZRZWiOW0A9ducg+Raglt9if7/xAW+veY/eoGyTSeyJ3lXUvEJWEzHM0aJHdm
ZibX9C8S+RPzl48EDJJ6xTnD9IUFYuW2yYq+8iC58XLm1h3684Sc92z1U/ZB
MjGzRzchcI6w1MsK2Pr9O6n432Rf9LNZIljIWOPu8+/kvk0d+5bXzhKFv6bn
+W9/J5Pk3h6nO/4mOl6lP4o4/50sE/lpd7VmhlhNNfD5s/87GcbBpawkO0NY
66ZNDzB/JwUaGyImqdNEiKBeuW3PAHnwb2HNifQponh83Lvp8QBpscvIylth
ivjwMmUbkTBAjmeE3d4VMkkwpWqPV5weIJu7xqsnqycI5binAjlmA+QRzVbr
uZpfhK3OLY808QFy/wkd+1qTcaJkbGQ49EM/SfnTq1PJ+pPowoT7s2X9ZEY9
ua9u8gfBlKLp6h7dTxYMfi8wHh4hbLXj+g9AP2ls4/kCZ4aIK9Tdd2uF+8nr
iwa7K9iHiNKfA0fVZ/vIgv3MqxsVBgmW5F09W4r6yFtjDlxtkQPEtlN9dxLD
+khPwlefqbGfsIdoh7VH+0jZ/VVzmrz9RBhFVShQo48cZMl5aO/aRzwc/dr1
i6+PLBzZtNX0ai9BC+ZWqv3cS65wdQp1mn8j2OWPFxbH9ZK7fifGN237SlQG
cdwLWPpGntU+Y3dP/AtRGhv59AT9G+lhdlwuRvczcT9jbauV1zdS8+Ook9L5
T0RW6bXv2nLfyJq8gs62h91ESg3L0rb+r+SNpgDuyoWPhNFqlNPmgK8kq3Ty
t98fuwjJyMj/52rZ+P/n0PGg3XMbv5Lj62omnil+IPxXls0HGnvIJi59hcur
HcRZzgDXtqs9pFctz7RGdzvhsXkhoEarhyzaJXBN4Ol74pDW77yU8i9k+U5N
5ZfUNkIraGzZ5PZncpEqpLabpYFQjfXg0bD8TOodETSrEq8ntmWMyMhwfiZp
mxRoc2a1xJaa7xb/Qj6RdtzHLwaWkIRAs8uJ8d2fyLmdQb1ZLjUEd0/vpU+/
u8lI/TeudupVBNPKl3z6yW7SKi3B2U2PTixuOFRzV6KbZHfMuJEeWE5Mi3S/
v/HlI8km6P5hf34J8VPJdiQw+SMZ9+7HrTd38okBzc6Vkwc+kpfOOB883JFD
fDa15LNZ/5HM0gt4SuTcIdoPv5PTre0iNVOvPteVTSSaTpvv/S+4i5xpX7vH
w+saUT9RmHT1eBfJt+G6KK0+mPg/WQfgrw==
          "]], 
         LineBox[{{-0.2126328996767897, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.34095191550393816`, 0.}, {-0.33428277380397264`, 
          0.}, {-0.3300058029298561, 0.}, {-0.32572883205573955`, 
          0.}, {-0.32145186118162294`, 0.}, {-0.3128979194333898, 
          0.}, {-0.30862094855927324`, 0.}, {-0.30434397768515664`, 
          0.}, {-0.2957900359369235, 0.}, {-0.2786821524404572, 
          0.}, {-0.27440518156634064`, 0.}, {-0.27012821069222404`, 
          0.}, {-0.2615742689439909, 0.}, {-0.24446638544752458`, 
          0.}, {-0.22150459657587682`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15038#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwVl3k8VV8Xxo1lLNO9FyXzcK9QIaTuEgkZklTIHIUoZKzQaOxXkgyZIqJU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          "]], 
         LineBox[{{-0.3392531333116301, 0.}, {-0.3300058029298561, 
          0.}, {-0.3128979194333898, 0.}, {-0.2786821524404572, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.4560811701545825, 0.}, {-0.44976098740512027`, 
          0.}, {-0.44548401653100367`, 0.}, {-0.4412070456568871, 
          0.}, {-0.43265310390865397`, 0.}, {-0.41554522041218767`, 
          0.}, {-0.41126824953807106`, 0.}, {-0.4069912786639545, 
          0.}, {-0.39843733691572136`, 0.}, {-0.38132945341925506`, 
          0.}, {-0.34812483021071716`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15038#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVl3k8VO8Xx+1bRMLMIEvWsUUqkuZYEikSskQiS1miJEsR2bMlWSpSFBWS
GYVS3VPfsmVPklbKruyy1m9+/9z7er9ezz33POc5n889V/ZogLUnGwsLiwXz
8v/7mcO86UkFqphUw79nbZEU7FOdOOR0UxVF2yQu7u2Ugo2LXQpqN1QxXbZF
uvGfFLRm3qptuaqKtc9+LMQ7SYNis86QULoq3ohYOcO/RgZ69LxoOedV0XOL
+eOFtzKgR/5v/LaTKs4dE99tf3wjCA3eqw5yVMWXpep+VjEbYbAyLdrEXhX3
HuBoCsjfCBn7D5GHrFWR19FYauP7jTAWP2WsYq6Kp/z+YzjtkoO8OencCl1V
LIqf8zmoIg//OsP3PBdVRV3TTT9MRBVhG9HAd2S9KqZKxWhQdBXBv1SkmWWd
KrKvvq+UdVKEzzFllrv4VdFhG/3luwJFqNny2eYtGzPfAuR7o6UEJ7N3uHyc
UMEf2Tk14s7K0Oe4FDjXqIJTyf5ieZ9UgLx795acehX8RnEszedUBavNGXO6
b1Tw5pWXv79vUoUXfCqh4aiC3I82f1GIU4XrtY4R7NUqqMm/2f3pZjWw3vAk
Yd0dFZS9ddr8wTV1+O97SJ76eRW01LgzOmWhCcoycUl/zqlgUtrAvxRPTUg5
khH6MkwFnSHF0zhCE2y/ltkePKOCacq6YVwPNOHnpz7+CD8VDHiu2SyxVgu4
PuyNaD6kgt6c6av0bi0wa5F28dVh7qdp70xFtDaU8avv27pVBTf62vDcydcG
oX16ev82q6DGjcaY50+1oafJVuyKhgr6/abd9pjRBu+Gi61PFVRwrv6MfJLX
Fkj6b4bGJ/L/fOptPW23QvOTeun7k1RMf99yU2G/DvgPhCif/03Ft/w1j3MC
dGDdOmUtm3Eq7hVxMdqargN2xxONVoeo+DL2fe1Mhw58F9vjeeAbFf9IDwzG
2uvC7OmmksUWKuaZVjmp+G4HSY2WrealVNRPOKNe92gHvHCMoEnfp2KxxXWz
f707wC1O3XS2mIoijc5qvqz6UPw51SG/kIplwyl2ny31QTPZ8tz0NSo+va2w
UXVcH3YNt+H1RCrSc1lLvDRp4FfYuXfMk4q6OReUEk4awMnxYfPL7lQ0Nu7/
MpxoAKe3/duj40ZFLq0XNicKDOBsk6pZjDMVTx99Lvet0wASpmN3SdhQ0WnP
dV8PHUMoNNLZudeAih27SyqfcxnBx/5cjVJxKiopEO7NL43hsxpD/QCZGf/d
eon6r8bwPbhB7Y8oFb30H939umwMg3xzKsbrqGg5q98cv20XzG62VPrETcVf
XjvnXj3YBUIxLDJr5pRxPP6en+IdE9gt57nOt00Zk7Vnsx/STSEY9Xdub1HG
2m03qx93mMLdwyLe3G+VccTGhXdgyhR4rv6Ht+uUMShqSQc3m0ET/8aTn58r
43G5HMeAKjOwnP/aalGmjNZZG+/1vdkDdo0OKZoXlfGy+1XJ7Zz7IN5Ls+Zv
vDKy/W3/TFfZB9XsPD+bY5Uxe+9Xv0NW+4BMq97hHaWMM5P5yzvy9kEvQ3Ss
IEQZj+17fdp0mwW45HXuWe/FzDeWvzbjtCV4BuzjnjdSxrXveDZnXrSCeZUk
apaBMopXDbibF1hB4mD93i00ZZR97r0i88QKSg4bpwduV8YtXF2Lm0asYHKv
HmVikzJWljz60WN+AMKVlVWHJZXxxjmn8un11pDRx76/d14Jd4dNWmxDG5C/
YXgqbFYJn8tafdT8bAOPHSKvkKeV8Jd/iILlgg30tC19sPulhD0Un8kuTVvY
8GLK9d0PJbT5NVV457Yt3Lv+LbC5XQnfiRv0xqYfhBc2tdkvSpQwIfmjtl6i
PaQt5747fk8JG2ru7gu4Zw8ut8OF1hcrYZllbkNLgz2sTu9MOlaghFp7cue5
+RxAPwMjhK4q4fjFQztD0xzgafsbj6NxSviqVtDj3E1HqLJo38zlqoSU1cq4
931OED9XEVBxWAnvllUKRXI7g92Ny2WHnJRQxu3vLQd1Z5gbt1Z8aKeEy8J+
b/PCnGFLynuKg4USDoSIxAWIHAZGUy9LiZ4SCrhcfs5m4wIPTAdaLUSVkF/t
nf2ds65QYpSgK7NeCfPUv7hKX3KF4p3UwmkhJZzdsPkg47Yr3NI+cSaHXwnJ
Lg27ZVpcIVN6TqKPXQm7n+qbcsu6wdk/HN5B04ooUT12/W+zG5jdlWfPbVNE
/eC1emy67mBSWOd3okURN3n5VmTsdwejG8e74S2TV0wnth9zhx1Xyu7/rFPE
w3+m/aqy3UEjcouVxgtFlKqWlJicdwdR+103XpYp4pTYoc0pzzygn8tDZ/ii
Iga7nfjAf9gLDGT8cpITFJF2Xvq94VkvyN8e9EcjThG5IzparuV4gaNfbPWZ
KEXctbimpLLTC9o77uiwhyhieMvJm1nmx+BF3oCOlIciTty+G2FoeByubT6m
a0tTxA21vT0je3xgfm/A1T87mPEGzxdU+vqArWfIwvXtiphX6VVRlOoDQlcT
avq2KOLlW+di2Dt9IH71rm6AqiK6jXBmlTr7QlDDsG4SWRGFl4iVkjA/sHLx
2Y7TCngzwd89u8MfPjVp1yVPKqBZRP7w3Jw/eOmsWtv/VsDzIqubIsQD4JxQ
ut/vEQW8F5MYwu4RAMWvHt+U7FNA402FilMLAbCqyMoV1qaAfxpyCjMyT0LJ
RE6nVpkCyuec1tnfdQq2OrsdWb2vgE5PvXvZRk4BNqiMN9xlrl80DmhePQXv
C55zut5WwGQ5Pf7LSoHAYvtDN+26AhJ1jYb95wLBvkbj5miiAg4Mk648UD4N
HBfe+N72VMDcY85bY64EQctHrfVn3RVwTRTFwK8kCLI35z+1clPA1Tb7ed+X
QaD8M5j3r7MCim3y5KuYCAILU+W7DrYKeHkkWmG/xRnIFkjuFzBWwN7ESh4e
gWCgXrdyDJVRwF31c1Oy+SEwPf2MZb+UAkpEctnMVofAs73UewqSCljxpp7v
e0cIWK6y/ukkKWAD6xkZDq5QCHStzFQXVEB7vpbV6IBQeKYo1t6/Ko965Lft
Z0zDwLLy026LT/J45s/r8m7ecxCqUv5ztkcexRkf91lTz0FhQVR0Xrc80koc
2CbMzsH8JYUXYx3yyDIm6ZWSeA7y/QK2JjXIY9zyUWUn3nCYUGCXr38sj1c8
PddT1kVA+lUVVsN0eYz4Q7oxrhMJnRFhtVtM5FHQjevp/PwFoJoJxHMYy+MY
qUPjHm80RAkXWHUZyKNW373wA5LRoHG3YeC0vjz27HvP9t4wGpLbSUKV2vK4
YXXXg9up0bBLrspDayMznvXBD+eUY6CqYVpA458cFrtSF4V9YyF3vZ+r0hM5
zNY38OKWSwDbFU/Zhio5FBRplu3YkQD8A0f6jz+SQ6O3hh/otgkQXmXjUfJQ
Dufjd7bVxCeAs+OO4+rFcsim1Jb+fSwBJG/yndS+Ioe7jn3+U/Q0EfJU7kfC
CTm0XrVLHvVKgnzDwXx7WTncLs0z7MGRBpliMWfZpeWw2aI9zW5jGiSPSds9
lGTGdzNf42aQBqFZjgLcZDmsdd99bU94GhwYaT5XtVYOFRnPvqrNpQHH5UoH
0ZWNOHfuq3bm2CXw/R4l/K57IwrNnbaCuXTQjZSIt0zZiOIrhx3Fxa4AKbHo
hhXrRswsc5RKSc6BTdRqy3QfWWY/atUPrL8BqVkbND99kcFR7otfAnwKQP76
mlJ3Exkkd7qJ29TfgTvO3jc8j0ij0ej6nAfb7kGyhKeJuJkUrljaJfB7lMIA
30kZc8oG9NYJSPmdXw4rn122fxPZgKeoIw8jS8pB5KGFdZDQBlSZf/NBqKoc
dtmoxuZzb0D2Az7TWi3lUJg7ODQ9J4km7JkzNYvl4KJ2+GFupyTO14vF8R54
CD0W5rRfyZLIla7hTPx9CJPS2+2jEyTxEc74neeoAO5ppZOkGElsNe0Tvs5b
AduyOQsNz0pizNkB+cb1FZD5FTmzj0vil4dlhwSUK+BAgE4LzUQS9X1Gipys
KqApXd45/a8E0k3nfNLzK8Blh2PJjiUJFJO7BaK3K2B6IHVhcE4Cc1wlZnPu
VoDEjj+ZO39J4Bkvqy85FRXgN9DYMvpJAk08HnEnvKqAtXoBYPJEAml8e3/u
HKwAmx9PNi6dlsCA87r/DSrTYTj198miAAnMHz6f/FWNDuG6coSVrwSWrtn2
vkuTDndSU5zuHpXAQd/GtOe6dJjXOZJpe0ACW15mNUSb0eFqCgfXQw0JHOKf
vPb1GB0+b90/4j4ijl9ZOCKFbtJh8wYrefpPcYxIOHe+qpAOiRwHjvz9Jo6F
Y4ubnIrpsOWd9fur3eLoW2P949YDOqSctHvZ8p84VkZHZEg+o8PO0sPXdPLF
MW9TyVO/bjpkZrh0xV4Tx03Jh7PDPtJhNOyIYGemOPKfmSmK/kyHbDO3OL9k
cUw/2NqV1E+H3wMepwpCxdHvgYZe+G865Mv47VljI47BLLwKa7kYMMt9ItbB
UhwzyqUvLvIwwHziBFG0RxyjlQMm+tcw4Fa3/9L0LnHcevgVT9NaBsw/D9hq
YCCOdIue0+XrGLCv6OTJ1B3iKNk3WiQvwoDClFOlvdvE0WDrnqUkMQbsdzot
e0ZdHMfb3J12SzCAJfvs4lducZTrvM2fqs4Au4hzW9TYxVGru0aucRMDyjzC
A8L+UnDDukAb9s0McNA+P7B+joLBfF9KA7cxoKL9QodZPwVvV1pEAzCAqyaa
P/sLBbtOF33zN2SA880Y0x89FDRhu3Qiz5gBjPjYaM0uCuo8Ch2vN2EAj3/c
84g2ClKq3/BNmTLA5WD8QlMTBe8UVruTzBnwSD9Bm1xHQXbhbUJdexnAJ5/o
7/mSgqUVt1ODLBjgtubifcYzCiZftibW7meA8DV+mlUNBS923N+faMWAV4rp
nb8qKXitK3Hn6gEGbDTKWVYupWBYdEFtry0DfoQWWdy8RkElapWg/yEGZHJR
+/WzKOjf+PRksxMDdmWWBfemU/Dy2qH/lA8z4M7DypuiiRQ8OmNB+nyEAZ6D
L6eSgykoYvY+TsuTAWJBJvHUQArerXpVE+PFgDrWRvH6ExQMeuF/p+sYAxQ3
tBuzeVLQ11/UMNCHAd0lNj03XSm4yVHn5gtfBsTrfvDb6UzB7rD+tbwnGLCt
7hDrJ3tm/eM6jQ74M2DI5mtWqA0F10z2LsYFMOBqn5uK2H4Kuh7h4bI4yQCz
gIEXleYUlCYZsq49xYB7SeNDvw0pyMa1lBEZyADvl0vbPTUpeN/vG6v6GQaI
7z/fyqZGwcV62TNtTG76zOp+S4mCvy6d5w8IZoDKAk/KJykKVipL9BWHMGBM
g/T1gAAF+8valVnOMiDv2fXACR4KCrEPjWQweZ+5FHcqBwXdrKrD5M8x+8dT
QbNhmYxOhh4qu8KZ/TBz77XnHzJeintt0Mlk/gtqjuwzZCQ6ggWPRDDgRJ52
NG2UjNSBJq2g8wyQUqkW+zxAxozJsbUrTG6t1isN6yOjXQrj8YVIBpw3eQGk
L2ScFnW9+JPJGu8Mux71kDHWJzyzj8lfXd8ct+4iY+4fcnAPk9N+m61OtJHx
2Uz6/UYm08KbL6e+JSNrf1/xYyZP8FopqtaTMfupWX8ek2/lvHva8IqMw0W9
byOZbKVgv9/rBRlPyVPaXJjMUtn7g/0pGTnDL1jrMbnCwCW04DEZpY1I1cJM
dm3t4wc6Gb99HLEfZuYv5OxZ8LmMjD1PMy/WMvlUiF8T6Q4ZH7uHtTox+afh
s732N8n4YBNNQoHJdvz8LdnXybhZ/fWbcWZ99ApK20Qvk3EXTyZLKJPLfJet
DqaQceZ58rsdTJbatrczM4GMxdXZCX+Z9WV7O9q1/jwZjeg0zygmB2Xp2dmE
kZGhX7QHmDx4JOlDRhCzXobm0SvM83JQ6XXoDGA+TzysqWZy0yy1d50vM/9S
WuRJJusTYU4HvMgYGZzxd5h53uUXGz+nu5Hx0a0ngpxMlrGluLQ7k/GCOYlN
PIwBGVLe3wQdmPuViT+rHMoAjpEa1/02zP1E1pG1mP0UXMnTn2ZJxleF34O3
MPvtkNm9nwImZOTXMHqqHsTUa+DQyJrNZDSpFbu1wOz3TH0d373qZDy2+VfR
AFMPXNwJ40nKZPz0uozSwdTLaK7iBK80Ges97W3uMPXEeOM5y81PRvsv/UIG
TP3Jpz8+Y8rNrJ+GbI88U5/Zhzj/xLORUa6X6zwPU788CgdD61ZJeKr3Ru2o
OwPOTtxZ5FwkoWrUh81vjzJg/MnsWZNZEh7nVDhx343pV7G7VmInSNj4KmhE
0ZUB7ZaZEa9HSSjE6/bF1YUBRpSff9kHSRj4xWTkijPTz35oRxn3kZDtYvsT
ZPqNYnkMa8xn5vs8tOaHHJj+ZizHwfaOhIfiejYpH2TAO7+jvCxIQuWQqhOR
TL/brcNIgloSPn33KPES0w9rWNn4I6tIGCRQppG/h6nH7IK1f8tI+PWOsWsN
01898Pv6lWskFDDRXzO4k+k3SZpZO7JIOKzpcn5yB9MvDkaJnUsnocjytPfS
dgaojUpTluJJaLXnaM0apr/Prj8itXCahCe/XLGcUmP6ZdVsl0UACX0mmtKs
VBjQ6ZiUfNuHhPd3JsqVKDHg4c3HC5ZuJCzus+yx3MgAH1X+d0WWJPxHo3f7
kxjw3ehJgg2VhAm1G276szKgbcCSdl+ehPtnj6wt/0uHF4k/Z/9Kk7Br4kvh
r2U65LYKHi0RI6HwwI5Kv3k6JJ0qIrMIk3Ah8cPj0hk6hIrsaDsoQMJcv4vD
I5N0sDvkpc/KQcL3PwLzOcfoYLK6PG33TwzdJj4oZA8xv++3Lt8vWxLDz0WH
QmV+0mHd4DMxhykx7H5A3q3whQ7Np9ZPlX8Vwx8d6rdY2+hQK3L/Lkcvc/2N
3zWBb+lQUk1zOfReDFv7JUP66+mQsOr9lrNZDKfcg+4SSAeji1jk/EQMa69k
hZ9l0EFLzc6Z8UgMJ6qq7o6W00GmbUyYp0IMU/sO3nIqpcOqCCmqslgMZ/it
e+AOHWpunTjElymG24PGutdk0+GuMfs610ti2DTAMNiXwZwnBq/WP04Sw+ts
Mh6CaXQ4rfZ6i9sFMdwblnA+No4OGjXigjX+YnhP5H3FziA6FLXV/+e5h7l/
tYWVgAPM+YP8/d0aEzE0FKHEuVvQYdvRhR90AzFsWB4xddhDh4ZZZY6/OmIY
eO7aUxNDOoxTknZlK4qhdlw6Q0OLWT+PfW/q2MXQ64up3ykBOrxaaK9TeiGK
1aaO/bdfVsAao5HulieiWGjp+HP6WQXYJrMOnX4sivmrx3KNaypgcMNmbiwT
xd1muvIj5RXMfr9i6pArirYUs268zpw/Uw82JIaK4lpv7/DCgAr4LtvbOLJZ
FBW9H5lsF6+Asbsv6rQ0RJExWHXNTaQC5tVv/xdGFcXFncPekwLM9+v5PeeV
EcULWRZkNlbmvGv9t4IqIIq3FTekkVofQkr0xqveQyJ44E4c1zWvh6Dzw8dr
JFcE7V04GhsyyiHtzjLbCIcIvn30ykGvvgzqn9fl/R0VRp0j2//WytwH9Xnu
xILudcjCJ60xYVUE3EcciokSIfSSI1YatxXAh2d3zIcVBPEma97bDztzIV6y
uty0nh8HFtiOnTXLhCeMfd9OvOBH0mi+2nqtTBg36xfMfMyP8sdfbX1HyQTr
MwKnvt/mx4aaZ851Y1dAqtVdOyyKH+k5D9Mvp12B6kihmpLt/Hg4p7zTqS0D
hvu9XwqUrUGWPTmS930ug/l9ya536Xz4+R0HPTIlFYIndwYoJvJhD29jAskj
FW7rHOELi+TDeRFF+74dqbDypsBAyp8PH+U7uIqMp0B5v+KD43v5sDQjwVh7
fwoIS2rFr3Ly4asDHiOFssnQm2aiq3SOF0X4LuxY/JgIXN1e78ICeZFa4x4+
/jgRtDck+jd78+KHI2yxlIxESCltunPKgRcbx5RZlfYmAq1h/7pnW3mxbO8h
Hi1MgELWQ6NWkzzYvsbyumtVPHgH+eed9eTB8RQiY3dRLIhvVV63zpkHHQUz
439Hx0LTXF/cXWse5Is/cPKLayyohBwM6AIebDonOZexIZY5f+sbaYjz4Kyc
Tqjr9RjwieQb7mvlxit6+Vt0s6PBL6lYe48uN8KnzmK2wiiQ3Ot675sGNz7+
NnV0PDYKmteIbwhW4Ebr17fmScejQC01leu2MDcanPg6o7EpCn5dCvq4Ms6F
hcNam5YCI8E/yyiyooAL+2o3iCkURkDAra9NpDVcGD8kpGBrfRa6HtyYtmTj
Qq/g4yFPZc6Cbq2zePwiJ669zv+f90QYsHT3es8OceIW81+kitQwyFjzgafj
NSd6a/dEqreGQlVw2+6k85y4/Cqmr881BFb24auVKQ4sDWl0oj0OAtdDkaPa
IxzIkmojpJgcBG+O0YR9v3OglmpZ9RG3IEiLfub2sZUDb9M2GnWsDQKZmhqW
qlIODE/d3/zlxGkwlqPTAjw5sKgyTdtzZyAkLRY87ethxxcO+kZbhwIgMGqx
1rmNHbUd5E3u5AbAIe4Dzz+8YUc2m95vH6wCQEWUBVsY7Hgz7/iHrOf+0KTp
8uZJCju271dSuXjrBPAdF2+/bMCOQ9WFseRwX5j+faqDX4cdi18UtStv84Xe
M42dCersuDt01L1x0gdKYkLfR4iz44w912LbMR8wv/n/ArHhS15qZuBhb0jq
zhgwvMeGHCYj/O3exyDw8Ojgs3w27OiSO3pZ4xgc+mk4rJPFhvR1xfbcs16g
Mj05qh7Nht0FPelcF7ygSWD/JMWZDU9QT7ruvO4JfCZrlqcE2TBCverU4xZ3
SK6MESoMYUWXpexX/xW5gt+YV/gef1ZUFbY9/CfIFSzlzIcnPVjxGUNV6uou
VxC6IoRgzYrlqv/puDYdgezAGwFf1FjRJzozdLODCxRqVbeS+1mQ/XjWsFCx
E8R6X9fDHhZM6FSl1to6gWdBRPGxNhZka/NLiORwAuV1u85XPWPBxlPJrpbH
DkH5ZLu6bQ4Lbp1uTc7Y7ghPHo6mXNrHgt8vSdV6tNnB9aGWhW3GzHhHOAty
4+wgXJru8XU7C+6dJtbV6tsB7VKIvroSCxaz7Ld59eAgvPbnGG9iZcFnXv1p
O3Nt4ZaTfja//z+iSzLaknbHGtzfsvk7Of0jApo6+C94W4PijkaTErN/hICn
xvKQmjWUidvNmcr9I5L4H31LLT8ANR8DbGN6/hK3LkxzqTy1gjb728JLRn8J
M3FbHfdxC1hyDbJK0vpLiK/qHv3vogUo+pikicv8JbIG2wKylC3gfPgQ747V
VWIgc+lLqs8+UCtQZQ2vXiXKczmHMv6ZQ+Jo5cSq6ioBt376OeubwaOZWPU0
8VVi0CHdL/KnKXxbOegrxbtK3FfaI/ok1RS2CS4M0gZXiKxzRefjfuyGn9r6
XyNvrRDfL7W9+ZdnAoYRr5tZRVcI0w3kra/2GINffBZfBvsKkfBzM18LhzFc
veRltnF6mUg5GPuC66URTBbwvDZqWybM9aWdZ/WNIL9uX23MxWWCO05zA4uO
ITS1bVhcH7pMkD/vD78zbQBzPb+33fFaJngGJVTlHhrAvrF0xmvjZULNnOPF
KxUDWBJ8f5/z7xJBz16vyHmIBoqU4qGs8SViXPPsxYFvO+HAxhAFxU9LhFLj
0LmaYzvh3hZKwe6aJWL7OYWPphH6YOd4+GpC4P85Ksce9aCycCCed2iRUK4r
EJQq0oHB/KEQ2a5FYqrc7GKykQ6Qc0eOb3+5SEyIpt2//2kbnL/yy9w7d5EQ
MKhVU+LYBuaxc2sb9y8SNdErmmLeWyAi6s+/7/qLxC/vSacSri1QEb44uUBd
JPY6l4fzFmuD6JnVTmUOZvw6Uh1tdDN89+TMSaxZIFBQ++1kohasP8qdeKto
gejq8vxv31Yt2O3CG1aTsUAkHBORS/yhCaV2Ak7DfgtE/MDz7gwTTQg2FZU2
k10gfh8IeddA0wB+qsJd7qQ/RN5x3FFeRwVQULoqHfKH6FuGIqmdVAiUpV7U
8fhDbAjb8c2iShk+UNR9j9H+EI9GQj/x0pWgkG/rpvrpeeKep8/8tQYFeM+l
I/Pt2zyhpxc1cP+gAvCwb1/3p3meMJ7q5746IA8nlvVnFO/OE34L5bUsa+VB
d3xXdbzTPCFyll9lc9RG8B3efS/fbJ6ImXCJPCG3EfJ/ml2r2jpPJDlf5NzS
KAvsX/adGxScJ3b/i8tIFZaF1hZb2P16joizw6vlktLA2mSn6UKfI57PHAvb
6iEFW+ocZIPz5wjO0RCJxw83wLUXzuzFoXMEleJJtFlLgsdDj3pO9TlCUFov
0LeJAiwmp6SOSMwRVb5idmX6FMjtjThTwztH6BaXfrjEIEMnZ46c7+AsYW2o
qaV9nwQGzo2R7TdnifjgHiPqS1GQ4NXQzRWeJahTPzrdrIShKl/v0izLLPHI
pa7z87d1YL3FdNBiYoZI6xn8UntqHSQecc1kaZ4hZkgHpN/kCcH844xJz7gZ
wsbS+Yqb7FrI2HvTlDg9QyiQt9osHRMA9b7SfPLRGeJZQ2lZSSU/ePC/2feW
NkM8DND8YHNoDXQe/XNPc2GaMLW9+970Jw/4L7CzJA1OE4sn5D+q2vAAb5qQ
/Y+uaSI390LdQB03GDyhcmbTpwlfzp8tUc+44IGgs9uyzzSROKhb1/GJA8yK
jtfYOk4TYpt3cgXv54CfemcEy02niX/Zs35qdewg7pX23FV+mqDud3VaesYG
ic+QUvdlijC8djNfsIMF5K1bTko3TxGKkW7HwIUFiKGP9aFPp4iO0fHbIV/+
0eaFZ86o5kwRopfX5Rpq/6Vl3PvXHBs3RQQn6ZWtO75KU6fxy389PUX0aRql
hd5eoXl4K3SmW00RGVsHpn6qL9NY/mlRR2lTRKvGpdTW8CVabiYtylh9iphh
e9Mu1rlI6yTsNeZ5p4jMq3tmj1xaoIFYUpLTf5PEmir+ftkD87RWgfIqAcYk
kbfy6P1wxxzNmbOzn7g1SfBKCpdet5+jhc5SdsifnyTKr/Pt99KdpdE774+N
604SH/Rj7Lv7p2gGTS2km0qTxDm5GNk1dlO01pdTxgfEJgkbHY+A+uZJWpfb
aV3foQki34aau3RxgrZb6sq1FecJglQVPHn41RjtqMCnKVe9CULgh6np7/5R
WuTKRvM3pAnindtKwyjfKK2ml7GU2vmbOD7wMX7jqWFaV+OS9fTD38TBf375
1g+HaFM1RqV2qb8J2p9LBj2zgzSVnE4nabPfxLGC6MairAHa7njxRzEKv4lG
gSchryd/0tzPHOUfZvtNKHI5fhqw/knLs2H+NTz/RTh7Lrx/oPqDtlZIWMpI
+xcRxjb5PGDgO03ln2NwsdAvQiZ+xXjB6jvN9HdBK9/vcSL3oHBuVsw3WlSz
VuS7e+NE2OETF0u8vtDyasM+6MSPE/zW73lIxz/TnpS83JTnPk58/ejoIRT0
iTadeOC7h9Q4EaddN+hf+pG2NvSabuPyGNE/0pp9v7uHpnqsL1394xihH8pG
l+DvoXmYnDKcvzJGPH0cziGc1U2L2vLk2qFTY0SvPJ+X/vB72g051ukXlmOE
Wi/r2Miu97Ru1suFCbxjxJ+sSmyldNGmJ3uWxgZHiXVBwm6nL7+jCX6XsbF6
PUrkb/EhnVn3jqbWdrz0UcEocVjmpUzwtU6a2YsKdkrkKKFX+WREkNpJ83iw
4BThPErsqG160El00C7kGTzq2z5KrOjsXW9yuIOWn5zIv5s0Snzv0Hv9g6WD
9vRsu0fJ7AjhqPCQXbakndbtTX6+tnOEYI1sAQ+HdtqMg6vo6YcjROLTorTt
gW00IbN7Jz6kjBAqDy74N3G00tR0Jt/s8Bkhbqjmn5q/1ky7OSOo1PJtmNgS
9dMoXKCe1tTwZMDg6TDxwFF5mZL9hjZ7w/3Oo8xhQvnatpkMudc0c7Nq2bw9
w8Qbu1+iEZYvafN5LpK+lUNEnOCb0zxfqmmygTyfvqYOEbUniqPDrR7T9pky
rlkfHyLmyWMvXrxj0AqnOEl6G4YIj27jy9riZbSWuofvH/wZJAQ1DrKPX7xL
W8h1zJTtHCTqavi6LWVu0yx3P1jHmzBIWOmn9G+9nEULk7BvD3cbJMrYfpde
DkumhYsLT6nCIHF05v3d3znnaP8Dn9XNZA==
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQ3REZMZ/17cP9DFCwpYZrceXPe3D+mp6OHWmbEfyl
c9jOBeci+NP2MP3UfXgXzq/488vv0Yk7cL5NzetfXjNuwfmHq88EyZhfQ5j3
VYa17uUpOD9n9Zzp3L4IvkmijNbMDSfh/ENnpP23lJ+A8+8vlpr5ivUYnC8Z
JKEbrnQQzjfc5RdyMGctnO830Xfe91+r4PysDJ8Xup0r4PwlYl41s5YuhvMN
nnV5PN8zGc6faBLKEKxdBOcDAOuPWr4=
          "]], 
         LineBox[{{-0.6863396858154165, 0.}, {-0.681066414329966, 
          0.}, {-0.6764829338664331, 0.}, {-0.6673159729393673, 
          0.}, {-0.6627324924758344, 0.}, {-0.6581490120123015, 
          0.}, {-0.6489820510852358, 0.}, {-0.6306481292311044, 
          0.}, {-0.6260646487675715, 0.}, {-0.6214811683040387, 
          0.}, {-0.612314207376973, 0.}, {-0.5939802855228415, 
          0.}, {-0.5690550419507858, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$15038#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.08714073841890102}}, {{-13.815510274069974`, 0.09530989591002416}, {
        0., 0.08714073841890102}}}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.1}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.1}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, 
   3.6390767166598787`*^9, {3.6442574366310177`*^9, 3.644257640914957*^9}, {
   3.644257708990077*^9, 3.6442577371366043`*^9}, {3.644260004751333*^9, 
   3.644260077952415*^9}, {3.644260115987558*^9, 3.644260126350301*^9}, {
   3.644260188124305*^9, 3.644260218133224*^9}, {3.6442602591886263`*^9, 
   3.644260302050921*^9}, 3.644316648114072*^9, 3.644576451074027*^9, 
   3.644576487542392*^9, {3.644576549658166*^9, 3.644576621616087*^9}, {
   3.644576764562796*^9, 3.6445767820862637`*^9}, 3.6445768574554853`*^9, 
   3.644576945003827*^9, {3.644577113369245*^9, 3.644577140083241*^9}, {
   3.644577753012301*^9, 3.644577802627615*^9}, {3.6445780569311028`*^9, 
   3.644578103866412*^9}, {3.644578289753704*^9, 3.644578315580659*^9}, 
   3.6445783615710917`*^9, {3.644580938831132*^9, 3.644580960697556*^9}, {
   3.644583691767996*^9, 3.644583700885569*^9}, 3.6445837471615887`*^9, 
   3.644583847010324*^9, 3.644583892827443*^9, 3.644583928512251*^9, 
   3.644585111858407*^9, {3.644585173229665*^9, 3.64458519082297*^9}, 
   3.644585513469898*^9, 3.6445863990953827`*^9, 3.644597859482862*^9, 
   3.64459793577026*^9, 3.6569749437404423`*^9, 3.6569800300558558`*^9, 
   3.7258961352719097`*^9, 3.725896167648038*^9, 3.725896201653112*^9, 
   3.726157291638895*^9},ExpressionUUID->"c8a700dc-8a07-4a4f-b908-\
d8d91d506d08"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "\[Tau]"], TraditionalForm]],ExpressionUUID->
  "c314c097-655b-409a-bc61-6ef8b8cf5d05"],
 " Cascade Spectra of Final State ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"1a65391c-44d4-4097-b3b5-eb5752257238"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.725895997927475*^9, 
  3.7258960182383738`*^9}, {3.725896159866088*^9, 
  3.7258961607586107`*^9}},ExpressionUUID->"c821a82b-f3ee-45f9-8f13-\
86f404efc518"],

Cell[TextData[{
 "In this example we load the nutau spectrums of 1-6 step cascade DM \
annihilations terminating in ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.1"}], TraditionalForm]],
  ExpressionUUID->"26c264ed-6f3c-4a1e-ac3e-14f6eaf341c9"],
 ". Here we can see there are far fewer tau neutrino decays, as these require \
a W to appear in the shower in order to appear."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.6569740152601748`*^9, 3.6569740215851297`*^9}, 3.6569741348752193`*^9, {
   3.7258960226274014`*^9, 3.725896033581571*^9}, {3.725896253335609*^9, 
   3.7258962966190147`*^9}},ExpressionUUID->"e788ce05-9c07-4fc3-915f-\
cdb356d563ae"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "\[Epsilon]vals", ",", "\[Epsilon]", ",", 
   "xvals", ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3",
    ",", "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_B_nutau.dat\>\""}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.01"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, 3.644257377150648*^9, {3.644257434361697*^9, 
   3.644257640256255*^9}, {3.644257707534048*^9, 3.644257735875279*^9}, {
   3.6442600032445927`*^9, 3.644260076895362*^9}, {3.6442601126335287`*^9, 
   3.644260125127042*^9}, {3.644260206635504*^9, 3.644260216755534*^9}, {
   3.644260257841144*^9, 3.644260300439433*^9}, {3.644576371341427*^9, 
   3.644576438767619*^9}, {3.644576479640806*^9, 3.644576479920644*^9}, {
   3.64457654220582*^9, 3.644576615392721*^9}, {3.644576776040201*^9, 
   3.6445767991854687`*^9}, {3.644576834719887*^9, 3.6445768523652887`*^9}, {
   3.6445769381615953`*^9, 3.644576938607382*^9}, {3.6445771076003437`*^9, 
   3.644577147245116*^9}, {3.644577743925811*^9, 3.6445777948429527`*^9}, {
   3.644578047110093*^9, 3.644578096858204*^9}, {3.6445782810736*^9, 
   3.6445783067921886`*^9}, {3.6445783514558153`*^9, 3.644578351709989*^9}, {
   3.644580871103026*^9, 3.6445809542044983`*^9}, {3.644583694406518*^9, 
   3.6445836945720377`*^9}, {3.64458372703931*^9, 3.6445837383126783`*^9}, {
   3.64458377711351*^9, 3.644583837531001*^9}, {3.6445838746916313`*^9, 
   3.6445839220568733`*^9}, {3.644585052730834*^9, 3.6445851006510973`*^9}, {
   3.644585166144863*^9, 3.6445851833791313`*^9}, 3.6445863844322357`*^9, {
   3.644597848860992*^9, 3.644597868618737*^9}, {3.644597923287142*^9, 
   3.644597929359888*^9}, 3.656974933701758*^9, {3.656980023633141*^9, 
   3.656980023762002*^9}, {3.725896123119398*^9, 3.725896124813836*^9}, {
   3.725896255249155*^9, 
   3.725896264438868*^9}},ExpressionUUID->"f103cdd9-d1fd-4df2-b273-\
0bb8081557d8"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwdV3c8Vf//NzOy997r3hshUTjvYyebJA0jKZt2SFFkRUYKEUoo6lMio+S8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          "]], 
         LineBox[{{-0.07565609090824879, 
          1.9654316857023952`*^-8}, {-0.07179351038312529, 
          3.882668950595087*^-8}, {-0.06701912734617815, 
          6.445584214594252*^-8}, {-0.057470361272283894`, 
          1.1852459375754135`*^-7}, {-0.05269597823533677, 
          1.4491651238519133`*^-7}, {-0.047921595198389635`, 
          1.6939802434532954`*^-7}, {-0.04314721216144251, 
          1.9076526620774914`*^-7}, {-0.03837282912449538, 
          2.0773675493252812`*^-7}, {-0.03359844608754826, 
          2.1895010061102781`*^-7}, {-0.02882406305060113, 
          2.2295860475302772`*^-7}, {-0.024049680013654005`, 
          2.182277405576314*^-7}, {-0.01927529697670688, 
          2.0313151150230946`*^-7}, {-0.014500913939759753`, 
          1.759486844783154*^-7}, {-0.009726530902812627, 
          1.348588935916365*^-7}, {-0.0049521478658655005`, 
          7.793861063658476*^-8}, {-0.0044358484495434294`, 
          7.075029109992696*^-8}}], 
         LineBox[{{0.004435848449543688, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}], 
         LineBox[{{-0.11069340620015802`, 0.}, {-0.10521419164175516`, 
          0.}, {-0.09566542556786091, 0.}, {-0.09089104253091379, 
          0.}, {-0.08611665949396666, 0.}, {-0.08452778780733591, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15676#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwdlnc8l+/3x+1d2XvPNyI7o/d1iUK28kGUkv1GVMqIKIUkIYkkmkaKklGp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          "]], 
         LineBox[{{-0.2126328996767897, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.34095191438669314`, 0.}, {-0.33428277380397264`, 
          0.}, {-0.3300058029298561, 0.}, {-0.32572883205573955`, 
          0.}, {-0.32145186118162294`, 0.}, {-0.3128979194333898, 
          0.}, {-0.30862094855927324`, 0.}, {-0.30434397768515664`, 
          0.}, {-0.2957900359369235, 0.}, {-0.2786821524404572, 
          0.}, {-0.27440518156634064`, 0.}, {-0.27012821069222404`, 
          0.}, {-0.2615742689439909, 0.}, {-0.24446638544752458`, 
          0.}, {-0.22150459657587682`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15676#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwVl3c8V98fx0k2Edl7foaISmbnoIwyo68oIetDhAaJQgiREYUkiqSkUkqk
3HfIKCujVLL33qPQz++fex/Px33fe87rdc77/T5XysnH0nULHR0dsXn5/93v
JGtizAMFEGo7ATHTfMhEYfr4iSwFkHYUFrsozI+kV9vkdt5TAOuKH3Nl+vyo
8db9soY0BbjFderwkXv8SL5ebZg7UQE0HhSxv7MQQB2abig1WAE+3QgJWa4V
RJqClRM5JxQAmRkM0+hEEffQ47cXbBWga/Bz9sw+UTRUFB+mf0wBaBIlPt1n
RFGS+XHBYUsFqCkq/DbXKYrGI2cPUA8rwBkJ90k2EEMZixJ3C9UVwGnmck53
ugT613L50Ac+Beg/3h9845sU2kfUsjnwKkDbBMn8wJoU8n66o55u+yafNsk7
LC2NOsMLzA5yKIA4Pa+fqY80KtnbafVliwJcMvDFqpwyyDdFy/7HNBWaRL2d
BW1lUV5YlETQJBX2Jb4xEY6QRV3erT2i41SYZTF44f9CFpkYejo7DlHh37Oa
cl1mOUReSXcf7qSCifQ2E9UyOdRr++fcYh0Voidq3u1TJSFBA4O9qTVUeOXw
rV/NjYQsdictqn+iwtcmoaNZqSRUzkYNuAxU+BKhyP3wLwmll9leYXhLhbuy
W3em15KRpVhp1PaHVGAUSDyb409FlT0XMxSDqUAnqiz5l6KEyJLXYpaDqBD0
o/siv6sSuuGQFPDxEhXabss1pt5XQke7Co7+50cF+mYl4pvgLjTwq5fjihcV
kpr35J9kVkZM342v1B+nAtPMpHowiwo6zW/rmWJDBS9z+W3vKCqo8T83W0dr
KqTvoPaqGquglLZQ1YUjVMjJ1q+bjldBpJY3kyKHNv3gSxK9IrQbGTVI2Huq
USFcbnW+QWsPKuBQNFFVpcId5+1arqf2IG4TTc1/u6kg/LYk0iBqD+r4fJQ/
WYkKYyQxh9HWPcij9nrjOzkqJLDF3yZ896KYynnEtoMKPJkVVgqlqqi+tEbi
yQwFMpRNT+hHqyPvwYvk4CkKbPfwuqHyVh1t305WsZqggPfTCceLQ+rI2j1a
b32YAsA8Ps9joIF6+A+5HummwFvzhf1ZrJpo4fzn/NUGCpAyH60T2VooJSuw
qPELBboZWXbnftdCGl+o73PqKPB38IrNIoc2CpaObTD9RIHEw93X1wO0EctX
45kH7ykgvJtOgtV6PxJValA9/JQChlkrA49kMSq3vYIknlDAU1TY7IIjRqeu
KRouPKJA20EuvdcZGD3qjLPJzKbAAMuIvCG7DlKONQuau0OBwq91jF1ROujg
SBOkR1NgzuX96lisLvLKbjEed6XAY/ldK3QVB5DvxMjhm84U8LmuJdswdgCd
3/fvkNopCrw082ge5z2IAj8rGIXbUcDj7FiWDO0gipqLOChiRYF7F3t8b2/X
R9l6avuNdSjwKObGZ/uLBujRDVPt2f0UeMZBlSzJNUBPvjlrpWpRYJW+8J5v
mwEqPJ2o0b+PAidEyh237DFE5UmjqkGKFHhXXvAOFgzRj767Sk+FN+d7QdrM
O/YQ6tz5SvGIIAUu/ffPlAKHUI9/7c5lvk1/m5aX7BcPoSG2ReqB7RTQ5a0m
BE4dRgu7zUi/mDf9NqWktu83RtzhdJLsi2QoOt5qsIfTFBnIuG73bCLD+9V2
2afhFsgftPdrNJAhYYeAnGmOBco7ucOD+QsZ5iol2amVFoglrRJyqsnA55UV
m8JwBH3mkPbt/ECGd90X+o2ijiCzpa5G0wIytA/XKcWnW6Lg5OI/IvlkGP+R
ayJRboleKMfLj+WRgfN+64mFXkvE7bk/ODKHDDISnKNeVCvU0n1XkUgng9G+
c3V/yq2QdZ3NDeXrZKgpzmHvWjyKIt2USzYiyeDtOrSXS/w/9JaBZaA+ggz8
3OkjcQb/IUH0VssjlAzH2Nmk/NP+Qz9f8Y0/uEgGHxZRLXoda2Sf0XKI140M
rEne789nHkOuPibMS3pkyH+028Uu4zhaosZQbuuQIdM5pvB263EUPVRjvBeR
Idig/ZAO+wmUf/JA4jmNzfEZ+osngk6gGWNNoeldZBjTW2sqdbJDl8lkhRFR
MlxtqP92xsAebRtwNY0SJkMXy+Xn3NfsUVZWjo+8IBleaNM491TZowp+idcu
vGRIP3Ew/c8BB8TMyL+/l5UM5+gvR/6QdURJvQzmP5dIELzia3lK7RSSvad7
9tICCTIOeC3NHD+F3tiEJAvOkeBdyenpuuBTqKPpz3frSRIc/vhI2bHmFBIr
n3Vs7SdB6U2X+9vtnNDj9O5z9c0kkOrLYOe45YzKrcpSyvNJUFgpB3p6bij+
791W98ckEB4Um1H1cUP2OZe5eR+R4AWHxpWwDDe0Prc/hvaABL+sXAjqihvS
ToIr3GkkuHRaprOhiIbeNX9ycbpGgsGzdy/y7/dAMQGPHnCEk8DoAHssna8H
Oi4Z1VUcSgK6khsuR3I80KqPkQ37ZRK0Njkw7GI/jdS5vhi/PkeCD7Zv2ZV6
TqNi0+bdTI4k4B6uUOnJ9EKRi4U+hSdJQH8wuaG4wwtZ37tZcPwECcwvSQ3Q
855BixOW8i+sSVA0b3F/JfoM2nujXcjGlAR5zM8WrgR6o1eff9Lla5KA511q
obCmL3pmONhoykeC+FeCqvIu51C+XpS6JC8JygZ/vk2NPIce7adkz3Fv+sF+
O8zoyTl0f88Zv1QOEvwXrlbnMX0O3ZJYFOllIMFTo70f3wafR4HLWz0uzMnD
QR6xxYknF5BRnizD3SZ5oJKi3K33XUT62dVeZxrkYdGxtfvRqYtI7577N/xF
HkxUFNQM4i4ireSCJwPV8lB6zjNvsxYjpZC9Fkrl8sC5a0Ez5U4A4jt28N7H
AnkICzada9oeiPqYXNRGrsuDU1xByZjBFaQj6ZUaGyUPb1QSbGTDrqBMjQvL
StfkoaXGYLr9wxVk6xXx1i9UHqYuJbk83BeMmr8+VGO4KA8TzUWMTEohqDxj
UE3cRR7o241+Hk4PRaLFk6kfT8nDi0U34x9loSiwaXHZxUEeItxIuvm/Q5Hq
FqaSp8flIY/Wqc0nfRUV0OTVNY7Iw7vnF2Umn11Fd3bT1I8ieTC2cD5s3BKG
lox90pa15IEwjFUVWQlDR10vrqRryIPuiMhuVfFwxJ0WVdK7Vx68LYJGDnmG
o8j1PHUfBXnItDcPZWGNQBdqR9RjBOXhVtJcVojVNWRhf1oD5uRApnxaY5AS
jX593lMdOyMHgapHlCWORSM3tXXLY1NysP+C6lRBRDQK4k70mhqVg6p/2/58
6olGjyreZIn2bu799+P96xnX0bo8PdOlJjk4p1QV8FwuFuVPp7aoFMiB1ey+
b5VX4pGq3SmH9SdywD2r9SW1OB5BLXWiNk8OyqkuAm3T8aj9wQdGxxw5qE/e
on3NOQHRHe1Xj0+Xg/N2aaemSYnoWIlS1li0HHivzxrkid9EW69+8sxxlQMj
80Efd/Vk1PBDhTfQWQ687mt9O3UiGaXsznxncUoOUlrdpu8EJyPygD/rhp0c
1BaY0td+SkamhuQ8m6NyUBf3W5187BZK4Yzt4zwgB9pevo8dIm8jSrqFbYCk
HDzlwfXdQmlobu49nbm4HPRrtL1L0k9D740pj+VE5QB+8X9KPpuGzNbpl1sE
NvW27TgZ9jkNnXMsuqXIJQf71Cl8UqF30Ht5/ua+dVloZhy70/cnHZkV/TIw
/SULe61nGE/szkQB1OcDCx2yMJJWrXjzTCbKfhAalvFNFnh/SURrPMlESwly
5eNfZaE+/pXogFQWyvTyUY2plYXJy+KTJzjuo2k5BtmaN7IwkNLcGLztARK+
1/7Ru0gWaNKJx9t3PUAHdzx24H8pC/zzX294HnmA0raY3nUtkAWkeeqnze0H
SKc7hWdrjiycwfsZ9SWzUWIalV43URZSmSvYv+nloHdc65kjcbIQf+nOW2f3
HDQQ2aSdGCsLfzLTTDTic5C634WA7khZsNz21Kn8Zw7qOVI+feWKLOTIa8/j
iw+RCrtl17vTsvAmNuJQTnkuarlyqWyv/ub7lRUxQzGPEcWIM3LrAVlQ+rJT
zvbtYxTK88CiTUcWfjuM5W0feIyU8moHz2vLQu2NQjVf9ATFNgtwF+2RBZFc
bev5pSfooEyxi4q0LMRZ6TolX3yKimvnOJX+yYCDeL2rb9lzxJkc2bG+JgPL
oivp9XPPkctJ4ZyGPzIQRpf5K4b6AvHM6aqfWZKBMQNHLeW7L5CPyE2ngkkZ
MHtypT9NpxCRvXe9pXbKQKvaruvWyi/RXV4vR1KpDEx2Km2X1yhCR9dcpWqL
ZTbz0yLxun0R4hh06HN/LQOvPgv57I0oQpeLrVzyX8iAS27mCafmImRnq+Wu
+EgGdFtenlP0eo1Es9h89yTLwDPx6mOLL9+gtqitKm2JMlA1M/OLufMNuuG7
MXshXgYiBWyO0piK0Zru3Pni6zIwWnBMWsCuGHUO/LioESoDu5aYmY3Z36IM
6pMQfEYG/FjWUNylEnSUN0en57QMOB0PonY9LkEcaxn0V91lYP4U/fnojhJ0
uSExvMJZBtoUe56Mq5ciO9+AKP3jMgDr8HxjvRSJFRsmGBvKgFz/0aTiO2Uo
U3co85iUDLwtcFYniRHoFn94IIPEpt9/6wZ/HCNQ7LiE9QtRGegIo9u+mkSg
gNu2nMyCMtC78rFPmxHQkdH6oOJtMmDUW8VuGwJo680iG741abjJciD+ePBH
5NkTytP6TRqW6PRPGuZXIqc3YlPBbdIgtw3nkZsqkU3MuzpqizQUFzqdNF2o
RAf3LoSGNUjDi43ERSdchcSjadMqVdIQxFqqU99RhVp2mdUnvpQGDjHrfAah
aqQeIhJpdkMa9gkd9OJtqUV2eZfipWOkwcz4auXO9VoU0vQ9ZSlKGhw1R5fi
yXWoWuJWXma4NBxeEuvfFVqHjgJH3VSgNLyWGg+f3f0Z+dJvsCd4SMOuuoWH
3Y++oMfhPTebDKThLyHzp+NLI6p/itJzDkqDCVODByN9E5puzci+qCcNEfFr
p2L3NaF9srZFEkganJq2yj3KbkJVVV/bfFSlIe18gG4ybkY9jJUC3LKbz4Ps
eWtkvyKB6Nx7FvTScP4RjSl8RyvKaPTIWNyQAivGpQRG9VYkyad0N31NCmxa
FTxqT7QicnZx2sCyFNT7763gftiKNN/XJAdMScFLeYH2x2pt6OTM6PX7v6Rg
dFZgNc6zHeXYKPnPvJECR7//anNYOxA5a+7C7SIpGNTWmWXZ14EKBovPa76U
grHG2rgPTh3o9Tl8NqJACpjzDBwEPnSg6hsWXoI5UnA59LzyPb8faBTOOekk
SoFZca/B2aWfaBflrVniaSko0SnQn9TsQj0V2oEn3aWAYp89neXdhZLsKnKp
blLw0+qk+uPsLrSQ0LBWdUoKSI0H28rYu9G7pf78VRspqB7ivLbR240MqriZ
nQ2l4BjnB73iph5k73CaUJXd1K94dyKtsA9xr06PbZGWgh1FlylHmvvQxyQ/
/maJTb82wgP3z/Qh2erQM6dFpOC9ZuSDIuV+NLYzVSSLZzO+zXtd/HU/8v9T
eZGFfnM8Hs+7Ep8GUNxtMeVfvyVh0nKC7zjPMLpvymp56ZckmFWKTPtpD6NX
jIvnBX5Iwp44deZOt2H0za/+rVWbJDy/8PlH9PthJGkdhOs/S0LY/DZPF88R
9Ir/h9mHt5JAp8jnm/19FHWk3jqTdVMSRv4j7b88NYHGzEMT9idIgsbwQ6JW
ehKtM3u9/HVDEqI4rrH6HptE0gEHFgWiJSHDYibw68dJ5GkzdzkxWBLi7756
PJs+hTYELW5c9ZSEbffGk+/umkGy6exPnfUloTIOd2wIzSE/lD7McUASRum3
t7dqzKHqPrJssY4kRNS7P++ynUM0BYN7LNqSUFbSZ5uaPofy34cmPNstCdIv
WvQzxeeRcvfi+WUJSTi9/bOmucoC8jeCS/yLEvDl5mShcPgSErz5e859RgJ2
sCxvMc9fQqU//niWjUuAX4H016qvS2jttKq9Y58EfOwMvuIvtYzC4vL18psk
ICnRWXe9chnFtdxiR/kSkP03OraUbxU9tPO45+ogAde51Mxyp/+i+8asviwn
JKDwHh3tpugauqv5RO+ptQQs0AkGVxxaQ0mCo8MzphJwjXFIaerhGrra5r77
srYEFDV2SJ21X0f2Ju41SUIS0Py5uORP1wYS1KbNEq3iYNoUdDSSgx7vUGCu
cmoSh526l6VzSPSYSzgvhfGLOPBim6ERPXrMtDKkZVwhDtTYCbOZS/R4scgt
8luhOOhs9c9ZHKXHLQpuIpNx4rArzegUT8sWHCviqi9sJA7xn99481dtxUaG
X7c6HBAH+tRDTZHDWzHT+f1VOUgcmmvpnyizM+LQz3wHFFXFYfSMvfZuK0bs
f6laR0daHPw7u1iWBxmx03eSttuaGBwZmtH4zs+M1ZPHdr8qFINpmdO7q/NY
8VK59dzSUzGo07/xiK2VFReNVbzUyhODC/SjVrc2WLGS3l3lT/fEQGIqaDXA
mg3LzBordcSIQcKei5lJrOx4m/kzyoaLGLRkf98td4UDD7L5Sh4WEgM3SpSQ
1D0uvNZpr9G9QwwqtMN6jRq58I4XppYXuMXAT8yktuQfFz5opRCRySwGLqWc
pFIVbpx9d2h4blEUWofWRHlTubH9zpMv7raIwn9VLwM/uG/HHaaH0WSsKJxI
jKU8ovDiGQmNY2FRorCYLnWO1ZAXM8+RfAXCRaFLweN7igsv3pfCmK0bKAqD
V52Wle/z4ltdwJjiLgqOS0FRHkI78BEftQakLwrce9iPyOzgw58TZe0SN0Qg
pmLXO6mdAtheyzZf648IsDGWmYebCeC5wbiVoUUR4KmZStxxVgCLaC3f2j8p
AkKfyiRrigWw12Bdw9ivzfi2pILzBwXxNk0frF8qAkttibHSHkLYqr9U+s95
EUjo/rivtUMEj8RN+eb6iEC92oUPSfSi+LK6DGHhKQLnj8fXXaeK4odxN07k
OYnAK6aOdIkronhJzeHW0SMi8GKwWWxOVgyn3djK9EJJBIwk9nzyCRHHnarm
o86jwvBLwY/+aKEk3i1mIftyQBgmZI2ULnyWxNFbjzhsdAvD7OeRE+8GJPHe
Vsv2tG/CYCRjcqVUSArf8LX+2FApDHzLbutR16Tw/qcn76hlCsMffk1bKxdp
nCnpdYjdShiexb3RStSRxQvMZyJszIShbM4276ODLD48fYbIPSQMXUzaByVC
ZPHSBx9VHR1hiDu38sGhXBabnzgv5acoDGnjlZvdWg7TpQSudjELwz03PClo
JI9PsV9/8uq9EGwbttaLCCZjnjscyKJECMSXemJZHpBxhXxiy2SREMwj4ZWS
SjKW1kv9S34qBAddm5SyWCm4PyDXNOuOEJD1Ld9HpVKw69DH2Vh/IXiokVqy
VkbFHh//aLgqC4Hmuyw3S7IiFjYPbtyyUwi43e9dLbJQxJ876Z3vk4SgotTS
3vCSIqausNz4JS4EBXuv27B8UcTjSgJdRziFQD16ZmnRVwmfydgThsYEIc3w
b0Jh9S589qLXZ4GHgpCim7yr2UQFD+i+Nz6WJQiqJYNapm4q2JqDoyElXRD8
Zw5vnwhRwZoPnjbx3RSEXtaaooQiFbzly1gbb7AgLEUd/3ZOdDdOEvfo5rIR
hAUO38eJC7vxq0+uC8wcgrB676uYEbEXyya+8TNkFoTXAfSJKr/34pTjjMuR
WwRBYmynie7fvThw+uEq46oAtH87ydOmpor1hAY2GIYEQOGH+4/0V6q41cuJ
lQ4EoHwjfPvhF/vwAq+D+Mp5AcgNyPxPukYd9xcvtJn6CMD+G096zUfVcYtt
TGzOaQHojZGxfMSugV9kvVkxOyUAQ1uLiUYLDXxagaM110wAFvkHi3h/a+Ae
vdIoK4oA2N3cO5q2ronrz/LOPu/iB44bpp037Pfjsh1P8rb+5AfFW0VtrJH7
cf5bZH+8nR98ve+5vH62H0ete3xhrOeHR1xWksnr+7Hedci1K+WHoQ3PC5ez
EC65f+Y42y1+6De9zyI9gXFuU02l6yF++HvMfV+nlS6eEuxpZdfnhyyW2atb
PHTxPqeV/pc6/ODYvKscBevi2gXy1g01frhWZKKz+lgXTwjFHEyR5wehk2/S
L/7TxXtdTD5VM/ADyT3CRbdQD1esNFeTyvngS6uRl7P0Qdwj9bNudDcfWHDH
POE3NsTjeeXVKkp8UO/Q2EV2N8RLijmVlyh8QO6+pqN3zRCza3p9YJXkg09m
2pV1hCHeZ7lRSOHkA6epETHlfUb4Rph0msfwDggPScsPIB/Cav2n3Ubv7oBK
BnWPN9LGOP7h3y2jW3fApI/b+2tnzPF8s5PtVbodcNApMtUywRzbrNe9EFrj
BSONE1c0X5pjaes0u8PzvFA2czvhxKI5fsOsWvy0lxfqPJ8nnMUWuPO0t4d3
OS9IK/+u0vhigakqvU3zF3lBIjohcGH8CK75UJ2xMcYDTxbE6Y5YHsWKS8zR
D75thwfPhcMGrtliZgebR0Q+N/gG5a4ZFTrg7+8fHh6R44LZA6+qo8EJWzOp
1p4R5YKw4trnxfVOuM38k/48Dxcoh9d87ulwwi19gzob/7bBLj3zYcqsE65n
Iant+LkN8uEgx00pZ1xx9ImMTvw2kPAP43l51Rk/n3i2lrrECbE1L8euarlg
xX0oUGySE2Tm5hV/GLjggpDG5ex+TmivESJRLV3wE57puWfNnCBhMy5e6u6C
H6orj1bmc0JjXT/39dsuOD3iVfu0PScExMYr80y64EjRt88NazjAJJe01yfJ
FZe+Muk+U84BBsYVXF/uuuIJoz6uW284oIXbRVs81xVb+nGe7cnhgJcKJHjy
1hWLNzrvuRTKASpstYdHf7nityHcJfkaHDD2KZt1RNINj/E9GmlW5gDxzr7z
/1HcsHiBltAyiQNOXltbeavihiM63AIP8HPAgXvbo+z03LCFygftzjl2iL62
wS3r7IZH+jw+chawgxwpc29GthsWufRvdk8OO+jLdkT8l++GzbhuSx9PZ4fD
qw/Rx5du+LUWhD+KZocU+5r3puCGQ2/xG2BXdpBqzvvzptMNCxlUfvYVZweR
MIHAAR4aNum0+ZvCxw42mb/6vIRoOPTclMIHDnY46Vj6bliChocyheJY/7IB
aZ7r2uudNPxq2cc8+zsbiJjy+ubp0/DhJ6JtrYlskDbnGKd5nob9Z/b7yEez
QXVPkObxABrOUXNguxTCBko2QeoeV2h47dMDHXFvNpjauqf7vygaft4n/8zd
mA3sk+/yeqfT8E+KkVGZHhs0he5L4ciiYeazHv2cmmxgRvbxvZtDw47/ngoV
kdngXvE285gCGuYRVYlcZ2QDSaJ9V8EHGkbOllIW66ywIp7L1fCRhj3zz7/P
XmCFlEFa4+9PNFylXjxn2M8KITmGTI0NNDwT8j0u/ScrhLXozhd8pWGxmhXy
5FdWsJp/lBvYvqnnPy2HJGCFpBzWrec6aTg7w+7PwFtW8OJb3/Kgm4ab+q/c
VnvBCnw8A7fL+miYfA6+dN5jhXRmycjXI5t64vXVSUGsoEtIW72fp2Gmb26t
l85tjuf286PZEg3vEYv2rvdghY6Be7GNKzR84+nnh2dtWKHt1fGKlHUaLpkb
x1XmrJDvsP109z8aHtTg/MVvyApvjN16+ba4Y1Rrvv29KivsOxfoacLkjk9z
nS3YpsgKMSZuV01Y3HGqdZLhKVlWyPpP3UuTzR3PDLRdYeJlBWotN62b0x2L
7lwStGVjhV2SqSopXO740HmB10/pWSEwr/Kg5nZ3nE1/fMxihgUiV+zxoR3u
uNEo6FrOMAscOX83oojPHf9NyJBc6mKBfT0P61kF3DH5+4cyo28s0FjPsXNg
k4+Kd1vfbdiMN/7LeU/QHYe60s1NVrHASzfNWiTkjp8VSMXpvGeBe18+Pa/b
5J/zeuTkIhZw6q7gQcLumEnLpXIwnwVS6+X1MjZ5d9g1e/VsFvjkaxM1sMkO
dY9WY+6wQCBzI1lAxB3f4K699TuRBVbOPHLfu8klx0Z3KUezwJ0f+yO0N3kg
k+1LWAgLkH5+KNq1ydxDCm7t/iywFPKYsm2TtRVN6cneLPDisj1Px+b3PS54
ZwS6soDxjvvJcZssrErevt2OBTgmFL/LbfLnxd5reZYs0PT4ke2jzfkHFt/9
s/8QCzTk2u/k2mTqxf982jALZEaYHnXc1P9TjWvg9D4WUAmSrruz6U/MSq0N
vSILWFmYXSjjd8eapWENqTIssOPpFuVPm/6OXdLWUxJmgZ3W8tXFm/6nay4V
V3GzQDcfmk7gdceH/75QOMHMAt+fHjpiweOO/5R53J9dZwaFB7eCl7ndcf5l
Gb7oBWZY8gxciNhc3+P7f18XH2cGA5a7lTc2159tI2XjdS8zHNvVr3aMfXP/
hLCN9DZu8quMH0mb+0lYp8ou4BMzJL9lY2bcuqmXLvjrtvfMQNDuEMfpN/WF
zb7TesIMcWEv0l79peHxiI642+HMUPB0V6v4NA1n6Cdt2RnIDOR9ds4l45v1
hsnkYoUvM9yauqCjvpkfBVGE4/RJZlCh/I0Y76Fhr5hHew6pM4Ng8+QLqc18
FDV2fNytxAw2I0Knp+tpuJ5dWMxfjhmKRlL35NTS8M64OKYcHmZYps2HlBE0
3GlqGKTBygz5GkHcEmWb+bSNfqbpHxOwOQdULL2h4cmECz/WJpgg3b+8aSaf
hjMtlMyS+5nAWdu5AOXSsNn2kQrKTyZ48qNl8Mxm/XmedKLAuoYJBrvGSs4l
07D3bb2QwgdMQPpU5yobSMPi1mvzBmlMcExLqTF2s/418he7/45ngp0Hgk52
eNGwUhrFku0yEwQEpAhIO9DwVDq3nIs1E2CJnX8u69Gwz/2uzwLsTCDySPKa
KAMNtz27N2e2hQlGV5mvlf9xw+pldsKRq4ywlcu24uCcG6b79tNjYZgR7BfC
Teh63XAS+3eWr1WMcOFM9ITeBzdc7N9kEBPMCF9DLFSPn3XDwhHx3h/9GOGi
Y9RYAM0Nh9w0TVnxYoQmA/eeqyfdsFHBl0G3E4zwTQzCLA+54R+9NREH1Bnh
caB6+JiEG14zgYq12a1gIvSX6X6lK3Y8HjK2Z3QryFY+dbix2f8+0RCPZ89W
OJdM3XPqqSuOD3t/6kfjVvietJBZvdlPJUtK6IqfboUTJn7T8Y6u+IDMS+Tj
uhUC/LCv84oLjll98K63gwFeWi3j81wu+FzoapldEwPMGJNVPmw44+PMRz58
/8QA401Ku+YnnTGVjw4aXjFAmbJivFy9M/6sbP+p9AYDCNw+u/w8yhmzuQs3
39RhAP+89Jeiq0445lvSoO7jLWAbdV2CqfIUji0K586+SA//uFrMZnbb46Zj
OTx/9DYIzqR3MonDlviP4wWLGJUNIuzLglFFuSWWP60fLyy5QbjpVQfJp1ji
4MvDrFrr64T8gHNltL4l3vlAgf7y23ViXN5gufLRERw9VjS9rrBOPB9WDehw
t8C6V6rq6fnWiNMe3kcEmU2wV+RttiSGNcKJbeDZ43JjnJbgZiQ995f4kGIU
9NHfGM88YKnSa/pLjF3RNY4ZOYwzq03Kwq//JY7TFrxl6g/hP1ztTxg3/hDv
ioMV/G4a4qLswUjW4VWC2i2spBl5YLNfD1+UalsliJxG0kv9A1jw7qi7xsdV
Yru4oWURwwEcnDx52OPuKqGx65i//2U9fDhicVud+SqRrNeRTvbTxT2ujKnR
JSsELULTOWwbxrxOzNH3c1cI5/WRLYV3EDawZ71UkrRCiGjErbnKI/zUmvPE
iNcKkSujTvE9uB/7G/JJGEltxrN4HutN0sIcFLk85phlwows8/A2UsdYjpQm
cXGZ+Oe94F/9TQ2fk6JcV3NZJig3T2oZ+6rh70KKnjS0TPi+jtf2ztuHs9lU
d9XMLRGe5xIu1MmrYvWJg28jTywR9c7twkteu7HniMHjTKMl4mjyWOKFzf+n
zAGjO8WqS8TOkESyW4MKZvhtEjTEtUT4nBl6ybRLBTc2HMUGVYvEmzW60zXt
u7DLC5caRsVFgkVuSoZBRwHT6Z8VdxBZJPYNdtZaVVDx3Z9X/EpYF4m7y9Ws
2wypuIUxVcZzaIEYZwx1hGMUrGNXF9KctUAM9qhxddwmYRFWJfW7PAtEKOvZ
rlgrWVycqZmwQLdApDRY5/8alcGWew2HTKfniQShtam+qzI42sHxFl39PLHn
F1+42ltpvPQmacb12jzhTv/QtkRNCicZZxkS5+cJIfE2t8hOSazY+zRT0Gme
2PHebbd2uCR24fhk8gXNE11Tyt5tBRK4xWn5sfLKHGFKC9TvJIlh7xUGupih
OWI9NzZDM1EUs8ZzH+tvmyNGTfmCXNdEsE4phTHl5RxxZ9paeLlbGD/jsjv1
9/Qc0U4zMAz7KoiNct1LjtrOET/WmeP+6AriAU0/rueGc0RB0nD97jcCWNgt
/oOj7BxRIq6svu0hP45+D0LVv2eJrXFt2mce7sCylg2+EvWzBLuSXeGQwg5M
DP+oCXg3S1ytZ+g/WcyLl3jm/RRSZwnOjw+zzNt4cNLjf/UR12aJ+ZNOA19o
PFgRcch2nZ8lOpmM1Q9tbMcuHnItiRazRJZJ7iHNvdsx3T8VyhiaJQoYX8bl
tHLju7dQ6AHFWWLy3WDFih83biGOKS2xzhIeO7a4XI7kwpg/JuZE5QzRFbdi
fWidAzdyPi/mfDVDBP0lVRef5sB2jC19xP0ZYsdX5melnew4uf79osStGSLf
SepHnxs7DlgQ0pINniF84iaSXt5hwy9bnoxPqM8QceC1aP+PGet8bhDIIs0Q
qecyL/5zZMaNH2cPHOGfIURbb+kxVDPhtlPn1T2HpwlfrODgnM6IDcST76zZ
TRMkifaq5DMM2Inz16yj5jShF8xg7zS+BYesSR/+JDBNuO+btmv32oJLfr76
E9cyRSSnBm95GUiPqaktJySMpghpt6MeByL+IYNI4dfhclNE62qE4L/SDeTs
58QxsmWKkG0vlm1cWkcZVnPvCz9MEvXPv+fqXVtD26OjHUQvTRJX9qgUVIj9
Rdu4ecT19kwS005RtikvVhH1n63/I+5JQrvqW/vrlRVkOPWgkW1qgjiWWZnr
b7iCQutVQlofTxD9ZgfTmJeWUEbZpe9qkROEvzF3UP9/S6g0/+OuDOcJ4uKd
0tWgskU0F32kx0V8gnjgo6Y5kLqAtgXcUa/7O058Mqi4/3zbAlKg9SYq/hgn
DvZMPaXGziMX/bO6S8njhMugbADX7TkUurf0zvGz40TyYkKxnfQcuidDP1du
Nk78p7rnsOybWfSN/mZ2FOs4UU6WK6gZm0FzMx1/xofGiMgH+3eeiZtBXD2S
VhZVY4SzrT63pOoM2tnk/vT1gzEih3Gc+WLlNDIqL2QQChkjzCQcGRXlp5HL
s5UTV+zGCJbR9+bMSVPoaobO616NMSLoqt/fB0xTKDM2msNAYIyoq5y6lRA+
id4FNrvkL4wSb9TOv7VhmUQjvysrV/hHidkJlpnm1yMoa56L1NA9Qtz7Vfpy
94Nh9Lm2dFDn3Qhxxr34ZeHEEFq45/zw9a0RIpyj/Jjn/iF02OitVMahEcJO
RlXx2dQA8hM71cMlO0LIzbUHaJgPoPtzbFnhG8NE/lZNG443/Wgpw17Us2iY
0M+uzTib2IekzrH86oobJoRMihTnGPuQieGrO5buw4TTJXar26G9KHuWUUBT
bJj4JExdXY3oQWYGz7azRg0RU7XKEeXxv9ElkWPNl08NEe+TXpy2q+5ED2fo
Ema0hojd1+z8dJk60W3WXMN24SEibVL/XZ7BL/Qn/ShHx8wgcbXKlci1+oly
p/8y5R0fJMjJG/JB8A01V+V+ElYdJKyeyQ1Mj7ajP3fMI+K5BomQELsDe4Ta
kcXBHHr/qgFifJhy+/D1VrSWdnjtoNIAMay8Zi9X2IxI3gvvSlgGCH7/W/7R
LM3I8kDmpZ39/cSKcjPH2YZG9Hhydok3rZ8w1p/aGuxej47q3Znto+8n3jBd
v3xWuhaFCBwotO7sI5a82792UWtQ/sSE9+fiPuLKUr7lhnY1av+Yoohu9hGe
zwSY3Gw+IbpUnYmXnn2EbGql/v3LVUgpoYT/gWkfkeFpyHA5sRJZ697yuCPZ
R9w4/7KwYG8Fejo+PBTa3ksENmy0bx6T0De4mbvwopf4e8fLS2zyA6JL0XJx
j+klstvO3U7+XYasdRJ6zXEvUceg0uo+/BZd5dO4XynUS3ja2Rb60RejgrE+
e7WFHsI3R4bKRn2Nttze1yn+pIc4XbvvPtfjQqR4uic9KbyH8JyfGdFce4Zs
cIwtk30PEfCTx6yjJh89H/39bZKnh7jZ1uLVQDxEr65wKVT+7CbO+D2X3zX5
ALGQnR/nJ3QTz1kidhsHZKLXl9lyLq12Ecm6bGSpq7dQwY3oEreiLiJJJZ6r
WiMR5WYwNVqd6SJsN1DbHodolFkQ0a9D6iIMB6q2qlaHopT3W1YVe38TjPxj
Sm2W55GgVezTuo+/CWPKw+nv0afR/wDtpBR6
          "]], 
         LineBox[{{-0.3392531333116301, 0.}, {-0.3300058029298561, 
          0.}, {-0.3128979194333898, 0.}, {-0.2786821524404572, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.4560811701545825, 0.}, {-0.44976098740512027`, 
          0.}, {-0.44548401653100367`, 0.}, {-0.4412070456568871, 
          0.}, {-0.43265310390865397`, 0.}, {-0.41554522041218767`, 
          0.}, {-0.41126824953807106`, 0.}, {-0.4069912786639545, 
          0.}, {-0.39843733691572136`, 0.}, {-0.38132945341925506`, 
          0.}, {-0.34812483021071716`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15676#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwVlnc8V98fx6nsj1329rEjlT3OQWVkhoRkfj4iJAmRUApZSVJmRim0NIjo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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQ3REZMZ/17cP9DFCwpYZrceXPe3D+mp6OHWmbEfyl
c9jOBeci+NP2MP3UfXgXzq/488vv0Yk7cL5NzetfXjNuwfmHq88EyZhfQ5j3
VYa17uUpOD9n9Zzp3L4IvkmijNbMDSfh/ENnpP23lJ+A8+8vlpr5ivUYnC8Z
JKEbrnQQzjfc5RdyMGctnO830Xfe91+r4PysDJ8Xup0r4PwlYl41s5YuhvMN
nnV5PN8zGc6faBLKEKxdBOcDAOuPWr4=
          "]], 
         LineBox[{{-0.6863396980074532, 0.}, {-0.681066414329966, 
          0.}, {-0.6764829338664331, 0.}, {-0.6673159729393673, 
          0.}, {-0.6627324924758344, 0.}, {-0.6581490120123015, 
          0.}, {-0.6489820510852358, 0.}, {-0.6306481292311044, 
          0.}, {-0.6260646487675715, 0.}, {-0.6214811683040387, 
          0.}, {-0.612314207376973, 0.}, {-0.5939802855228415, 
          0.}, {-0.5690550419507858, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15676#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwVl3k0lV8Xxw2FjBeZ5/leMiQydo4QimRKioyXZMyYFCmSoaRUZIz6KUqF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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQfVW2fNdZzZf7GaDg1ImdTx12vYDzv8xNXrJlCoLv
5bFdcY4ngv9tTpxM9ubncL6f21pBzvZncP6fGV5/XPSewPlbargWV/68B+cv
/SrDWvfyFJyfs3rOdG5fBN8kUUZr5oaTcP6hM9L+W8pPwPn3F0vNfMV6DM6X
DJLQDVc6COcb7vILOZizFuG+ib7zvv9aBednZfi80O1cAecvEfOqmbV0MZxv
8KzL4/meyXD+RJNQhmDtIjgfADnBWbU=
          "]], 
         LineBox[{{-0.9165981887396715, 0.}, {-0.9082825004152018, 
          0.}, {-0.9040578876296842, 0.}, {-0.895608662058649, 
          0.}, {-0.8787102109165785, 0.}, {-0.8449133086324376, 
          0.}, {-0.7952246786477034, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$15676#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVlnk4VV8Xx8k8lHuvMTK73EvmDEV7G0tJSSoyu4QSZSZTk0RFGihRKFMK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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ/dX/qIi429v9DFDg/m7hOa53b+D8hjOG9ZdXIPif
OgIfpMgh+NcYJy5q53wN58//zK9+9v4LOP/UiZ1PHXYh+F/mJi/ZMgXB9/LY
rjjHE8H/NidOJnvzczjfz22tIGf7Mzj/zwyvPy56T+D8LTVciyt/3oPzl36V
Ya17eQrOz1k9Zzq3L4JvkiijNXPDSTj/0Blp/y3lJ+D8+4ulZr5iPQbnSwZJ
6IYrHYTzDXf5hRzMWYtw30Tfed9/rYLzszJ8Xuh2roDzl4h51cxauhjON3jW
5fF8z2Q4f6JJKEOwdhGcDwDwhXG/
          "]], 
         LineBox[{{-1.0317274433977766`, 0.}, {-1.0223470456241772`, 
          0.}, {-1.013897820053142, 0.}, {-1.0096732072676247`, 
          0.}, {-1.005448594482107, 0.}, {-0.9969993689110717, 
          0.}, {-0.9801009177690012, 0.}, {-0.9758763049834835, 
          0.}, {-0.971651692197966, 0.}, {-0.9632024666269308, 
          0.}, {-0.9463040154848603, 0.}, {-0.923677624717265, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$15676#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.003799686711486782}}, {{-13.815510274069974`, 
        0.09530989591002416}, {0., 0.003799686711486782}}}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.01}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.01}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, 
   3.6390767166598787`*^9, {3.6442574366310177`*^9, 3.644257640914957*^9}, {
   3.644257708990077*^9, 3.6442577371366043`*^9}, {3.644260004751333*^9, 
   3.644260077952415*^9}, {3.644260115987558*^9, 3.644260126350301*^9}, {
   3.644260188124305*^9, 3.644260218133224*^9}, {3.6442602591886263`*^9, 
   3.644260302050921*^9}, 3.644316648114072*^9, 3.644576451074027*^9, 
   3.644576487542392*^9, {3.644576549658166*^9, 3.644576621616087*^9}, {
   3.644576764562796*^9, 3.6445767820862637`*^9}, 3.6445768574554853`*^9, 
   3.644576945003827*^9, {3.644577113369245*^9, 3.644577140083241*^9}, {
   3.644577753012301*^9, 3.644577802627615*^9}, {3.6445780569311028`*^9, 
   3.644578103866412*^9}, {3.644578289753704*^9, 3.644578315580659*^9}, 
   3.6445783615710917`*^9, {3.644580938831132*^9, 3.644580960697556*^9}, {
   3.644583691767996*^9, 3.644583700885569*^9}, 3.6445837471615887`*^9, 
   3.644583847010324*^9, 3.644583892827443*^9, 3.644583928512251*^9, 
   3.644585111858407*^9, {3.644585173229665*^9, 3.64458519082297*^9}, 
   3.644585513469898*^9, 3.6445863990953827`*^9, 3.644597859482862*^9, 
   3.64459793577026*^9, 3.6569749437404423`*^9, 3.6569800300558558`*^9, 
   3.7258961352719097`*^9, {3.725896258406053*^9, 3.7258962659012136`*^9}, 
   3.726157293123817*^9},ExpressionUUID->"7378dbfb-008a-42b6-8970-\
8798f81c4bbf"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "e"], TraditionalForm]],ExpressionUUID->
  "ecbc8c6a-5dbc-4e64-8dd6-c85919177c69"],
 " Cascade Spectra of Final State ",
 StyleBox["W ",
  FontSlant->"Italic"],
 "bosons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.06"}], TraditionalForm]],
  ExpressionUUID->"4ad551c7-5511-4be6-88f9-e046f27431c8"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.725895997927475*^9, 
  3.7258960182383738`*^9}, {3.7258963962133617`*^9, 
  3.725896409095798*^9}},ExpressionUUID->"fcdd28e7-4c1d-4843-868e-\
85ee8632446c"],

Cell[TextData[{
 "In this example we load the nue spectrums of 1-6 step cascade DM \
annihilations terminating in ",
 StyleBox["W ",
  FontSlant->"Italic"],
 "bosons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.06"}], TraditionalForm]],
  ExpressionUUID->"394ba1a9-1750-429b-aafa-5aec16fc2539"],
 "."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.6569740152601748`*^9, 3.6569740215851297`*^9}, 3.6569741348752193`*^9, {
   3.7258960226274014`*^9, 3.725896033581571*^9}, {3.725896411495592*^9, 
   3.725896420397263*^9}},ExpressionUUID->"99cecbb0-545d-4048-88fc-\
158c0d34a966"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "\[Epsilon]vals", ",", "\[Epsilon]", ",", 
   "xvals", ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3",
    ",", "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_W_nue.dat\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.06"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Epsilon]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"\[Epsilon]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.04"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, 3.644257377150648*^9, {3.644257434361697*^9, 
   3.644257640256255*^9}, {3.644257707534048*^9, 3.644257735875279*^9}, {
   3.6442600032445927`*^9, 3.644260076895362*^9}, {3.6442601126335287`*^9, 
   3.644260125127042*^9}, {3.644260206635504*^9, 3.644260216755534*^9}, {
   3.644260257841144*^9, 3.644260300439433*^9}, {3.644576371341427*^9, 
   3.644576438767619*^9}, {3.644576479640806*^9, 3.644576479920644*^9}, {
   3.64457654220582*^9, 3.644576615392721*^9}, {3.644576776040201*^9, 
   3.6445767991854687`*^9}, {3.644576834719887*^9, 3.6445768523652887`*^9}, {
   3.6445769381615953`*^9, 3.644576938607382*^9}, {3.6445771076003437`*^9, 
   3.644577147245116*^9}, {3.644577743925811*^9, 3.6445777948429527`*^9}, {
   3.644578047110093*^9, 3.644578096858204*^9}, {3.6445782810736*^9, 
   3.6445783067921886`*^9}, {3.6445783514558153`*^9, 3.644578351709989*^9}, {
   3.644580871103026*^9, 3.6445809542044983`*^9}, {3.644583694406518*^9, 
   3.6445836945720377`*^9}, {3.64458372703931*^9, 3.6445837383126783`*^9}, {
   3.64458377711351*^9, 3.644583837531001*^9}, {3.6445838746916313`*^9, 
   3.6445839220568733`*^9}, {3.644585052730834*^9, 3.6445851006510973`*^9}, {
   3.644585166144863*^9, 3.6445851833791313`*^9}, 3.6445863844322357`*^9, {
   3.644597848860992*^9, 3.644597868618737*^9}, {3.644597923287142*^9, 
   3.644597929359888*^9}, 3.656974933701758*^9, {3.656980023633141*^9, 
   3.656980023762002*^9}, {3.725896123119398*^9, 3.725896124813836*^9}, 
   3.725896175201226*^9, {3.725896423564294*^9, 
   3.725896434763706*^9}},ExpressionUUID->"0e604600-44bf-4f72-b86e-\
4502e1651db7"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwVl3c81f8Xx+09LkoZ2Vs0KLPPwbdhJauUlUoikkrZo0ilElL3cm9ZkVla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          "]], 
         LineBox[{{0.004435848449543596, 0.}, {0.014145384281923006`, 0.}, {
          0.018919767318870132`, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07262329958375738, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16306#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwVl3c81f8Xx+0t95qRvUdEiKT7loRQZkZ2UUi0bKIUkqysO1yhEBoopPic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          "]], 
         LineBox[{{0.004435848449543596, 0.}, {0.014145384281923006`, 0.}, {
          0.018919767318870132`, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07262329958375738, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16306#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwVl3c81f8Xx+097r32yN6rSEZ03yqbkGRFKSNKSJJZimQliXDvRZIZLTKi
PqeS5GsVqSiVvcrInr/P76/7eD7u533e7/d5n/M650ifCrT3ZqCjo7NnpKP7
/+9Fd/a0pAJVyD/jQWf19jfZWnXG9Vi+KmjWMd56OvCbLLPaI6+WqwqmDSmU
/Wu/yR0Z9xras1Vhx0lb45+ag2SFNt0xQpoqlDw6VS5cOEj+uteHnHVZFVRC
Or69vjlE3iv8drrwmCpk0KYibl0fIRNGS2tDXFTB6sMae37xCHm0KvWaiZMq
JPjHZf56P0JOt3UVHrNXhTs2rtNrHKPkqfi5gyqW+H7L/DmZd0bJtEVJ6hM9
VWiq0xwpezRG3v4UZfFSQBUqqk9c/sg9SdbBWjhO8KnCf1oRraz6k+SAh/xt
dERVcBIJeRHnNUn+HlthY8ylCp/SZU47NE6S67S/H/mPQRU6TzvMOwVOkYPu
Ghz/NqMCzPmbSYeGpsm/XdaCFz+owEZ/EyWaYZYsbGqqnfVeBYwWeMomxWfJ
dlrpi3rvVGBkOP7xNd1Z8isOlbAoUAHunM0y7XOzZEqDSzRjrQqIif5nVNI3
S7bfUX+D+EAFDBuW9UpezpHf/rpEU7+sAh8De/e5lvwjK0ldT1qOVIEY8jBd
5Lt/5JQT6WGvw1Xg0cwzw7dD/8gOAxUORy+qwPt/1X86pBbIw/2/uaL9VWAH
Td6JO3eBzPLFKrrNVQXqLfKofnmLZPN2yeNndVVAdTVN41zzMrmCS916zx4V
aPovaiZ3cplMsN67d1tLBeCn0RUm3hXy11YHwTsaKhCZEB0Y4rxC9mtJ7Hgh
rwJBot7GE39WyElv/5E5+FXgCMfQv2DZNXJb/XvJslllEF3db0B9sUEOGLmk
dPmvMlwMd/lpMLJBJhKVNI9MK4PWrIK/KGGT7OibcGBzTBmeuKc1pPtskn8J
Wngf/qkMC4MngyIEt8gLF1rLV9uVIS0sbvfFa9tkcY32PZYPleHuRyuatCk9
euUSTZYsU4YjvBv9tBP06OR1dbOFYmUwDv0+ahhOj4q/33TOu68Me7782zld
QY92JdtEzucow9pwmBK3IAMyHu8ESoIyVDSoMp+YYUD+9z9ZTXkrQ2pQ1t8n
GBMKmh63vO2J23/vHPfsFxO6oLNtoXtSGcTL3L3G6JlRRKuqeaybMmSz6EtN
GzOjG/NxxmJHlMH3qWjNqXZmdP+A7j4rI9y+hlnS8BgL+jZI1Xgoqgzy87Sj
tmbs6LvaM/XDwsrwoFV4r14gO/oV2qK2LKAMFmxf9thnsaNRjkWVg0RlKIr3
gH3j7GhBy0axn1UZTKZ1VrdSOBAhlk6Kc1EJhBNzw24MciJTWW/i2U4lmLJ5
ENCH8aBQMNyn364EMUVNfG+meVCJO78f639KkM6VfXhChBexZb+FwmYl+GOR
K7sSwotauWSCvr9Ugq3jreMEIQKyWRroOFShBNe4jTsjewnI8YNzyq5EJTAs
Fbk4FUBC8T676rbilcB+bVvhQSIJ1TKyDbfFKUF4QevFaw9ISJhca+AXowQ/
c46/edJHQn3PBKYKLilBg0bat2/mfOg47ZMFn48ShFr1FEWo8SPvQGvWpQNK
8IxpxfchURAtqSQpZxopQb+eta6AtiBKGH1vpU3G7/fVk7fKURCVux9MC9ZX
Ap2G4+vJNEE0a7VXZGanEji93rfrhYoQilJSUh0XV4Ku1Ku/GuyEUfpvRtu+
JUXwiuxud30viuRy958PX1CERpKV4etZUfTc+cod4XlF6PugH3NKVAx97Vz7
4vhHEY6rHQrRCxBDO17NeXQPKYLtA8f5TmFxVEr5GdzWpQhJB/QCOCN2oFdH
Gu6+KlcE5VgxnjO6Uih1ndrtW6oIP+TqyJitFDpeGEXgK1aEeIpDhK6vFNqc
35d0ukAR0l21V27nSCHDdIgmZCuCs0mH7uKmFHrR9c7r1HVFMA7sDS9sl0Y1
h7q0WDwU4ZZKmLdcoiyKX3wS+MRdEep5jxWoF8six9zbFa7HFGGxsdPb460s
Wpy2V3jsiJ/PqODiwS1ZpJ3yWcT5kCLk+2UPMYfKoWetfXTlexWh6wjhR/A5
eVRpNtJxSEARSFZ8WuejFVH5gRt6UnyKQJjY/PkoVxEV71O+P09QhGE2ry3B
V4ro3u5zF7O4FKFbK9Pw9LYiypBcFPvNqAjqvWx5/2KVUMQyk1/IvAK0jR3t
6shQRuYlcozUTgU4zvmE/e9XVWRyv9n/XLsCxK9f1G3eUkUHcn170X8K4J6S
Mtoqp4YM7lSUDTcrwOVTji/2n1dDGle07TReKcDBPHrry1zqSMDJOPd1hQLo
7uaoCLXWQIMsXrrjiQoQ7iTpvRK+CxlJ+Wcl31AAwbtVLHO3d6E8/ZBljesK
QFxZp3CU70Iu/nG1F2MUINozIbKgbxfq+vhAl/GSApCHpsS99mmiV7QRXQkv
BUiWV9E6w66FcrRO6zmQFcDhqVPxdMNutGQVmL1soABhpUceWn/djRy8L61Q
9BUgJZ0nrHthNyJk36j7ra0Azy60WzlqaKP4zRK9QFUFUK1UeqNTqI1CWsb1
koTx83GZrV/K2IPsjp/Rh3l5UB1+PWmUqYv6W3c3J8/KA3eE7Kn4al3ko7tp
7/RXHqTCEvf869ZFkYQ0/78T8hCsaZB2kE8PFb95ni/+Wx4EzkSsvrmjhzYV
6FnCO+XhZfFVrhKqPiqfyfqkWSEPJzp5ludaDdAet5MnNsvk4eFrptFjMwYI
WlSmW0rkISoyvGGezxB9LnjJ7FEoD1NHVQsy3A0RncOQXipFHhjmcn49mjdE
TnUa+ZMJ8sB8WtjrhjwZMV19d7bQWx5Ob3fsLXQyQu3fNPkiPOXB0mnyk7W/
EbqrlffC7qQ8PI3XLeO5aoSUhkPZt9zkwVVw8mF/uRE6ZKZU4uwgD9Mu3Vr5
2/j33MmD3Afl4QfPzJ2pyv1ImWLnEiYlD7G943UDOw6i+flGOlsJechQU3Sp
33MQNVopl8qLy8Pdnc3Y40MHkc0m/fInIfy+/tdjZ6MPomCPqgx1XnnoubNb
o/kn/r2CYNfgphyYMORhv0qNkU1Vv+mhfjkofFRiHGNnisJUHg0vfJWDI53c
CnYBpuh+Qcw1Wq8cRKvesDNJMUVLt+RfTX2Ug5znTw/dazFFef6Be5Ja5CAr
9wJB4qAZmpFnlHv/XA5oZ+WrNZE5SstWod+fJgervWZt9Ucs0Qvezbzxm3LQ
qZ8QfyrUEg3HdxqmJcuBIVFzaE+OJdK7GBL2M14OfKQ5Bd1/WqJfh1/NREfL
gUzW8/fF56yQJqf9wIszcvBxamXS97Y1+hQd3qBtIgeap4QrF9ZskLI5dzzT
QTkQ3tV43lfKFsWQCux6jOSA4dGfxFETW6RR0jJywVAODvvU57vftkXJXUKE
qt1y8O9TRoakgB0ylq3x0pSRg4Bg7h3Mz+xQTcs8t8a2LNTWe7EbbBxG3Hfi
v25uyMLIUqhLGtEeebmLFravyULqsZKGDQV7RJrfr3duSRZEPg0fErO3R4Fi
t09V/JGFM4X99y6U2SOlgJ21Kt9loeR9445KtyOIyufvoVgvC4Y+e4bGehyQ
w4a3dEuNLNzNf0A2nnFAXCMnBn2rZYGDeMsIYz+KomqOeJU/loXEC+uzRHQU
ubkY+OI6CEcqF3I1Hh5F4vkcQbvvyILpOeqiR6IjoqmUXUHnZOE/K2minpsz
cuArNPp1RhaCmANWr0U4I64NGv1VX1nY9/h7xmy2M4pqT4t94ykLXocLXbV7
nZFbUNgNE1dZyNjpcNbD3gXtqDG7ZWUmCwa1DLUOdq4ob/9onpO0LDzw89Te
edoNZQjGRjBKygL1b2+4QaIbSp6SdHwsjvvroV62/0M3FJbpws0qLAs9rFD4
Z8YNHZ5oi6zhkQVJOVXWvAh3xHS7yllgQwZWZcmi7FnH0dlfMaTuXhnoZg/V
0gv1QHpXxOJtUmRA7vKGOpHFE7mVhKfKJMnA6acdFn6inuhK55e7Szdk4GxA
EvdnDU/ULJlRkhcrA64xL6fGnDyRA3B9+BshA3O8+Rqb5Z4oiH6L85afDDgb
oM2PDl6oNPbX7U5TGTCqmXm+9twbCSUU5drRy8Cy2WB44XNfROvwoy1uSYO6
/GyH+kdfJCWgQaVsSENX127f7mlfpHS/Jnt4WRrejudaBMn5ob2N7++E/ZWG
1ymGId4Zfsh9diLxXr80HND3/sAefgYVOmuEzj6XBs+9wvEaTv5op3KtTdoZ
aWCa8Az+qxmEfr0xjHD3lQaHy6e3fu8PQulub4pUfKSBO25ZY+hwEFq41b7R
dFIalJ/m9/AEB6EXS0Plq87SYF1VosZdFYRMmwisnmbS8GXok+cj3fPo+Ikz
2B45aRjb5hpIsghGNzN37Or/IQXy5vV7GzJD0L1D7Pbh/VIwos5RUFgegp4x
L14Q+iYFxj61KA8LQb0X22qP9EiB80euzQ8TIUjKMRK1tUoBI+FCZhn5Inom
+M3mZa0UBNG/uDs0eRF9zco4l39bCpjehT6fs7uE5CicDz1NpODmaf5R1UMR
6IGbX673CUno6+63Ub4Ug5LFvE1EzSWAulzi/4MuDo1wBElZiuyARS+XV9bm
Cag1Tc4tbUsMTsyUlT2npaDve2wnPCdE4buStFZ3fBo6yZlY9qxRBCw+s7qe
X05H5y/5two9EAbKRs1igGomWuA7IbFyQQj8Tv34IeORhYZqFnoOBQpB4BJT
LIdvFvrkkpRceEYIjlWZus8EZqHH+c9XbE4Kwd7Uz9efXclCZ1S5uotshGDo
37XjKvlZ6NeB+htHlIXgSwq3h+JAFmo7zzf3aEAQPoffkxh2ykYN/GUlTH2C
UD3QQNlzIhuV15KPu34WBCG1zNp4n2x0Y9PvP+Y2QbjfKySufDEbHUiEIrd6
Qfj146nPxfRsVHfvnCtHhiAIl0n+p9+ejYo637/1thCE8QbpeFf9HPRX+Fc3
p4kgqOSd6ctFOUjn1MrQUyNBGKjT5Bg0yUEtC0pMW7qCoHZQTuCcfQ6aFkky
vqsgCE98UpqTz+YgbS/rd82MgjAH9BlVlBz0ZqWrWfGVAJT1do7+WchBnAcm
etvrBWDayNspcy0HOSTTj114LgCO92lO++goaHSHFitUCEBwaiJ7KicFcRy8
Y+ZMFYCFSmWxfikKOnzzaEtCmAAMBk4WvTOnoF/SfR8mtARASUjbzi2bgqZK
XjVragjA7uGrHMW5FLSkXvg2XFkABnrLdDzuUxDnXv+X7FICcAVDvm8fUpCO
/dYTZW4BvH/8NuP8ioJSrslk+43xw8bVhgPGQxSUxcaa+XSQH8yypoSGxyjo
furU7dUf/LB2VND4+jQF1VKqkxN7+KHq7nLzf4sUNPjM9ErZa35Iuvq71ZuN
inSHzvhMUPnBWeOrca8SFR3ws/XUzOIHQu/rxHI1KrKe2e0Rns4PqPP3StQu
Kjq1vuHCnsgPg/uePJLQo6IUvluHlEP54d1ssrWnGRVl5VywPH+eHyj9zQs6
VlR0X9LZrN6fHzKkBOW4bKmoVlV6v4UnP/CMqmY0OFLR4MEqbT87fnj1yiJE
3YeK/nzI0nxqxQ9c73Tiuc5Q0YptlMaqKT8ImbrD1Dkq4nYzUUrcxw8JuhWS
L0OoSHhQWf6jHj9MmJ3y+nSJimR8eWREtPmhrO+4/WAEFemFfBErU+GHeD8v
98UYKkp9sM4wwYT7Q3aH2mY2Ff3rOuVylY4fWixKk9uoVOS8+eGxyAYfKBf4
+Ofm4fYcs90s//FBrm2Jr/EDKnrOuqfm4W8+AOH1b6WPqUhUm8Zl/IMPTGd/
KMc/o6LLHoye37/yQRrXicdez6loKOVMfUgPH6gHarEZ11GRef1HXu4uPviY
5fJCtoGKKkf0fIr+4wNR4YXC+pdURCLda9z3ng9q360LfcOo6PuZAL+AV3xw
NjyLwN5ERfuzPmMsL/hg05djS7SZiorfGgrmP+eDlDS5D8otVBQkzvm2s4IP
9klHJhq1URFjR4m4JpUP3nlQmDx7qEhF83fnv0t8oGqitPVjmIpuuZsrpFzg
g5BDIp7Lo1S0kPg4Si6QD17ruCvwTVDRq8Fo5aM+fHB6tynx8B8qkuUdufLn
JB/oujOUBM9QUYKBde91dz6ok6kLyZyjounTVWoSLnzw4zrvYt0/KjqcIRpb
48AHQm3vLD0WqagGrn6zseODt3Obl+uXcP/9Gd85ZsUHDom8v7hXqGjYpPa7
0EE+eFNhJvNwjYrClo/ohGvyQcQHNfn/tqnoh2xDClGdD0rjTY8R6WnogJ3M
UJkSH5iTXbedGGiIq2z2Vp8kH2Qc1ksZZ6Khe643Jwx4+EDf6tyCNAcNMd9Y
QD3sfLBaPyt4iZOGzlQdu+vPzAdDDpcsOrloSJtL5WDuBgl62r8wJ/LSUI7e
7Zw9KyRIf1sVPEmgoS2vlZn2fyQYsNKpsiHR0PuXzbStSRL84aC7LiFAQ6Vv
LihVjpLAJRgTuyZIQ0nvpaqPDZLgoYJW76gQDfm3tSOOARLw7n1qXyRMQzYf
I/6r+0aCukuF0gYiNLSrV9Hp9GcSeIzV/teGM7G/Z1DgIwnO5oxwHxOloZ5h
jbXgFhLksjPvDhKjoZqJ/uvSTSRw9oXgFZyz/iYQuzASpJL+MsSI05DryqCS
ei0JatgeRd3aQUO/OLOcxopI8CgkruyVJA29IRgPZRaQYPqq7Xk7KRoqFJgL
MM4lwcTGe/sRnH0kreILMkiwL2DAXUSGhszlVoh2aSQQ5vYfqMNZRbkodyuZ
BK+UkuTcZGnoj9Z29bFYEowdT5iplKOhDt0KI44rJNjR5bTXTZ6Gnhi6tNVF
kCA0y6yHW4GG0vezOJ8OJYF/6pzfG5xDTKuGBIJJQOZbvBWuSEOOVh6BTedw
f6uWvNZSoiFdO+71YD8SHNcW/3UFZ+GjL+KlvUlAzNn73AvnNZfTpC4PElhn
ez0ywfn7cf68y24kaO9sT5fF+aXna2V1ZxJcv75Pbhu3H3NObH+SLQl4Tufr
PMP5VHBLm54VCYKvp4sm42x86aLzmCkJuveTg7xwZr3aGWhMxv2BJX4XxXn8
etT6vD4J8hiGCKv4+VuTlG8U7CFBm9j32W84V9zqJdlp4vcPyJ15iXNqRmze
lhoJfKzqLxThHJSzS6VSiQSusea9aTgfzvvx/JgcCT4Pbp6MwVmrMGk/hxQJ
7rvssg/Bmb9Ut71ODPdPZP9Hf5yXKoadTwuRYIrr7pofzl+e3h4W4CNBwOHL
3WdxrqshBzXx4P4CMbtgnCkNU+vBHCQY6tljG41zFGTfkGYhgU5ufk4Kzu7v
TPi66Emw8HT5Vz7O5Nb5vMubRBjUd3tVg7NUZ76K+ioRFGmkp104M/RY1/Qv
EOHUpPKd/99v6Ovq/qRZIqQ+3Piwhb9304/idr1pIt4/zKQY4lw8eMRlbIwI
dGi64hIeHwljdCOZQ0T42Xdy8QkeP2emK4OMfxKh/f0j1Qk8vtSXWBMKeomw
f1biqIs0DXXpXqWb/0gE4oTut6t4fIaEr4UdaCdCa4vNxQo8nl9sTPsNvSVC
Z+4qA6cEDR0n+wzuxojgUcfqaITHP33MT9e4F0TQj0y4GoHnhznjJyv5p0Tw
u6jtvY3n17SxVdPFCnz94/BpS5xvxTcZNpcQwVY1cIyG52Mve6366TwiiHhc
+OKA52+E1a7i2hzcP3XYtxd4fu+4WSbBlkmEcZF6H0WcvQg03rJkInBfZpoj
4XrAZi+QsBpPhCaJOvrbuF48vJNKZ3mNCJ93vsH4cLb5zBpOicbv/8aDKs1P
Q/OCV+cmw4ggxnCZ7imuN5nOa34GIUTgL3LP30ekIT3KhcHkQCKMtXQktuB6
dWWHT7eaDxFGIoOO/8D1TObET6vok0SIC1NAfrjeNd9zbmp3I8I5YoDjMjuu
l3JWzwOOECERUjJ3sOLxobIr64kREVoIQ8IluL6S/ct46Q2JcIFb5KULHQ39
rpRJOKxLBE3Wi218uB4raQqEz6sT4atXu3X+BhX9F5w6d0AZP29tLs/5dSoK
qGY9c0eOCN9sOr9Z4nr+XHfNVVuMCIsifXMCuN47h1/ojhMkAkWS5x7LMhVt
vJi2+kwkwkGeI4JbeL3I3/Bukucmgpfey/L1Bbw/If80DGUjgozzX5GHeH0Z
veL8vJmRCFMOPV7P8PqT+PqjutA2AZ4pDf6oxetTlzHu6UUCVO3Nev16iopC
4vdlsc0RIPPesEULXt+EWmp4XaYJUOpRpv9xjIqOW5XRrQ0SwFArjP/vEF7P
DqcOGnQRQGxQU/jsdypiPeFcjJUTAHtnnDjfQUVMZg5hHsUE+FL0YdeNdipi
2GlnSX+fAG9Kem7L4vWXTsha/H4uAW7TlZi+b6WirS2zvwdyCCBMCGs7/wG/
7+hBGMoggE3XwFUZvH6vdqD0uDQCjJS3VBPw+r5UY+Aln0IA/nQm1p63eH3O
09VpvkEAr9mfOlmvqWg+fjfb6VgCRCqK7DyG9wszATv7WK8QwNTkcbcU3k9M
khUvW4QSYFf1WHI13n/8GhBsbvMiwKjSYjHfEyoaaCZln/MgwIClpMR6JRX1
P+I5w+NGAK30JtLkQyrqvczCY3eEAKwOlcG/SqioTWLpaPd+AqQfcfDRv0dF
rSzziiH7CGBML3z5NN4vvf/7Z5VfnwDtZ/j259Oo6M2rkVzHXQTguOJpq5pD
RVD8O3BZlQCaPJQdV7Lw/iL1x/5sRQJcoPbm9GdSUWPoNz59WQI43TpMNsqg
ovrjn0e+SRDgzuCEd0U63j+YfqyNECVAmpbeL8s0KqrWaE8UEyRAbuCtjeab
VPR4q0ndnZsAn8eK4t4mUJHVPr8pWOaFvR0l3GOXqUjupSJnx1NeeNMcOHDN
n4q+ND6wHJfnhaZAKWRsSUWOLHtazonzAlequHow3s/22L4z+UfiBUPSF/cS
Yyr6NDhitLXNAxIXCEWqCPcHm6Iufx8PPl+qqTzXxu/rUCZrlMoDdo/Lt47I
UNGj6cqNrCVuSNnrHVC9SkHqOuSIHX+4IT7ii63+MgVVXOlYvj/EDRHf6BXb
FyiojDQzX9nFDYPVpDrZWQp6oLdr4m05Nzz0LonIwPt7StyzzzPHuSGTf5/B
wV4KihevfWT2ngu6Lk7s3HxCQfXPrH+ee8UFe+aSTOwfU9C0+SBvxnMuKC3d
Wq6ppCD7i9znfxVywe2cr5uV5RR0nbOwgIXKBXlHhn1RGQXVFeh9UkvngqOG
mbSBEnxe0e1gOJLIBVZdLlv8xRQk0eG5OzyGC8rkGubeFuLzjteqZ/4lLvia
Vy8SXkBBcWupGe8CuOCeSXvEnnwKmlR4sUh05wLGxzPd7yn4PHKFUFeuzwUf
dlxx8k/H/xcoHu/axQVXvw9MhqTh9isMRJYVueDYFCEhORW399Un4qAgF6je
veI8koSvD9go9+PmguZLh/OVE/H1TOn9t5i4gNOvi//yDQqy03xp+H2eE/Ke
nB51jqOg2Pf25xgmOaGbu//Fz2sUVOM+nqv0mxOsb20+vHSVgsST+LZDOjnh
bZ1TR99lCrKVKttJbeaE/m8nnhZFU9C1GrLH65ec0HA9nXg1ioKeW/ekjVVz
grHOxWj/SAoaH/R7zV3BCQqv4NTpCAoSC9+e213ICY+b73KdD6cgG95MGVcK
JzDdcE2sukRBV4tUjsTc5gT1n18N2i5SULUBxBYncAL348y66QsUNPbxaHXb
FU448HJmWyCYgkR9p4bnQznhS2kEh0UQBcVkCJoib07YKVsl2eVPQVUqFaHe
bpxgPm36R/4sPp/C/pLkI5wgwSrIkOhHQdZ//Nm+7ueEpbhrbBE+FHQllkF/
S48TbhNWj7F7U9AzkWw/uV2ckEy1rCv1pCAR07etQRKcIObK+EDkJL7+u/P6
XQFOaMzdIk2fwPcP/qv6kosTeCpTzbqO4/uzxbkNMXICxWb/lWZ3fP88kZvs
6xyQ92/n7w433N6exy93znMAazA1auIYbu8/479HJzggZSzcTBDnKyf7JKJ+
ccD20SXxo674eZYDbe9/4YBD1383FLlQkGWZeE93GgeYSBL16O0pKHR2X6BC
Agf4fMvnbbGjoELdExzhVziAx70whGJLQRvvCowkAjhAfLtexfsQBSlxv+0P
8uYAzZ3hTCesKeiow3DoWzcO4F5wiTxtRUGPBhUqfa04QK+8rKvYgoL6lM3N
Gw5wgL60yucBfH5nPe83xL2XAyymV0ERZ+26pMsemhxwWaWI7poZBXlsPxSp
UuIAHU3/mT+m+Hxu2l7NLMUB31Ples/iXH/zr62zEAdUTvBMrpvg/unhnSrn
4QDjkwVWeTiTxDXjN5k5QFvIlPkIzmRPe2m7TXbYGcPNIYrz2fILjfcX2IFj
h4P2P2MKyp7LcFqcYodu3WPGAzg36dXMmw2xw0tyz0AfzrNXvtyk9LFD/pHj
yeM473i/ovTnIzusFi4+Y8HtWfKINqEP7KAlCbmSOIceNTiRDuywOQDVbvj3
92lua8O17JDZUXr8/kEK6hyKztR9zA7PQieT5g7g/lXJ35VUzA7RhZYyVjgr
BcN/33PZ4TedFsuT/RTkUP/bZ2cmO2jrLPNK43yVjpHhWgp+nwPShHwj3N9m
crk9sewQ01vQroJzX6qJnmIkO1wNYmV+hyiIpdenOzyYHUIni08H4Lx7R0JA
mx878KNGiiLOHl5l7JIn2eG7zjWdOTLu74etD847s8OvaqN3/+FcNz+Fmmxx
+46H39TiPKLP3S9oxg7HhERznuNMuqoR6kdmx/Vws/AdzuQWW2LjHtye0n7V
cZzP8J6v4FFnB8HRUc8d+H5ZjulmJ+XY4VZ3dIA3zk25VYNVYuzQ4jRyFHCe
He6JZuFjh3uCzDwa+H3E1ZaEXTjYQcQ5LPgRzhYXhKof0rNDcZmayX7cH6Ev
9Gy3Vtgg5eg/tVGc79O7TtrNskGpOXM1Dfdnh3nk9cIxNojaCDP1wv2/fosm
tTTABlorZbsM8fdR+vKywbyXDcSVPsbvw9lB4qcjtZ0NRKgX4jVxjvGmm//T
hHN95NGdOFdWSN80amSD7EMLX3Rx7vt3QOlOFRuIyldNWuHMYuD1dqScDTi+
FZ/yx1nr2vXjevfx/Rl3cFFwPvGheDUphw3CqHTln3FOIbRk/Ehjg3g9wuL/
46fOaWLnrgQ2MFvjpIbjPJzH8d+1K2xg2dm3bwhnwqiqz+dQNmDuKQ52x/PB
UP0QvVIAvt/VWRjH2S8kgBbhjdt3zy64jueT6B4lItGNDSSxVlljPN9aF39f
L7FnA5sAC7Iwnp8RNdS1fRZsUFAbYc5gSUEql44G9iA22CF88goDns99urzD
Z3TYYD75C6MInu9JKy3O9OpsYLej4asJrgeT4YYHNETZwJmr/sdvXC8oe5dq
mghsoHd17azdYTw/1h+rHmNlg4yGRoYeXG/WGvzuzW2yQkV79uxZBwoqj5IV
SFhghfriEBchRwpy3fcjUWKKFdxF93MzOVEQx9bdrerfrECXasCB4XzmCsf4
7w78/ycdzC64nokaNbmFvWOFM0OG6ntxvWulu/yRp5EVXn0olVPB9TDita5p
0TNWuGvlM6yM66fKtbkXBmWs8PtImtNeXF/7Djzc+SmfFTjk+1zdcP1NYvR+
4HuXFep2HGlIw/V5Ku7rzcxYVrh/lhC8+xQF0UzSGdQiWIHrqitbIa7v1izW
l94EsYIPN124Iq7/FTcwjxl3VvD6HRoR5EtBbubhn687sIKBS3TmnjMUxMW+
21LcihVUDo1QCXi98U8q3m2hxwpz7AlmbHg9ErfyKP2pwQp5Wx+S5PB61cYp
uiNUnhUK912ZOxpCQVFt3be5xFnh8jR5jhpKQWo3b7IUklihVmv9y2IYBX0/
ZBapz84KRxtrP5zC62kKD/1s5zYL7DqolCWN11/DzhdePkss0LzOulaA1+c/
t0K+bUyzwL9uSpx6DAXl2WnY3BligZy4CNN3eD23IY6/Ue5jAUnGSyZnYnG9
ST9W4fieBYR+LPf9jKeggMwDV54UsMCrFtZHt/H+QsJx459pNgvIf+kcfoj3
Hx2CNb4/UllAM0m38Bven2hkK9tzRLHA15p7ieezKOgvhSDv5cgC9ZKNSRS8
3wm8N9AqxMkCf0L2Vi3UUlBPZe68DQMLKFx3YOF9QUF6DW6i8avMcGaQyry7
kYLoevv8FsaYYWkC7aYCBaVzfmH72MQMlTr8qXStFLQkfHcXWyMzjA0eexbV
RkHHFI46oypm6F21G2DtpCC5/d0llQXMUNBMJ3qoB+9nQjtNky4zw4ozkwXt
Jx5fcakBry8yw5rEpAplEK+vtw/dXfFnBsv3KQulIxRkXvHfiM8xZkis4n22
MoW/f30Sd549M/wr2SOjP4Pn63uLPZ8tmMHvQn9g4jwFhfSwuXPtZ4b8hmSB
iUUK+vb7fdxBPWbwfS4Y5IT3sxvW8GZjjgmKZUPWXvFSkYfrlcndE0ygOOe9
J5tERe9Ok0lnfzHBhaJ9u6MFqCj1WuPJbx1MkPl1vMZfjIqk6uroah4ygafF
nU9/FanooOxTcqA3EyzGjRCqDlJR0mrBi99fGYG19XxIfhgVBcesNrh1MsLW
lMkZmygqcmU9/PLLO0a4e+GWCWcMFakI0EH7M0bgLLQde3wDn092HX9Xn8II
V+KchUvxeYPDV7TrthEjfP6ryfKwFrffmz6yv5QBziUJahTP4/bdJ0cb8xig
eI/uh4dLuP3h/eO6mQzw+dzVxw34/KoyPzupfo0BopZWTFcYaKiV23ZWxI0B
FBW5vPbi8/mzjOK5DHsG+MjtwhmDz/MUsa15XgsG6L51VKVZmIbOKFcuMuvg
9pXLeZ0kaYjDhHN9jpcBasY0m/LV8Hn/v1Mb/iw4k30rN3fSUJ/9i82xDXpY
44mxOLmbhso9/OgGJujB44Ulj8FeGrKMes/c+pYe6jYvOZDNaUiLUZLV5AU9
/Hr891OnFQ2JJuHi+4QeCL+Ysk7b0tBkljxnTS498Ku17Cp1pKFPEtFcmhn0
ED+v/snWlYZeFPVwVyTRg7nlbet1dxq6r6bGq3iVHrSS+0rKTtJQclUs4f4l
enhbdtM30YuG/Kd8oiwC6OEzsrTUO01DNrKW47Ne9LCV4do96EdDhDsEQPb0
MPFn35h6IA3dDc4N/KFGD+Vrb44+DqehsPKY/jhZfP3X0F82UTTkMuhppiaK
27+wKjhzmYbE7VUkI1np4cuH/7h2x+Hn0aztEB6kg4ua4u2dqTQU50fZC1/p
wNvmQmvkbRryLoguPt1JB5LKdDHKGTSkRDS+XNNIB0naat8TcnB/WyhOulfR
QWVUQJ4+jYamYjgcmcvpgJdaaj2ZR0NtdX9eV9yjw+ObW45SQEOPZrvUHbLo
gIGoSDZ/QENpStU56zfpoBnNk48V09B5jyzmwjg66HLT4RAspSHtLvcfc+fp
ICsX3gc9pKH6x5Mpt6zpIDHrdEHHUzwextpXdA7SwVNdw6tOVTQUJfnUa0Af
379kI6+/mobIty4ZqivSQQH5h82XWhpqCmCabqWngxKWDpailzRkdajz8fDs
NlY2/quagNEQz8vMG7sHtjHqtR7TcKChDJqM7se6bWwrdv2w0VsacuKa4JEq
3sbYfmor5DXh8RD1eDTgzjbm+Zv59vI7GvoxdfHVy5htrJwredHqPQ3dO2Z4
lytgGzvb/yuT0kJDnv8xBBw7to2t8++9PfiBhhQMPpiUm29jE16xVtBKQxPl
t3as7tnGIiyfJHL/R0MVoo6LZrLb2KWhNjNrnAOTxNvvErYxlnrJg9E4a60N
PhjZ3MJ0P/FoFuC86FcWpT21hekfNn1Vh3Pdt0CH2K9bmMGPnptNOEda6Kh9
ereFrUTu03uHM7l+g1G6aguTi7xs2YAzvfLb/sB7W9g7Fm6TEpybshOrXt3c
wkpZ3lEScb7BZpfMHbmFffvW9vgUzpZhgp5uvlsYV5z/Vy2cuca/73149P/7
fXFaw+/T6VRIWjuwhTXYTR2vx3nNI8QuSXMLU63x33sRZ4UzJqmiUlvYmuLM
F2Wc7S8ItpXzbGFH216rf8H9czlqjN1gcxP7KK4nFY1z+fU6s/+mNrGLU+kx
Yjh/Tk28fqxvE/MuHuB8hvtXrUCVPqp2E4O9bqrNuP+dyzfIXMWbmPpS94cD
OMdWtUfRMjaxKgHtoufNeDw25r1Qi93Ezp9ZYZDAue9d4Erj+U1MZlftKSn8
PVk6jXQOeWxi41VlU3fx99f8Sgz5YbOJrfkyy2+8pqGEyaqZTdVN7F6mNm/m
Kxqq/henniq6ic0+OTj8oZGGfm4cPSvBvollhK4/mXlBQzq8K6Pk0Q2MtWJC
hYDH4/Buw4Er9zawEIWzUU8e4fm9j1uccGsD+ycZLRJeQUMGpgMu96I3MFet
1nt7ymko3TnmM7huYGlFRQzJRTS0P7qpjV5gA8tsufmohIrrR3wmRzrjBrY1
HH+bgOdn9i0fc5n5dWzSP63d/y4NzRawNR3oXMeCgq6lbKbhevDwG333y3Us
6XHK7C48/82qy5FnxTrWHrr33NFkGgp+GRn9j7KONzV5+iIJNJTXbN0Qm7iO
/XN29TmI60dr545VvrB1TEa8+5NTDB5/X//qPPBZx54KM+9wwvXHeirtWdPB
dSxK8nCRcAj+/ryfy5i31jDRe2IRNafw9xcpHsucXsP2xidN7TpOQ4dlLskr
9K9hVz8qKVBcaKhUW6TAtG4Nyz/8YfdeOxpydHHPvhG8hoV4tUXUGNLQtVMa
vUIn17DgO7Lmlbo0VHl2m6/Udg1TV5cfvaNFQ0yXC261qK1hLzemP+9UoqGq
+yPx7GOr2L8Xz+5m4/VlNG/sknTPKjZMuaGWzEVDwtQJX/3XqxjFPsh9mRmP
vzt/LP2oq9jVSTQUskxFlnGLPB9sVzEFPtlq3m9U9MubOSuhbgXbKDrU7IzX
Q75TrAn3ilYwodc/aqpTqcj0OHt4XfoKRvdqS3z1OhU9dOQ+Nu6/gk0/GREz
CKGiUDMBSXPpFYyQR86g2VIRl7J8CWvSMnaqc27ozToFIXnFbMlLy5ip/kHM
b5aCgqWVE3W9lrG8BfZ3c8MU9EVE/exp8jI2bpLIWNqOzz8ce3a+n1/CjHlf
07/MxfulaePa+GNL2P5xVvkWPXz+HTctzTNfwla89I0rVfF+b9g8p2bPEtYk
NqJxUYKCGH9YR47yLmG/4sQOCDPi/Vu7AzJtWsRGY+OXB97nIK/HXu+Z1Rex
VocqFyarHERncl7ihNgi9tcmcWzWIAdR+6Iv1rEvYnVvAn69VctBn5izZM+O
LmDNDP82dvDkICO3D1e68hewe7HihKLObCTGrqFHJS1g7qQ7F/msstGnU8ul
u1bmsdfnUwqipLNQwAojXdLoPMYSWyPBxJOF2FMJTkM985hBuy3ThbW7yKhe
mfnuU5yl/8SzdN9FlbxuJ9fPzGORrXefzF67ixIaQaT5xxzGwKH0l/w5EyHB
pKRjb2cxTvnA2QCfDNTB/aiG+9ksdh17qrHPNgO5MX8axO7NYvOPRp4s6mag
sAURA7nLs1hUMU9UD2sGevqpbGpabxY7G3Yg4cODO8hU4k7OhtsMZjSR5+/Y
l454CCSJA7v/YJuk0GufdG6j/H+8iu0/xzFHMp/bumUyam2pHzF6MY5xsJX9
tuJIRgu5ng+qM8ax22JtQpQPScjSvFaaZjGO9ReXbxqaJ6El2nHxs1VjGEUW
ns2bJCIb00oi+41RLECB8aaWyQ20kW25YawxjDG1znLk68QixYCFF3Vsw1g+
NrhNW7qG7A/mhasNDWESt1lGv9RcQ6V/5pb4soew64xnvvHoXUMOB3LmBumH
sKwyY/2GfVfRw6mx0ZjPvzHjI0LPe7Muo+oojsLw1QGMaCbkqCN/CVWkJNT5
VA1gP2N/vltsDEVFNJaOI+cGsP02F4LSjoaiu40Mq+q/f2COu1Z6jyVeRGEb
azaDLd8xYfrZvbp/LyDDqKk1y+w+LOFS0Bfxj0FIO8WPoGffh7VrLaQ1nw9C
6rQxeXmuPozFrwpF8gUhicYhu+0r3zC+H7e89asDEN1Gf3HV6a/Yz4zDWdSJ
s+htZJu9uG4vVmIXklX9zgc1Jlv6ss99xs751od9lPdB1dSW6KXyzxixw+Ly
aKw3KmpoKu2S+IxpRw2xlpp6oRvrjVtxLD3YKYZB2DF+EsVwGvAHQzcmf2Lk
Ds3xJAoTq1c+EdGN/WAbZy9974H8DJ476P/9hIncuX5Y1vMEsoqsLP/z+SOW
/CKLFmN1DBknq0LfrY/YBEfop/NHXJEhtezze4uPWFP1y1CWky5IvaGI7v7L
Liw7v6jJ4KYTklgyqKyw7MSiuJuEkYoD4hXU+xr/qgMjflXjfHPiCKLT0WY8
qdWBtZT0dU5S7FE9dfiEeHg7FrZcQqLLPowGL6q5CIi2YwFPf57T4juMihbF
mS9PtGLkCT3367zWyP8hLYvzUCv26CLFkz3CEmmfFFfJefIBi3TTHf44Z47e
tInZVl9qwTTaJbm/s5uixGvU3/v732MX+H/MnC43RnZ6YiGd5PfYE01ZiTbn
g+hnoWjOJHMzltEYm3nppxEqdqGohvm9wzYqP0zVByIUwCv6irm9CXOs5ZGq
MNyHNiJEhqQy3mKO0eTYSRV99HZXzsVHy28wDf+k6wzWukh2+12y9943mGrd
Tus3WnuQiL2wupPMa+zA5e76LAct9Is1Gxu+DhhhqyHm9eAuZBu588HwJwwj
JnwwshTciQZGNT5s57zCLsRfS3SjqCHxhATcPy+xPSFNN5yjVdDaS3U+HaVG
zJGOK+abjhJKUFbXOzzzAnOODSpntlZAgplq7v419Zjk8emhtZtyqIhO7dqN
6DpM2vfAxYw1GaTtr1py37gW65i0ibxwSxq9+aLS9pKzBhNO9xfcsJBCdgdV
5r5+qsZGGR23HthIoJ+PlAUXcqqw3uXFrcfm4ihAVNmA9+QzbHy+L882UhRt
XFfyUFF6ip3+qlem+FMY8Q/ZciQPPMakhnLiD/gLIc0XNg6v/SuxHydLjDhE
BZHN7UN5y2vlmEdpuMn+n/zojK/1uHpiKRYu5jm+9pQP3UBWWl5CxVhVv2je
nRsk9EDQMopSVIjJgth8qQMRvf5j3ty1uwDzIG1oEbkJqDHxlhRPXC6mkTxU
XGTGjZZ0b1ZH3MvGSs5ZresIcqBdo0nmY413sNKG9opzviyoR4lYX/LsJsbg
FdbPLsmAzK9z/Y6ZisUuxTH7vdZcI196y0uqNg/B5s/vHZH8b5qspniU7ohq
MPbFZuMpD8Mk+X9NGp8T
          "]], 
         LineBox[{{0.004435848449546488, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16306#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwVmHc81f8Xx+15zXttIXukSIXovouSFTIyExkhaVH4EkVZpZJ5Lwohq4Gs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          "]], 
         LineBox[{{0.004435848449545875, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16306#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwV2Hc81d8bAHB7j3vde+1kbyKKIgdFVpI0CCGEUJRChSIhyvgad6gIZVRI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          "]], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA3DSDL2dWvL8q0hFDoMyHPogpLThR
77q/WokJ9wg5nj4WlSxdbLa5v0HovoF6hag+pQAsgod9uL9YHxUhIIaxPjRs
K6eiRLe/rVSUB2s8tz7C1yrMvQu2v6JzU4+DR70+364pFvSZs78beYVqT+zE
Pm4aKTsPYbK/fv1dQoYLyD78hShgKiixv79gc8R0Dcs+FONPCover79W2KZM
D93NPjG6TlTBbK2/pW1aRfcx0D5OkU2e9/qqv3dfCWUgRdE+amhM6C2JqL9t
sFJbXRvSPoc/SzJkF6a/ug8ezUOn0j6kFkp8mqWjv2ONToec2tI+we1IxtAz
ob9yS+gPW6bSPryJjyAOhJ2/arAc7ZT60T72N420eqCYv0uc8594xtA+MOaK
SOe8k79df26giPDNPtQoEbmnso2/y7dtTnj6yD5IhQzhgOuDvyK8xa1Ag8I+
d8MPErRIdL/b4ckqi8K0PjcrVQBTK3K/3U2aunfJsj4lprjv
          "]], 
         LineBox[{{-0.1379712763070238, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.11956510309924584`, 0.}}], 
         LineBox[{{0.00443584844954559, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16306#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwV13c81d8bAHDZe9+BjMreGVl1n8yQyIhIpBBJGmZf0ZBQGsq4Q2WkQluk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          "]], 
         LineBox[{{-0.2258229670121181, 0.}, {-0.21880456020282513`, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.11956510309924577`, 0.}}], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA1zSDL2dWvL86RJWVXFWIPogpLThR
77q/Jfhm1K2Omz6lACyCh324v2ZLxnNGX6s+NGwrp6JEt7866B3UzQyxPsLX
Ksy9C7a/9xJD7iVWtD5QQyrx2NK0v1qdqF1cgLc+364pFvSZs7/vRKHAan+6
Pm4aKTsPYbK/IJmWzYtGvT78hShgKiixvxDh7V0zyL8+FONPCover784DE0Z
A/vAPjG6TlTBbK2/vsoWuGjgwT5OkU2e9/qqvzznFuhAjMI+amhM6C2JqL/+
k61CDfbCPoc/SzJkF6a/M9pG6NUUwz6kFkp8mqWjv8Ip26Ek38I+we1IxtAz
ob9F1kDY/0rCPryJjyAOhJ2/VwUEYOVNwT72N420eqCYv6gv4jCKub8+MOaK
SOe8k78ptue49te7PtQoEbmnso2/Yp3Hh5betj5IhQzhgOuDv3wFl2exs7A+
d8MPErRIdL9DFLrwiHiiPhInVQBTK3K/743ZceywoD4aBr3x
          "]], 
         LineBox[{{0.00443584844954651, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$16306#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.03744950678496077}}, {{-13.815510274069974`, 0.09530989591002416}, {
        0., 0.03744950678496077}}}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.04}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.04}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, 
   3.6390767166598787`*^9, {3.6442574366310177`*^9, 3.644257640914957*^9}, {
   3.644257708990077*^9, 3.6442577371366043`*^9}, {3.644260004751333*^9, 
   3.644260077952415*^9}, {3.644260115987558*^9, 3.644260126350301*^9}, {
   3.644260188124305*^9, 3.644260218133224*^9}, {3.6442602591886263`*^9, 
   3.644260302050921*^9}, 3.644316648114072*^9, 3.644576451074027*^9, 
   3.644576487542392*^9, {3.644576549658166*^9, 3.644576621616087*^9}, {
   3.644576764562796*^9, 3.6445767820862637`*^9}, 3.6445768574554853`*^9, 
   3.644576945003827*^9, {3.644577113369245*^9, 3.644577140083241*^9}, {
   3.644577753012301*^9, 3.644577802627615*^9}, {3.6445780569311028`*^9, 
   3.644578103866412*^9}, {3.644578289753704*^9, 3.644578315580659*^9}, 
   3.6445783615710917`*^9, {3.644580938831132*^9, 3.644580960697556*^9}, {
   3.644583691767996*^9, 3.644583700885569*^9}, 3.6445837471615887`*^9, 
   3.644583847010324*^9, 3.644583892827443*^9, 3.644583928512251*^9, 
   3.644585111858407*^9, {3.644585173229665*^9, 3.64458519082297*^9}, 
   3.644585513469898*^9, 3.6445863990953827`*^9, 3.644597859482862*^9, 
   3.64459793577026*^9, 3.6569749437404423`*^9, 3.6569800300558558`*^9, 
   3.7258961352719097`*^9, {3.7258961730712137`*^9, 3.725896176681426*^9}, {
   3.725896429308908*^9, 3.725896436311098*^9}, 
   3.726157294313781*^9},ExpressionUUID->"62f66364-f1af-482f-b518-\
b82330078f99"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "\[Mu]"], TraditionalForm]],ExpressionUUID->
  "6b2baae1-466f-4cb6-a698-9c987e970255"],
 " Cascade Spectra of Final State Gluons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "\[Phi]"], "=", "50"}], TraditionalForm]],
  ExpressionUUID->"c2f0a858-a94f-4d36-b7c9-c5b0bbf3639c"],
 " GeV"
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.639076412252461*^9, 
  3.639076429227652*^9}, {3.655488386909247*^9, 3.655488387753139*^9}, {
  3.72589644564526*^9, 
  3.725896447671039*^9}},ExpressionUUID->"5c899bdf-8166-4f2c-8628-\
ba14b8953fde"],

Cell[TextData[{
 "In this example we load the numu spectrums of 1-6 step cascade step DM \
annihilations terminating in gluons for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "\[Phi]"], "=", "50"}], TraditionalForm]],
  ExpressionUUID->"8844508b-3235-4f04-a900-bac5683a494e"],
 " GeV."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.6445980312314053`*^9, 3.644598048158736*^9}, {3.65548839460959*^9, 
   3.6554883957627993`*^9}, 3.6569741280149107`*^9, {3.725896453486498*^9, 
   3.725896453885912*^9}},ExpressionUUID->"4d8f3500-3f9c-4e42-93f5-\
3a4d466ed1bc"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "m\[Phi]vals", ",", "m\[Phi]", ",", "xvals", 
   ",", "flux", ",", "loadspec1", ",", "loadspec2", ",", "loadspec3", ",", 
   "loadspec4", ",", "loadspec5", ",", "loadspec6", ",", "dNdx1", ",", 
   "dNdx2", ",", "dNdx3", ",", "dNdx4", ",", "dNdx5", ",", "dNdx6"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/Cascade_G_numu.dat\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m\[Phi]vals", "=", 
   RowBox[{"load", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"2", ";;", 
       RowBox[{
        RowBox[{"Dimensions", "[", "load", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m\[Phi]", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xvals", "=", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"load", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"2", ";;", 
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec1", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx1", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec1", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec1", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "4"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec2", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx2", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec2", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec2", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "5"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec3", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx3", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec3", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec3", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "6"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec4", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx4", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec4", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec4", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "7"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec5", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx5", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec5", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec5", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xvals"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "8"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec6", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m\[Phi]vals", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xvals", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx6", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"loadspec6", "[", 
            RowBox[{"m\[Phi]", ",", "x"}], "]"}], ">", "0"}], ",", 
          RowBox[{"loadspec6", "[", 
           RowBox[{"m\[Phi]", ",", "x"}], "]"}], ",", "0"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx1", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx2", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx3", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx4", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx5", "[", "x", "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["x", "2"], 
      RowBox[{"dNdx6", "[", "x", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Purple", ",", "Blue", ",", 
      RowBox[{"Darker", "[", "Green", "]"}], ",", 
      RowBox[{"Lighter", "[", "Pink", "]"}], ",", "Orange", ",", "Red"}], 
     "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<n=1\>\"", ",", "\"\<n=2\>\"", ",", "\"\<n=3\>\"", ",", 
      "\"\<n=4\>\"", ",", "\"\<n=5\>\"", ",", "\"\<n=6\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.638539003567604*^9, {3.63853912444792*^9, 3.638539127218301*^9}, 
   3.639056012020714*^9, {3.639061226178513*^9, 3.639061230000971*^9}, {
   3.6390626177280293`*^9, 3.639062624597332*^9}, {3.63906296534056*^9, 
   3.639062980297701*^9}, {3.639063055035693*^9, 3.6390631177028913`*^9}, {
   3.6390631611248693`*^9, 3.6390632086441917`*^9}, {3.639063255187817*^9, 
   3.639063372221395*^9}, {3.639063453287771*^9, 3.639063453456121*^9}, {
   3.639065249443858*^9, 3.639065249635944*^9}, {3.639065298154196*^9, 
   3.6390653719402437`*^9}, {3.639065422048918*^9, 3.6390654312306767`*^9}, {
   3.639065516186607*^9, 3.6390655534937763`*^9}, {3.6390662025372047`*^9, 
   3.639066307136261*^9}, {3.639066415538189*^9, 3.63906644737391*^9}, {
   3.63906695110944*^9, 3.63906695878749*^9}, {3.63906754287934*^9, 
   3.639067542949849*^9}, {3.639067579548677*^9, 3.639067606031039*^9}, {
   3.639067650511935*^9, 3.639067650589734*^9}, {3.639074796825118*^9, 
   3.6390748073267813`*^9}, {3.6390748438453493`*^9, 3.639074846996669*^9}, {
   3.6390749186703053`*^9, 3.639074953027285*^9}, {3.6390750100090322`*^9, 
   3.639075125887274*^9}, {3.6390751643031473`*^9, 3.639075298122554*^9}, {
   3.639075328947755*^9, 3.639075515143014*^9}, {3.63907635788829*^9, 
   3.639076401263814*^9}, {3.639076434207601*^9, 3.639076487532075*^9}, {
   3.639076690007765*^9, 3.6390767031080008`*^9}, {3.6445771538368177`*^9, 
   3.644577154500536*^9}, {3.644577235378191*^9, 3.644577356050426*^9}, {
   3.64457739648755*^9, 3.644577513568507*^9}, {3.644577544232073*^9, 
   3.64457754799872*^9}, {3.644577605357257*^9, 3.644577624050283*^9}, 
   3.644577673866103*^9, {3.644578087963068*^9, 3.6445780888099413`*^9}, {
   3.644578251564781*^9, 3.644578254195959*^9}, {3.6445808713366413`*^9, 
   3.6445808713648157`*^9}, {3.644580921951578*^9, 3.6445809266978807`*^9}, {
   3.6445809743232603`*^9, 3.644580978731881*^9}, {3.6445810985910177`*^9, 
   3.644581141708456*^9}, {3.64458119834447*^9, 3.644581198567319*^9}, 
   3.6445837383232327`*^9, {3.644583956159071*^9, 3.644583973382719*^9}, {
   3.6445848902302*^9, 3.644584890748803*^9}, {3.644584932860217*^9, 
   3.644584948499735*^9}, {3.644584996744629*^9, 3.6445850332899446`*^9}, {
   3.644585191186246*^9, 3.6445851953794117`*^9}, {3.644585405650796*^9, 
   3.644585428326337*^9}, 3.644586384471479*^9, {3.6554883904755487`*^9, 
   3.655488390913857*^9}, {3.656974151600212*^9, 3.6569741518050528`*^9}, {
   3.656974868342043*^9, 3.656974892887167*^9}, {3.725896460404813*^9, 
   3.725896473611602*^9}},ExpressionUUID->"549714b5-d728-4a06-9893-\
c99107eba91c"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         LineBox[CompressedData["
1:eJwVV3c8198XJtlbZe89vpQiRPdaSakIycrKLEloUCSErJBNiMxUwkfDeJ8i
KysZieyMJCMjs9/n99f79bzOvec+z7nnPu97RRyuGjvtoqCgoKWioPj/9/oF
+tiIJ3KQbZ5X4nFWD52Sm7e0ypIDFqu0BPsgPSS63i3x32M5mF04uxfK9VB7
QnZVW4oclA8rxNdxHUeSrSpTbLFyYO+ju70zcRx9PeKMkgPk4Oq9oUOiiSfQ
C7pT9K535CBmOOGydtsJFNKr2K3qJwe5s5ysQ9Qn0QGvbbdv1+WA1S99MPLW
SfSgKCFR4Ioc/Ciomh2+aICOcNf9yrWSg8JprsQbJqcR22Thax8LOXBlyFru
eXQaTZbHBB07LwdnE1w+f+g+jeINLbmnjOVg/0XN2hPmZ9Bs6KKO7Ek5UAvr
3ZJ3NkQZK0LppapyQNG/a0Kxwwj967pzomafHOz8iLAL0DVBh4kmBts9cnAt
oHrnpJcJ8ni2t5WCXQ62yl4dDMk2QYPBJWd0meTAmYYpSXPHBL1RGjT5tEsO
4lF86r9aU+SZpG7TPy8L4+9FK1LMzFBBUJjQ7TlZ2PBZCINIMzTk8WWEf1YW
viRcf+Hy3gydOn75ot2kLJgzcOeqKpxH0n/TXKcGyfG9c340LOZo1GLDa6VZ
Ftpi2KUcpywQt56eUnKjLGCuhRQOCUtkdDB+RfWjLHh0s8ubXrREtQyyt+6A
LJj1quxKGrVEaVUW/lSvZaFIbeyT2g8rZCzwNoz9qSx0dV24sUFvg+pGbmbI
B8jCL+emeM9L9kha+H7E2m1ZmEpuuikQZ4+ibONvvfeVhbNLNTtCb+yR6VCJ
6bnrskBptLwmTeuAJgZGmfzdZYHK3tHdrsgB0fQZ+LdaysIlfCdr77+L6BKn
xeUkc1m4NtHs5ivniNrPOVvYmcnC7xL2VE1zR5TUHai8fJbML8n70XqZI5Lq
Is3xnZCFoLQVW4UrTki/TcjmsoosPN86eOnSijMqYZI/pawsC6Vfn76ylXZB
bKeOHPl3UBYiOs5TNli5oK8tppyPFGTh2/gR0kydC3JretD+TkIWHN7u6S9K
dUURdX8Qw15yPS1HCv9aXUKtbxuFihZkIGKH5vCSjgfy+HFTOuC3DPjP09F/
u++B2NmlFU1+yUCdCXPh2SYPZOYarr09JQNBH//xrJy5ikY4TzidHZYBU/Yu
/2RFT7Ts3VK83iYDk88tunRMr6GkLL/y9k8yUCnDlk/hdw2pfZKtzm2WgWF+
ilmW7GsoQDSy7fRH8vrHPt8UmLuG6D4bLDyploEjZ048ORDphfgV2pRPPpMB
qT/pM9193qjWwh8JFclAdVvO/t1UPsj+vvzx5XwZUPH/aBOn4IPyB6PNM3Nk
IKWm6k1TqA86EHnm9lKqDPgkq0d9UL+OdKc7IC1cBpbi/HY/f3MDued0Gcw6
yUDss9ucr3f7Ic9f0yfjLsqAi1sN+wFtP+R9+N8JFXsZCHZwMjgS6If8WuT0
g61lQIlJsYl2xw+FLYXo8pnIgBZXjOczijsoR1vlqIGmDECPRoaGWADKjzqt
sXhUBqjyBg66XwpARb0X1ZPVZeDz2mCvTlkAKr0UqzZ+WAZqd+jDF3Xuotr4
GeXb8jJwgniV/FYlEPWPpSs845WBW4UFo5o+99Dgf2XyZ7lloL0v4P7tx/fQ
yI2m/9b2kfMdb47lbryHJhlWZHXYZYDlxPxbP74gtHzwjNQArQxYjUSu/W0K
QmzBFMKMK9Ig8WFJ4pVKCNITc2K/3CENYTKDx/gvh6EboHFUrU0arJbTdN9k
hqGCC3vdaD9Jg+2B0vmPXWGILqUOchukQYv94JEjGuGohUnUc7BGGhJmlIty
9j5AZ1aH2k+XSEOP2s8Gy8EIFPCocoOvWBpSQ13ORXFFopcHYiR/FkjDoRM7
lpomkYjt8tGA0Fzy+F11JkqtkahrOF2eSJMGh9jCac/6KGTWbB514IE0yEUL
Zyp1xKBQ5wNvdkKlwVqxqpdvz0P0mopuojVEGk5esIaU8w8RN3qt7hYoDZXb
Te3mYw/Rt7J9s09uSoNdv9PxyLuxyCaj68QeZ2lwCjhTa/UsDjldPUW7qi0N
jgMph010E9CqbIRMoqY0BIZ0+xA+CSh8stFACUmDstQei6y8BFR8QSfWS00a
+kzoHGvpEtGCwRGe+f3S8DteSC+lOxHdkZaWm+aXhjLbzIi3wcmIZcLpdBiv
NJhYKyxNViWjrKzcq5Lc0tAZ7Hw9bTkZfeAUqnDcIw1x63/bUlxSEC0159FR
emlQ29Bz4TRNRfGjVIbfVqWge6jygIZ+OhJ/rHXNd1kKvM1o/VwepCOS+d1H
3EtS0CkxwKrwKR197djoM5uTguCe83OxRhlIoHbR7su4FATERz0fcXiMCtOG
vVo7pUAuveAGZUEWqjWpSqotlgLaRtthP+scFLOZ/sW1UApkPDQ6w8NykE3u
HbY9+VJw8/KLus2yHLS9dDTC5YkUZPgxOe5lzEUa8eDPliIFOlZbZNfORe86
Pzo63JcC2ZItqwaUhyJu5T9hCpYCvUWD2mTPPGQpHDZUGSgFYTZOk99z8tD6
VX1zxjtSEDNQk9FKl49UWT8ZVHhJQXOWnrPht3xUebrzII0dWV+Skd9SQiEK
XSm9WnpBCrgPSloktBcis8dxJZZWUsD7UUOthq4IrfwylnxpJgUlg5K/CwOK
kFJUD4/5aSnw9A2/yHitGJW1fKMoPiIFw5fvnBe8VoKeH//RfnofeTzbsXAR
n1JUrB2mKrxHCiaPRFdxpZSi/KMyOUtsUvDzvLm/dXUpyj505XoykxSIv621
6aZ+hRKEVvhGqaRAtSE4LS7jFfJb2+3msyQJqtOIZrS/DN1cyu/SW5CESGXx
hr1U5chnTl+D57ckbBeohOf8V448xqNYa2ck4fm+KbGOwHJk37G3knZUEsT1
8qOC5CuQfoE4VXqHJDxI+6FPk0pCx3Ia3K+0ScLTXCJXrYmEtB+79uJPkvCd
kWHlyxoJqT8qKZpokATj9PgwTfNKpHBXyUihVhJ64NfefYKv0b7zuo/fl0hC
v2yQlV/tGzRG46gy/UASTFc5YzgtqpGmsHtyZJgkaGgZNehkVKNMNZ81hfuS
cEHCaJF1pBpZuIe8vh4oCQ95Mv5FuNWgzs9PVahuSkIT9cqwckgtqs34oSLo
KAmnxlw/DLoD4q+cS35vLwnCR1Y/NDwC5NexsuZoKwm/DPvbmKoAKe+iefPM
UhLk/DndShneoxIXSVW1s5KwyETZc+XFe5R60EXVFEkCwzqvfwRdHVo1uJqy
pi4JtySqrLOU65Cp082/aWqScEZuX7fgxTrElhL2ZlSJzG93kZ89UYdCtwtU
r8pJgjRrDMHuX498mqZVI7glwd9HVoiWpQEZ2VxSgyUJcHi33sER04wGWg41
RC5IwAnDrw3hDc3IWWXb+PxvCWgRyle//a8Z3WaLdf89IwGuhRGT/V4tKP8D
KYt/VAKoy7veZNh+QtuSlDS+HRJgRWffeci4DYU/aonXbZOAwzYWy6vxbYiD
IkGI7ZMEVAffbdXvbkPS/ZJqBQ0SUPfP4u5j83ZkGnnKvadGAj6ZzLbLu3ag
4vnkLsUSCbA0vUdH3dWJlK3tbbeLJMAlhjtceq0TQZPsr6YCCUh5mdf2mP8z
6nlSQ22XKwGKxkFWga6fEYXpuGpMmgSIsBX4qu3uQuffKGT9DJeA4hyjC6Kn
vqDd9z5eznWSABoJM35DsV7U1q+4x++iBMibZ88qmPSipIOZ74zsJeB4nP/c
9eBeJD1xg37Hmrz+Z59/Gj960enj0gXmphIQkehJ2fS8DyUxR44x60jAHfPN
4QyTfmTrvPZgQlMCBLg1cq0i+pE0cVGxCkmA/fMLRrHv+1GVp0ag6xEJ+Nfd
bmWr+A2NfJkTqFOUgN1+7GalnANIJs3I4pawBBjUC2tRrw+ipaVqCkNBCeAb
Swt7rPIdVRvIFErwS8Ahf9rg6hvf0ZltyrUuLgkwdn3D92j1O/KyK0+QZ5WA
S52+Cx+2hlC1JGfn2LY4tCgF7OGLH0Fnygf0Tg+Ig6Z1d53Q8hi6JftiYvmr
ONy1tda5LzyOcp4EBmX0igO7c88x49PjaPWhRO3sZ3Hg/GQQL1k4jjLdrypH
NImDUmjVWpfDBJqXoBJvJInDQv6kHtfcD8T7uOe9R7k41Ap1JLoJTyLdvYW2
nK/E4T3/sP0h00mUsut0ulOJOCiTLtYp1kwizeEkjt254tA3FOPzN2EKxabI
UmrFioMDzbByifUMese6nTkdLQ7h6YoHt5Nn0ERoh0ZspDhkePkLfP0yg1Sv
+9waDhWHogMNVQdO/0QjZ2vn/f3FISuxviJWbxYpMhoPvbskDkZpgl8PnZtD
Xf6+VUrHyPpPHV4bXllAMvrMobt1xEH6iwBtB+8iCuR4YtStKQ7pwzQvmDUX
kUJB0w9vDTL/xBIx/8hFFNnJxVZ+SBzswvifq0guIV2xSkdFUXFgqNJdeH35
D0qfO7GfUlgceGYDONcS/6Cl19/XOwXEQWTJwyUO/qDsU9QPPXnEITjiXMI3
zmW0fd307Us2cdB7GAHdjcuosmmJWeGfGMTfi/7Dp7GKmB+Fft3eEoPEEz4l
7u6ryPECb27bhhhczNK9LfF4FXEsaaleWRWD5O7Fjq5/q+gqX5xDyZwY+LS4
ziu1rCFpj/2vZQfFALLYxke911H6Hnc7qbdiwPCQ1yZdZBuZbjmJNFWKgWK/
RgOH8zZi+mE75lohBioaWe4yz7bRnUoTx+KXYvC6SF3yiMoOsrZQd5XPF4Oo
JfSd/fw/xJ/F4HnokRhU8ew0+gxQ4O6w3YrdsWJQ35Z1lIqKEkd57iz6xIjB
fs7Um3OylHhLa8m78oEYeAQn+ny9TYkHJ/pvqgWS9axtdAuJ7sIZskV38RUx
sHqgek7pHhU23ZOrOXJJDCx1DSsmXlBhpq0MynuuYsCl8LJmZ5AK32mLDf5w
UQzemQZEex/Zja09b4UdsxSD94uvG/02dmOByuMPDY6LgY7dPZWBhzQ4U2sy
87yIGIRlPU3U4GLACZzBflRCYnDn34cj28YMOHJWyOwlvxj07pXJ033IgG8l
WjDTcovBcJ5cmzs9Iz4703q7kkUM9K38mLV3M+HdceXm+7ZE4ViEex7bPha8
4WSk9H5dFLxo/QzbLVjw4pE51itroiBoEnNDMosFD01INtYviYL28t/7z+RY
8RvVNGWfGVEQi/0oySXJhi+PBHJ86RWFs+wDvlJm7NiBJPA7oJucT47+TYk/
OzaPeNcs2yUK7AltHhF57FhXaTkwqE0U4s7P6BmvsmPBcJd5xXpRqObP25bO
4MBd+8+0xr4ShaRrwsk563uw6l2+0DNRomCXoWWfTsmFrQt8Y0QjyOsfs5FV
P8iF73b0Ja2GiYKPdUogvsiFG4QSCjKDRYFr39H1Ww1c2BSYmn/7icKyY9K1
j3Hc2JNyh/GhmyisU/mm3tHgxQky1nsvuojCz/cTLI3evPj12Xf8Kk6iwJgz
bRH8jBfvPLkhP2wnCh/lhtdM+flwlPb8mf3motDg+dv+OhU/LgweievQEwWt
j/Yzt6YFcOszlJarKwpA5UN7RkoQz3/JyLmpLQqp4RyDuc6C+LC4RbkQEgWr
8MzMnklBXF//ufuqsihQSAcVXJkTwiPUdVxs4qLwPC2Y5T8GEcwVnvfYiFIU
qLcz95q7iuGMdreMlR0ReGRveFovQQwL71NIT9sSAXeq9X2JIIalcypTJtZE
4PGjvUHnecXxkerGR7d+i8Bw3Pj30C5xfGFh5kH2gAgY/Sf0Wc9MEo8dfhF+
rF8E7m1TemeHS2Jnf6+wn70iUHdm/27XKknswbAZotQlAifD74foikrhQHGm
wKYmEXiZdvH0qRUpnGuucGOBJAKm+xuMXV7JYOmsJZ/EchGwGmy4yjIrg0t+
VHofeUXmy1kadlBCFld44WshJeTxUUeLV9JkcUOUkTt3rghcqEk/GBIlh2fA
y0EzVgSuBxt4lYTL4/0yr8/EXhKBy0Cj5bN6AI980PC74CoCZVqLlY95FHG8
9Yc8WWcREP3Mqcp8VBEvP2zbqrcn68mucoUQRfxudbx43VwEfvElM4dyHcR6
9Wy0F4+LwB6H3S+pDQ7hvxeSDh44JgKc9+8odngdwkVrfDbb2uT4um7yVNoh
zCQnRUpGIrC/1baM5tch3BV39GKrsgjs6OuzscQrYRvbS4SyOJlPRHDGxzll
zLY+/3OXqAjMcJP+A97D+H38dc5OIRGgeS27wKF/GIs3BF65xCcC2vQ0yXW5
h/HP/5L5sjhEoOH3SYOLtir4xkbdTTpKEXDr7RFQnFbF0YkCBwa+C8N3S4/8
Tl0NnH2a3th3QBiwj+2N30EauIx6xZurXxg6+R/QxbzXwL3XW1+bdAtDy81n
tmaaR7Gw2W3c2iIMtSOacdK6CJdx9p+peS0MzDqYeuCgJq5vr/e0IgkDiOCv
SmaauC+0NH69TJj8ntzf0OeribdWw3qVXwjDnbdWQpvvNfGxvsM2L54KA9PX
oION57Tw1+SEK1lxwnA4wnLgT6Q2/mkY+PDoQ2F4f3wfnViFNt6mdX81ECUM
e9IzvZ4OamPRWzorXOHC4LR42iVbQQdfNl+6ExsgDIbxQ53RvTp4h9so6t5l
YYgbL1hqPnwMi6cxPrt4TBjMHU5cszqqj6+jtCkmHWGoc910EvDUxw1j0uKV
msKgl0a1oZ2rj13k9B7TaQiDyV5FqGI4gYurAx8+PygMOhzn8M2hE/jA8Ir3
mpAwcO9/fpKUaoDvBYeUZguQ9bbRT1J/McBdUnvmTvCR8x+JePaR6RT29jzg
nMEpDHw0+x4k3juFKykvm2sxC0Mx38PJSM/T+IY++HKuCMGaX2zBPUdDzB33
fcl1QQgGO1JqhPMM8dv+jctVs0JAmch+T33SEG9dUraxGxOCrGz1l3+UjHBQ
dLF2cYcQ6G4WzSVXGeHorgRGVCwEQvflZMV6zuKn1m6PnWyFQMNn3NNawxRn
G9B70lkJQfnnDzMBDqY4/UiR9jMzIbB5H0gaDzfF8dwzUwunhSD8/OGTN3pN
8b1u14N3NITgGmrdbvE5h21OuTbG8whB2rX69NBaM8yt4bJIfBGEBwV7itQe
WOC9crT1Dh2CoJyh3Hj9jQVm5S1Iov4kCIILEwOU0xaY5u+kusEHQahuV6lh
1LfEK+XOob2lgvDCRPjkH0Yr3CXnzDcXLQj51x9H+uVa40g+p2O8+oKQcFHm
gxODHdY//nm3rY4gmOvstfstY4dpvI/W5yJB2KdtovjyhB0ObNmnI68sCE9q
+eq+PbDDN3wbNDVFBUH7kyXzOJM9duiT0nDeEoDm42xvdws6YNVHPw+WlQrA
nyHdY7uuOuLVWrOl1WcCYJl93e5okiMu//nhlXqBADTxmdJX1zhiBe30Ax8f
C8AE7UzofWYnLLZooPA1QgC4dBt6TUqdMIvhc5kdRwHgrTr65wCVC/7B4Cl8
kkcAEvo6Ut+NuOGtQRu14b0CcJBFm2aB+RLe+/K0sQ+bALy8Uud3Wf0S1jWR
C8mkFQD3EIvvysmXcE765NTSCj+cDBMSFTa+jG3+u/AyvYsfuI/vMcvuccdf
T59Ec5H8EJNsQjvP4IkXhNTOB4Xxg/Zq+aaWpCemXZLy5Armh4uMaTU1Wp74
cBJ1jpYfP6wPlbsf8PXECUNAneTKD8iXo4P2pyc+e1WlDR3jB13dspCiL9dw
S6y4dewOH9Szv2ihbvLGNuoWxeobfJDof0tCdtobL/2I/ju5wgevVM+k36bz
wXzqawlH5/jA8bBMev4JH+z+o7nt5wAfdFF7aYq2+2CWI1fxsbd8kGD7Lu/b
8HVsMv5WdMObDwxXDFNCpW7h6ejfnnlX+SCNwTO86PQtfEdVjDC6zAdOMou5
/7xv4afRUVYFDnzASV8koff+Fl5VsU0wPcsHIbLmjVo2vjglajfNSwU+eLMw
5iGY44cHlQ1nLs7wgv0XP41wY398UMBI/NUEL6z+bPQ+GuyPw3eftd0Z5gWx
pUzBwxX+WOmLcU9KLy8YBUHDEmcA+T5n9r6tjhf4dgdRZw8H4KPPLqSqZPLC
v4BntPMoEGcKu59gNOEF3nCba0tr9/Ay7ZUQ8zO84EP3rqRqbxA+OX+FyDvB
C4ePvL5arBiEV2uuKmtq8oK+6M3Nv5eDsKGVt8h1eV4Iab785fRYEKZI8lsf
ouUFpd9r63K9wdie8UFRWTUPcGbr5z4cuI85UpmQ0Rse+Dw757W+cR9/kIzt
mivnATZ/H/Yw3lAsqp28Kf2MB4heAwkWy1A8fivvdFYqDyx8mvRv/xaKnSbf
L0be4IEPR1lN5MfDsNv7DTWnAzzw/MmcxivWCMxrGNC+6z8e6Gbk//D6UARu
GaS8mC3FA68NXz+dOB+BZf/SRQ0I8oCKwsjAq+wIPKvANXSWmQcq9R848CtF
4isZh4LQT25QZFts1HKIwtduurdwPeWGm4ZXXJMHYvCEVrXB+SxuyF5jPj5H
+xCbMTG1JaVxw+Pp/257KT3ER54869gXxw0fTh35jzHmId716Wf3ngBucHF7
VVAlEovjBd2GWc25ISnt+YXQgVhc9tFpmZaJGw58yT33yS4eL++xFfzrzQXn
F95WFJUl4vHK5e7TV7mg51FGxOH2RNxlERGZe4kLnnh/s/82k4hfZpH+nrHn
gmFWHh0XkSR8SY7pS94ZLjCW8VpJikvCI9pvw0xkuIC16FiI6Y1k3Hptz+KL
IU7Y+MfE9cIoFed1NNY5neAENiehm6zHH+MRkW/NMwf3QaFE7lVcm4Njnm7u
mtm9Fz4wKPzNzyrAjTUNGTs/OaDuZvJVCusSLL9KG/6klx0CerIyYj1LcafK
PYqlz+xw5lAR6a9vKfbx3bil3cYOggeZc22CS/G7rV9u43Xs8CmZx0c8qRTr
U3UZSLxiB4Hc7Pi0qlLsyJbBWhTJDh97hAJVaV7hNNkDyaWa7BD9VAM/T3qF
aW3N84liNpBqOPWfcWEZ3n3c9JZdPhvUFxS6UZaW4V37jU5S5rABR4ZY5vPX
ZXhn5/hv7VQ2uPvxu85WQxlezlQ53BDGBn7Hn43nTZThkSHOhlZHNrhgcVXt
kmA5fmvT86NfkA0WLlwNZX1Yjiv1Pr/242WDlM7rOqTEclyh0PaAj5MNsmx2
K57IKMcvd+rlLzCzgRpnvuGFonJscNRtFtZY4UVj6vGjdeVYvEaKsf0VK9in
HnpDu1qO+6qfnpyWYIVhx3IuK7MKbEaj3HSFnxWaH9B3O1pX4G7Dj8f+cLCC
R3FwsrNDBe4a+6G5848F0vSb3Ew8KnArnZTK3m8sECEQfr//fgX+YFokphnD
ApcOeaq9K6/AWplqTz6GsABF6u1Uy7cVGKaaBQ1us8CH4BGL5doKXOP3k8fM
lQVmvqt84GipwG+y5djctVnAYXH0h/NQBX7x6/lW8ioz7JlFpvTUJCx/GPkJ
zDGD+duByHf0JFxyt30tZ5wZzrEfbXBkIeEijvml553MoFfZ2PuUi4Sfqh6Y
qStmhq2a1zw9MiQsFgTOJ54wA70GpamRAgnnfDKaaE9mhn/Tmw/qD5Jwls21
4f4QZoBvVweT1Ek4LaSsZ96GGYL8zwglGpAwT7u2yfVzzCA6EcRsZkjCKVxf
OjcMmIFXbSGSyYSEE4v/fKJWYwbFh1M/rSxJOLZT6QPfHmby/fxbc4wrCYfy
v35xvJEJ9q3WawcGk/DbslPDV2qZINv4OU9YKAn/0h9jTSAxwbGc0OthD0jY
+DrztZFcJhDQTf3r/ZCE7zPmPqFJZwIeu3PptvEk/OaJatd/8UywMuTyRieR
hAXbLx7yDWSCo/69SDeNhM86rl/MuskE5Sn9zo8ySDhkIybhowd5/sByX18m
Cf+UfLfCfoEJBst6DmrnkvDru2xvitWYwKCKR7ngGTm+L3+68wAT6ObxiD17
Ts5fos6zJsUEdJ3LAgUvyfm+OvvpcDKBGdaRDy8nYSPFGo3BJUaIGt2d9Ocd
CQc3Gl/Z9ZMRWJ5ybFRXk3DlhenH0qOMoDg/fOVuLQnzR+z559PBCMWXRtD8
exI2FC7an97ACFfUHpln1JFwUCWye1/DCCXnL69rfSRh0qnu2KkKRqBUvjIw
3EDC02Nu75lLGEGJLb7wehMJ8/n+WzyUywiM+4bWd7WQ8BnWRFHLNEZIemC6
wf+JhO/lyZoExjFCzgZJjqOVhCvUITg/nBGEImW1Nsl46vO5ita75LjK0ouv
bSTM6zo7sXSDEczYUn4Ut5NwYAKnHnZihKf7Yy33d5JwuWzJDSdrRng0FXxx
jIwnQasg0oQRdr3Ia478TO6X8319r04yQkv4wQm5LhI+NedO91WLEUhSX6nq
yPhu8C61HVVG6GyR8jr7hYTLeFLcxA8wAoMw1bU+MubRq2vxFGSE81x92y3d
5PmD5ptJ+xjhz93scdUeMh+v33I1TIzwyVqHLouMy+lCrMepGOHMcpn/NhlP
ZvJE028yQHi38knTXnI+5Zc1+5cYQDEoxyWXjE990v19boYBmswTPvwk47v2
3wTvjDDAY6sUNdk+Mp+1q4Y5fQxgSzqbYU/GP6KpA5vaGQDlJBbHkjG3eHrp
748MkB8QsOc1GRu8OzC6t4YBvMqu+3STcYBRA7t6BQO8G0+U7CTjV5NW2vbP
GOD0wYkAAzKeuLPoFZbDADbm0yffktc/WcTf/SWWAS6mn0YeZP43Fo5elQxn
gFvK3/e8I+vPVbFl8L3LAFeH7rzbINdn6+MTTUEPBnDN8OG1JtdTmrluwNOJ
AaySVZL8yfU/Zzpxo86aAdjlppwTyfvzYkzyuasBA0Tsc9YrIu/nNxl9/Spt
BmhosBnLI+837TW3ceYjDHC/2fNXKrkf7P494ymXZoDNZnZaN3I/cfArhm5T
M8Cl7aaj+eR+RBeNRYy26cHeiv2yfT0JXy72rs5Zpoc+c2bbveT+TVlMOL8y
Sw8ho7E/a8n9Xa9auXR8nB78xT+12wEJL9zti077Rg+/eOyr18nnQaDxr/Tc
Z3rws71r/KCGXA8W3nrcTA/nGNWbd5HPz41z6rbxQA8lIhf5p9+S/SvDemPi
NT2YSUnZEK9JuGPcP1HlJT3IMI/sfUAi18MLPg0+pof6ZzC9UkrWG3NMVeo2
PfQKpV7WLiBhml7nL75e9LCvZLP43VMSPiQQ7tHqRg8095jnpXNIOOpZy9Nr
5vSwa0mxd5rsH6jJkL1amR4kXjr6bMeR8CXWayUs8vSgGdpqJU/2p2Sz+OP2
4vTA4V63YhpF1jfR7U+zhx4yS9S0I8n+lkNp+dNogQ6km8M44/xIuF3/9v3c
KTpwVn9Ue/smCW8+zBBeHaIDA/AJtfYh8++rqdLvpQOmzYrsXE8SNhUcNktv
o4Ndf0sc2t3J/NUd634U08HzSM3Pf6xJ2M3HI8PPiQ5Yhbv3S5L9m1dZmp3d
mg7A7c4bh8Mk3LIyer/AmA6OvQrxTFQkYdmb5652YzpoO7F2bkiK7He+GtoK
vHRgu7ZlT7GXrO8uw/RoOy3odr5nS5uqwLya9da3PtJCK40p89XRCtxCEfCZ
pZoWeulYjA4PVGDZoMV36kW0EFk345zZXoFnQ75GJwbTQrqS7uaPigrsHpF/
6IQqLTh1ywmU3a3A/AZ2hcMKtHB8P++uH7fI/1NGXoEbErRwzauTmtWrAv8X
HU2Ty0ELfUZzE3qOFXjuoU//1i8aeNugKMulV4E9ErXvlj6hAYHbFbRK1BX4
avZQCxcjDVDcfiUndbscdz9/vHRmFw1IsYcZi3iVY9Uqa97QdWrooZvcYHEr
xxS939yWp6jhS47Wk0azchzP2Ef3uZ4a9FTuJYAi+b5xo0MvIoAaVCyjHI9P
luGtU/Bha3E3FHJVL6/pluGI9SfvRr9SwZfK+099ekqxV+B6lXUHFSSy3FCg
ayrFlrRna/o+UkFYxb2d5HelWHYfBbSVUcFB/VdBL7JKccsBm49vo6ggkMQ1
D26lmMGVtzNOkwquRrXJhay+xBG98T+0CnfBlZ742hKRFziyPJgt5yYlIL38
wReninHH+VyODe0dIrVxOsHdKQdv2PkYRSjuEJ+k7S2u6+dgyUvHYniFd4i3
jE8L0uVycMCdKXr17W0idvoEob30BP/3RI7yzuttIoOzWOpf4BMc/rN8fltu
mxiDIcqq9Gys5V/fSrlvi4j+9GY19+Vj7B6ayBBPtUUUaUbkuPk+xikPnfVF
lzaJ4B6tsVs6j/HCE7p67Y5NwvHPRPa1rxk4s+FUVfCDTSLKeF/0KkUG3mDt
KaLe2SAKI+8p5JxMw+U5P0Lpp9aJNC1Lf27OZLJfT90U6V4nqu4U2sSPJmHu
9BlXtffrxFacwEzPsyQc8GjupFv6OhHNaBISfTQJnwxZYWk2XCe0Qwa2yhwT
8YgTdXL4m79EUFUV7Ub9I8wkI1FAG7FGiMpE3r1ZH4uxhFSK0M01wuCSfqF3
Yiz2EpF5oOK4RkyaPjT64hyL+3jkL7ugNSKAwnhXM0MszmFQ3t+4tEq4VDr6
Fb2Mwaq/dF+HWq0ST9vMmW6wRmHHl46N1PIrxOHXDHUeAmGY4tg1QVu+FWKM
O1U4/2soTv/mf/0N/Qrxr1uO6WlCKO6iTha7PLlMsItsn19nCcWa1s13O7OW
CceVSTEu5vuYj15BNZ1jmdg1bnzYVDAYV2YeebhMsUzcO/jpUNtwEDZWOj55
ev4PUc3iZj76JAiH29olULT+IW7cEsmblSK/B0nxC073/xD39HYy59Xv4S6H
tcIDf5eI5O4bw3RMd7HHXyqKiMklovlQiqtEXgCmj2E7P969RCh2xli9wQFY
860MddKrJUJwmVtQ2dcfP2e1tt+8tERwUsiPPdy6jcOrgafh+yLR82387n/z
tzDmjIiwqlsgODP43BfBG7czv6hkLlsgLJK5WU74eWNr6q4xInuB4KsweVmv
5I1vLfOoiwcsEHO680JPcrzwq66i2V+qC0ScSK2qi/81rNnSxpUltUDsm+Kr
u3r4Gm5/v6hzlnOBiKc6hq4teOJue2/Vy1PzxLCKDL7q4on1BB+lblnPEw4r
u1fc6jywA/PAot2ReeJ4+4ujzcc88N0t0ZMfueYJSh2X88dbruA338o2ort+
E9+mqhzz+t2xbHKXlZD+b+JQpn1PB/tlzMLGIah9aI4wzcmM1ml0wbL/LG7k
s80RzcqDTulWLvj47yftDL9/EWKpn3/eWHTGga2Kd78U/iK46hiTekWc8VL4
2RFHwV8Eq/Ap47lER8xyK1W1eXOW2KAPY+NVccRyLqOx8v2zxMSZBL+//Rex
47FrWquPZom/y1d+9ohfxL2UcTlh9LPE/kX3FbUOe7y08HVjdvInYTu+oywU
YI9ZR4RNjOp/EjHShsZvFOyxfm0pFc/dn8Qfz+rwlQQ7/M6v07F4eYb4+juF
pXPGBgvdTP7yt3mG8AsFSfbDNjjrD6tU2/A08SvF+bG8tSVuaXr7Q/PdNDHp
bPy6sMECLz+++LQiYZqIFb4cIqNkgU/qvxbJODFN9O8479hwm+PVDBv+y+VT
REjEopoWjRkW8aIbGIqeIjp2dp9PfXAOnzpelmrsOkUcVc2f52Q7h3MWqbmO
CEwR6qdtBLwkTfEZvefs9GGTxIhIQ3nNTWPsy3e+8479JHHpsb/7xT3G+OkC
xcMF9Unil7/H065XZzHD6MJ4+78fxG3OHHcjprM4b36TpsDyByEt2xJcF3QG
d9bnfeRV/kHoDmpU/qk+jTdSDUNiWMn4yvW8l5unsJFuLuWN+gnC6tmPss1Q
A7yVcnJLV2GCuNOYEtfeo4+lPJbfvaGbIJ5u8ZSeVdbHxjqZvv+NjxNOMlrK
UanHceHc4uqelHEiW9yxh8VTD5tqpy6OUY4Tb7t7mpdMdPFdLp1Ss8ExYpz2
0oXZPh1c/OuXR0vlGHGdf8x7n50ObjlHqnp1eYzQ+Cj5wPuONn42OzUZ2DNK
DDUt1+/z1sS9EJe3/HKU2Eq94F23gDFFkrqja8QokTLDN5NDibGZ5sNRQzxK
lGyqmfsfPorv7VPLruMZJe4c+VmeYKmBS36O2agsjxB9KwfY/7uvjnclHh4U
LBohilILIlbm1LD8pZG0+OAR4ghLhon8f2rYHEdY0NiMEJNT+/gWPFXxi5nv
vXMcI8TnmiMKW8wquOIOQ67v+hBRPEm/nZSghEuiwt84lw8Rv7kaZ6lZlXBe
Bk27yZUhwub0+p/0mEM4qXrXuvzod+KXcPztsoyD2KnogS2/73dC2MuWwfu7
Il469UiY4tcg8fFfv57ItwPYk8nXsSNokJizc+gK23cAu/Gv+VZrDBKTf33f
8Mnux5Yaf54mlQ4QnYU15lRIHmvcmd04mfKNcG99efdmrQxWinJjUzX+Rpzi
tJVSXZTG8hlTEhJM3wiBaNZ+TzlpLFg9bvTvbj/hpOWiqlIpiTlb7Z1/qfUT
JrtjrpfRSGLWweHb/X++Ejz2lwICbSQwxdZAfrnLV8I8Ppv6o5g4/stoWZ0t
8pVQE3lVRxcnhhf5vn6OHugjokfa7dWoxfCYeveWi2EfsRNEPG+kFMXfDIw5
ztH3EZz3KFI+PRDBXVadUtp1vURRQ4IdHbcIbrl85uh+/16C8sQYh06JMK67
3WrMr9JLsFj65B7RE8YDarIcFP96CN/7zy3a6oVwRXqT/2pxD0Gx+3i71h1B
nFdVX9gp2ENMPQ3iee/MjzM/adfWfO0mOGyyZ/Vc+XDSAHwpju8m+AYFZ/Z4
8eKwzeqdEJpuIqraYrA6kxsHMqrv9YIvxIDeLt8X77nwLb63MrZ+XwiGY+4a
HHOc2E2dZKr2u4v4KmvZrXphH3YwOHRJsrCLyKw4o7j2ZC+2tHp1d49DF/Hl
ymdnwfk92OD28+K5ns9E4DRntXcOB9aNlINvDz8TE9MRxv50HFgjvain8cRn
wpS1UCv/BjtWeiY1W0H1mSjx/RPX+YsNy1flUeTUdBKNz0eU+i+xYclPYpwP
b3YSp77fi9k/yooFB57I3VHsJEYGZHOrN1mw4Kr685KTHcTaUYcNK2tmzMqp
+jW0tp1Ykvs54PuECVMcVqKyP9hO2AevtNb8YcRX7oeT+6+NOHFy+rwsEyMe
u/6fxT7eNmJNySF2/iYD/pIoHTIf3UoEx2dURd+nx/Uk8ZfNlK3ES87k1KF0
Opy3wk8dMNNCyFhFs5eP0WD3ZxnJjKdbiCke+8Fnm9RYyZ5fNrW0mTAaGhEJ
FaLGH1r5DCtuNhF3WgWMXoRR4QdB6aNaA42E3tR9ty+fdmEjVT6fDtRILDT9
yw7j3YWHc3lTf1I3EEnUS26bvRQ43yJN7pbbR+K+xfmCc7oU2IOVt5a6rZ44
d6t6Y/LGP6T8MdXo0YF6QuK62QzXrR205cczLpxQR/zmqy1IidxGdQdSr79Y
+0A48PzRflm6hSImuek0rD4QhZurWlGTm4jHmFv+vOh7gsqSOmgmcAON0KYQ
E/eBcDsu4HNufB0Z3t7/dKKLIPJmKPutjdfR0KRC87/UWuKV7ZuR8ta/SCD8
//WsIXadLBn1tPyLNmrk9xyWriZ2pNqr476voXAZedWz8++IU49S9s55rqE8
iv+CwvzfEJfpeh0eP11FSu5yBTm6r4lSU3/SjuYq+tAn21rDWEnsJ3b5Kw6u
ICMd2cWvXRUEURIqPuS9goZfyHAup5YTBeyH00OoV5AHr4w6q30ZYecunOgX
s4y27kvbyUq/IswVTKtnGJfR3nFDhsihl0RGSN3nNr8/SPHdGdP37s8J3Yar
NUt9S+hM3OnMtY1iIobeLHpJaAldcj01Lf+gkPANfORwyHARhWGDg45c+YSl
ttKpH/YL6CnnyTtpebkEvdBhQYrC3+j9nH5D56EnRMjnrxX3tH+h6gcPhVlC
HhOxlA0dhhEzaFUlusIvO4XwUB9i+XV9Eh2YjNCfqn5ENI1syppujqFuafa3
BWXRhNH33VfWhYaQ/n2m0cDZYMKiTtY++WwPulnHylGh70O0XTPMN5huQKlK
5yhM5LyI5pGVE3G59eh/C1OZrw==
          "]], 
         LineBox[{{0.004435848449543507, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16944#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         LineBox[CompressedData["
1:eJwVl3c8V/8Xx6ns9bH33kQimd23pCgj4SsrkZFNyiaVmYSQEZlFVoWPUck9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          "]], 
         LineBox[{{-0.11069340620015869`, 0.}, {-0.10521419164175516`, 
          0.}, {-0.09566542556786091, 0.}, {-0.09089104253091379, 
          0.}, {-0.08611665949396666, 0.}, {-0.0765678934200724, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449544261, 0.}}], 
         LineBox[{{0.004435848449542856, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16944#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 0]], 
         LineBox[CompressedData["
1:eJwVlHc8lu8Xx4mIyPPY2XumIZvuS3aokHwRkVFWyIoiMyuhzBSSEaLwFBLu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          "]], 
         LineBox[{{-0.2258226601814613, 0.}, {-0.21880456020282513`, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.1290861068264908, 0.}, {-0.12431172378954368`, 
          0.}, {-0.11956510309924577`, 0.}}], 
         LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAA1zSDL2dWvL8eFrIZE+h3PogpLThR
77q/pjtBqOkSiz6lACyCh324vzcCYC5X5Jo+NGwrp6JEt7/EqY1/OsCgPsLX
Ksy9C7a/Tb2S7s/6oz5QQyrx2NK0vwPDb4TPFqc+364pFvSZs7/GKC7haAiq
Pm4aKTsPYbK/MRRVFhDDrD78hShgKiixv9pji9V1Oa8+FONPCover79gTxGt
v66wPjG6TlTBbK2/yZWzBR+QsT5OkU2e9/qqvwkrwWrzOLI+amhM6C2JqL8U
M1Wb5KCyPoc/SzJkF6a/tCsm/yK/sj6kFkp8mqWjv7XK5N1iirI+we1IxtAz
ob9NPilt1/ixPryJjyAOhJ2/MiCqsy0AsT72N420eqCYv8033oAOK68+MOaK
SOe8k7+Yb09p6VqrPtQoEbmnso2/ELqJPeB3pj5IhQzhgOuDv8U/00quaKA+
d8MPErRIdL8ZsfUClCWSPhInVQBTK3K/748vxfVlkD55ZrXZ
          "]], 
         LineBox[{{0.00443584844954651, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16944#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.6666666666666666, 0.6666666666666666]], 
         LineBox[CompressedData["
1:eJwVl3c8lu8Xx+0iheexlb2lUkTUfcjMCklkpIxSqIyMiFJWC4UGEslMPApJ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          "]], 
         LineBox[{{-0.3392531333116301, 0.}, {-0.3300058029298561, 
          0.}, {-0.3128979194333898, 0.}, {-0.2786821524404572, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{-0.4560811689804138, 0.}, {-0.44976098740512027`, 
          0.}, {-0.44548401653100367`, 0.}, {-0.4412070456568871, 
          0.}, {-0.43265310390865397`, 0.}, {-0.41554522041218767`, 
          0.}, {-0.41126824953807106`, 0.}, {-0.4069912786639545, 
          0.}, {-0.39843733691572136`, 0.}, {-0.38132945341925506`, 
          0.}, {-0.34812483021071716`, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16944#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0.5, 0]], 
         LineBox[CompressedData["
1:eJwVlnc81e8XwM2MyLxm2esSESF0jz0zk5CEUERkk1UJqRQVimiThHv7msXn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          "]], 
         LineBox[{{-0.5712104247734878, 0.}, {-0.5664794027416444, 
          0.}, {-0.5618959222781115, 0.}, {-0.5573124418145786, 
          0.}, {-0.5527289613510458, 0.}, {-0.5481454808875128, 
          0.}, {-0.5389785199604471, 0.}, {-0.5206445981063157, 
          0.}, {-0.4839767543980529, 0.}, {-0.4796997835239363, 
          0.}, {-0.4754228126498197, 0.}, {-0.4668688709015866, 
          0.}, {-0.45760590069053464`, 0.}}], 
         LineBox[{{-0.4487342037914476, 0.}, {-0.41554522041218767`, 
          0.}, {-0.3471136864263224, 0.}, {-0.21025061845459195`, 
          0.}, {-0.20547623541764481`, 0.}, {-0.2007018523806977, 
          0.}, {-0.19115308630680344`, 0.}, {-0.17205555415901494`, 
          0.}, {-0.13386048986343793`, 0.}, {-0.057470361272283894`, 
          0.}, {-0.05269597823533677, 0.}, {-0.047921595198389635`, 
          0.}, {-0.03837282912449538, 0.}, {-0.01927529697670688, 
          0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, "Charting`Private`Tag$16944#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVl3k8lN8Xx61Zoqwzg0K2sUcRoTmWLAkhRJSdZCsiRFR2QqVooURRJFPZ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          "]], 
         LineBox[{{-0.8014689341008865, 0.}, {-0.7942179552062263, 
          0.}, {-0.7899933424207087, 0.}, {-0.7857687296351912, 
          0.}, {-0.777319504064156, 0.}, {-0.7727360236006231, 
          0.}, {-0.7681525431370901, 0.}, {-0.7589855822100244, 
          0.}, {-0.740651660355893, 0.}, {-0.7039838166476302, 
          0.}, {-0.6496974810539741, 0.}}], 
         LineBox[{{-0.6408257841548869, 0.}, {-0.4839767543980529, 
          0.}, {-0.21025061845459195`, 0.}, {-0.20547623541764481`, 
          0.}, {-0.2007018523806977, 0.}, {-0.19115308630680344`, 
          0.}, {-0.17205555415901494`, 0.}, {-0.13386048986343793`, 
          0.}, {-0.057470361272283894`, 0.}, {-0.05269597823533677, 
          0.}, {-0.047921595198389635`, 0.}, {-0.03837282912449538, 
          0.}, {-0.01927529697670688, 0.}, {-0.004435848449543604, 0.}}], 
         LineBox[{{0.004435848449543514, 0.}, {0.02369415035581726, 0.}, {
          0.028468533392764388`, 0.}, {0.03801729946665864, 0.}, {
          0.057114831614447144`, 0.}, {0.06188921465139427, 0.}, {
          0.0666635976883414, 0.}, {0.07621236376223565, 0.}, {
          0.08098674679918277, 0.}, {0.0857611298361299, 0.}, {
          0.09053551287307704, 0.}, {0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$16944#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}}}, {}, {}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.08532455294852939}}, {{-13.815510274069974`, 0.09530989591002416}, {
        0., 0.08532455294852939}}}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.1}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.1}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"n=1\"", "\"n=2\"", "\"n=3\"", "\"n=4\"", "\"n=5\"", "\"n=6\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    1, 0.6666666666666666, 0.6666666666666666]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 
                    Rational[2, 3], 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.4444444444444444, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 2/3, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 
                    Rational[2, 3], 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 
                    Rational[2, 3], 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6666666666666666, 0.4444444444444444, 
                    0.4444444444444444], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.6666666666666666, 0.6666666666666666]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.6666666666666666, 0.6666666666666666], 
                    Editable -> False, Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.5, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.639074931265847*^9, {3.639074993996307*^9, 3.639075126508544*^9}, {
   3.6390751652623243`*^9, 3.639075298714778*^9}, {3.639075331043693*^9, 
   3.6390755160311527`*^9}, {3.639076375523621*^9, 3.639076401822846*^9}, {
   3.639076469427896*^9, 3.639076488218067*^9}, {3.639076704542169*^9, 
   3.639076717305942*^9}, 3.644577159564115*^9, {3.64457729122045*^9, 
   3.6445773608921213`*^9}, 3.644577402036332*^9, {3.644577432209478*^9, 
   3.644577519554563*^9}, 3.644577554891653*^9, {3.6445776113653603`*^9, 
   3.6445776301037283`*^9}, 3.644577679022887*^9, 3.644578222132937*^9, 
   3.644578262695685*^9, 3.64458100205402*^9, 3.644581163799165*^9, 
   3.644581226672163*^9, 3.6445840561751328`*^9, {3.64458488311733*^9, 
   3.64458489793933*^9}, 3.6445849846531363`*^9, {3.644585180434134*^9, 
   3.644585201868363*^9}, {3.644585409788192*^9, 3.644585435218499*^9}, 
   3.644586406127926*^9, 3.644598056429336*^9, {3.6569741460690603`*^9, 
   3.65697415907928*^9}, 3.656974827319139*^9, 3.6569749001614523`*^9, {
   3.7258964642560596`*^9, 3.725896475177352*^9}, 
   3.726157295926375*^9},ExpressionUUID->"cc974da2-5156-492d-9961-\
26a6ebdad27e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "e"], TraditionalForm]],ExpressionUUID->
  "22581b8a-24d3-46d3-beea-53583c96ddbc"],
 " Direct Spectrum of Final State ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.3"}], TraditionalForm]],
  ExpressionUUID->"0424bfae-5556-428d-8157-d07cb11f1105"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.639076412252461*^9, 
  3.639076429227652*^9}, {3.639076546090394*^9, 3.6390765590298443`*^9}, {
  3.725896542355111*^9, 
  3.725896543277062*^9}},ExpressionUUID->"9da068d9-2622-4cd2-ac76-\
e0be60146689"],

Cell[TextData[{
 "In this example we load the 0-step positron spectrum for a DM annihilation \
proceeding directly  into ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.3"}], TraditionalForm]],
  ExpressionUUID->"74e8940f-63a2-4d9c-a253-6b4647869078"],
 ". For other final states, replace the 14 in the flux row with: 5 \
(electrons), 8 (muons), 11 (taus), 14 (",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks), 18 (",
 StyleBox["W",
  FontSlant->"Italic"],
 " bosons), 22 (gluons), 23 (photons) or 24 (Higgs).\nNote for certain direct \
spectra, like the positron spectrum from final state electrons, or the photon \
spectrum from final state photons, the spectrum is actually a Dirac \
\[Delta]-function and it may often be easier to just use this analytic \
expression."
}], "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.644598060861582*^9, 3.6445981089747334`*^9}, {3.6445982623169527`*^9, 
   3.6445983408554983`*^9}, 3.656974193760705*^9, {3.656974233478744*^9, 
   3.6569743216982307`*^9}},ExpressionUUID->"e3b1d7c5-ff71-4ce6-80e9-\
6689b670c13d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "mf", ",", "mass", ",", "xval", ",", "flux", 
   ",", "loadspec", ",", "dNdx0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"BaseDir", "<>", "\"\<Spectra/AtProduction_neutrinos_e.dat\>\""}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mf", "=", "4.18"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mass", "=", 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"in", " ", "GeV"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xval", "=", 
    RowBox[{"10", "^", 
     RowBox[{"(", 
      RowBox[{"load", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"2", ";;", 
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
      ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"x", " ", "=", " ", 
    RowBox[{"E", "/", "M"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xval"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "14"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"mass", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xval", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx0", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"loadspec", "[", 
         RowBox[{
          FractionBox["mf", "\[Epsilon]"], ",", "x"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["x", "2"], 
     RowBox[{"dNdx0", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.12"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Darker", "[", "Gray", "]"}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", "\"\<n=0\>\"", "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.639076588298305*^9, 3.639076666827195*^9}, {
   3.6445840003231363`*^9, 3.6445840120261393`*^9}, {3.6445851269240093`*^9, 
   3.64458514902188*^9}, 3.644586384478674*^9, 3.656974862833619*^9, 
   3.656974915776977*^9, {3.6569800476470346`*^9, 3.656980047766233*^9}, {
   3.725896555189452*^9, 3.725896556659367*^9}, {3.725896600187499*^9, 
   3.7258966121411057`*^9}},ExpressionUUID->"0c93c203-037f-4004-a2c0-\
314f60f8f3d0"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
          0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`]], 
         
         LineBox[CompressedData["
1:eJwVl3c8lu8Xx41somSvx+YRIat4rktCRkqoEKEkq0FGyUpCRlRGZjaPlEKk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          "]], 
         LineBox[{{0.004435848449543597, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$17577#1"]& ], {}}, {{}, {}, {}}}, {}, {}}, {
    Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 0.09530989591002416}, {0., 
        0.05013224040602732}}, {{-13.815510274069974`, 0.09530989591002416}, {
        0., 0.05013224040602732}}}}, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.12}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.12}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"n=0\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                 RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.22222222222222227`, 0.22222222222222227`, 
                    0.22222222222222227`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.33333333333333337, 0.33333333333333337, \
0.33333333333333337]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.33333333333333337`, 0.33333333333333337`, 
                   0.33333333333333337`], Editable -> False, Selectable -> 
                  False]}], "]"}], "}"}], ",", 
           RowBox[{"{", #, "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.639076611805574*^9, 3.6390766683190613`*^9}, 
   3.6390767190461483`*^9, {3.6445839842947693`*^9, 3.644584014261587*^9}, 
   3.644586407561598*^9, 3.656974333286442*^9, 3.6569748645354233`*^9, 
   3.656974917386509*^9, 3.656980049533836*^9, 3.7258965615539093`*^9, {
   3.725896602080819*^9, 3.725896614136876*^9}, 
   3.726157297483829*^9},ExpressionUUID->"60a56c7f-26b8-4fd2-8122-\
a51f60cee9a0"]
}, Open  ]],

Cell[TextData[{
 "NB: recall \[Epsilon]=mf/",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Chi]"], TraditionalForm]],ExpressionUUID->
  "4e8ebdf5-03f7-43d2-a949-4469c05858a8"],
 ", so above when we specified \[Epsilon] and subbed in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"mf", "/", "\[Epsilon]"}], TraditionalForm]],ExpressionUUID->
  "716dee1f-2e0f-451b-b66e-2ec7a1951ef7"],
 ", we could equally well have specified ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "\[Chi]"], TraditionalForm]],ExpressionUUID->
  "bfbeef61-8650-42ea-864f-2116b8f90897"],
 " and subbed it in. An example of this is shown below"
}], "Text",
 CellChangeTimes->{{3.656974350305602*^9, 
  3.656974455523155*^9}},ExpressionUUID->"eca7266f-16da-47dc-bece-\
e4460f01b852"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Nu]", "\[Mu]"], TraditionalForm]],ExpressionUUID->
  "46469745-09fa-47dc-b8e4-9e0be35ad5ee"],
 " Direct Spectrum of Final State ",
 StyleBox["b",
  FontSlant->"Italic"],
 "-quarks for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Epsilon]", "f"], "=", "0.3"}], TraditionalForm]],
  ExpressionUUID->"6bfc38e5-4042-4c4e-9522-6d79c6d86570"]
}], "Section",
 CellChangeTimes->{{3.6390630204859133`*^9, 3.639063025852809*^9}, {
  3.639076336932643*^9, 3.6390763661398563`*^9}, {3.639076412252461*^9, 
  3.639076429227652*^9}, {3.639076546090394*^9, 3.6390765590298443`*^9}, {
  3.725896542355111*^9, 3.725896543277062*^9}, {3.725896575914863*^9, 
  3.725896576148849*^9}},ExpressionUUID->"35a6760f-eb80-4ebe-a0f9-\
586a5f1ee84f"],

Cell["\<\
To check, we expect the numu spectrum fro the same case to be roughly double \
the nue spectrum. Below we show this is the case.\
\>", "Text",
 CellChangeTimes->{{3.6445976000873127`*^9, 3.644597637650031*^9}, {
   3.644598060861582*^9, 3.6445981089747334`*^9}, {3.6445982623169527`*^9, 
   3.6445983408554983`*^9}, 3.656974193760705*^9, {3.656974233478744*^9, 
   3.6569743216982307`*^9}, {3.725896617006521*^9, 
   3.725896640966722*^9}},ExpressionUUID->"a50297c0-b2c5-4e4c-ba99-\
e4fdc273bdac"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "BaseDir", ",", "load", ",", "mf", ",", "mass", ",", "xval", ",", "flux", 
   ",", "loadspec", ",", "dNdx0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BaseDir", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"load", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "BaseDir", "<>", "\"\<Spectra/AtProduction_neutrinos_mu.dat\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mf", "=", "4.18"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mass", "=", 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "1"}], "]"}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"in", " ", "GeV"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xval", "=", 
    RowBox[{"10", "^", 
     RowBox[{"(", 
      RowBox[{"load", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"2", ";;", 
          RowBox[{
           RowBox[{"Dimensions", "[", "load", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", "2"}], "]"}], "]"}], 
      ")"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"x", " ", "=", " ", 
    RowBox[{"E", "/", "M"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flux", "=", 
   RowBox[{
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"Log", "[", "10", "]"}], "xval"}]], ")"}], 
    RowBox[{"load", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"2", ";;", 
        RowBox[{
         RowBox[{"Dimensions", "[", "load", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ",", "14"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"loadspec", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"mass", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"xval", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"flux", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "load", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]}], "}"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dNdx0", "[", "x_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"loadspec", "[", 
         RowBox[{
          FractionBox["mf", "\[Epsilon]"], ",", "x"}], "]"}], ",", 
        RowBox[{"x", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["x", "2"], 
     RowBox[{"dNdx0", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "6"}]], ",", "1.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.12"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<x\>\"", ",", "\"\<\!\(\*SuperscriptBox[\(x\), \(2\)]\)dN/dx \>\""}],
      "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Darker", "[", "Gray", "]"}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", "\"\<n=0\>\"", "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.639076588298305*^9, 3.639076666827195*^9}, {
   3.6445840003231363`*^9, 3.6445840120261393`*^9}, {3.6445851269240093`*^9, 
   3.64458514902188*^9}, 3.644586384478674*^9, 3.656974862833619*^9, 
   3.656974915776977*^9, {3.6569800476470346`*^9, 3.656980047766233*^9}, {
   3.725896555189452*^9, 
   3.725896593663879*^9}},ExpressionUUID->"7cde9690-44b1-4324-b3d1-\
cf26241c3bbe"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
          0.33333333333333337`, 0.33333333333333337`, 0.33333333333333337`]], 
         
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQXRrLOaFrofYBBijw0X4fFT0fwVf6eUVVZy6Cf27K
gt1nZyD4amfMnwtMQPBvWKXZTa9D8K0kDr9ZHI3g/79U47lXFME//KB8jm6d
FpyvodDa9b0awe+Jn1RxsBLBD7m3JiS0FMF/cvshT20Ogs923bv2TBSC73FW
Pi7bHMFfw6PrY2qK4Av4WFn9N0Lwb5wKEZush+Bnnug8t0sVwe86/NmOSwTB
f8fEqHtFEMEPcuKTnseP4Esd1PhuyI3g1zGYPf3NgeA/sne+fJQNwQcA/jZd
cA==
          "]], 
         LineBox[CompressedData["
1:eJwtV3k4Vd/71WAeUjLPF3cgQmQ8Z0sahEiKRCIUSUiGBmOGzPNMSciQzNzC
fVOZUoQkFDKTyEdI0vf+nud3/7nPes7Z77v2Wus952xJu+umDtsZGBjqdzAw
/N9/uMRAh2EHBRj+/6fxVrYhr50CJftbnDU9v2kPrw6+9mmlgMn6Z+kjzHsw
P0LkO6M3FFB+++X9OS9JTOKkVj/hFQV+awuP2/jLYq9857+uAQX8VtmS0C5l
jOWDwVJuA71evPPRxzHaWPHmn3Wv5xTw2TiaPil2CDMil24zrKcAnxMbs4mw
Hpbgz8GzWkWBM/4UHcfAE5iIwjvVEyUUwFJZjh+4bYY1nbuLixdR4PZbQV1X
z7OYbYj8sZUCCgyH+6b+u2uBFQxHW+Q8ooDYwmqKK1hhipEnby+nUyCmlunA
ng07TG+mCzLCKUBQNbcTrnbBpngC2q+HUsCt1S1x8Ms17D5S7NG7R4FEpk8x
+azXsfcpceM//CnwQn3O/lCVG2Zx5BTTYW8KiH54a3qK/wbm8qjHYN6BAus3
KpbuDnljbt9nTsRfosBF55DB5js+2I2D//TVbOl6KFTaq4r4Yrc65I4HW1Gg
1tjT0dXsFnZ3r+4xiiUFDh2IY4z/fgsLuGBxtMucAuJG243TA29j9564Hrl5
ho6/P7SU47mDhS3f0xM+TQHumkWN9Jg7WIR25uGXJvR+5wl6bPN3sJjQCt3L
Jylg03UfY9C9i8V3tx7iNKRAj5WR7t3Eu1iS0FedKn0KOOiqrIWM3MXS7FfQ
uWMU6J/f81SS6IdllrGhf3oUaK6ICbG87IflrEvg+boUyOc8nI7l+WGPdNUw
Ax0KaN47LT702Q8riDLS/olR4NnAzZSj7P5YUf8lrVQtCnS6ByymqPljpRK3
NDENun7K96lTF/yxcuc4jfGDFFC/lGtsFuiPVVcXqN9XocClB1os2x/4Y3Vb
DWr7lSngTtR35Kv3x54f7z34cT8FYnVFDBs6/bGmhFnV2/IUEJgRVZT64o91
PtdV5pGmwNsb+84Ur/tjn79lKpQI0fWa8ogwm/DHhvdVyp8SoACe0Os/PueP
jXq17VvjpQA/Z0jEAZYAbBy+ymXzUOC57aEBduEAbIrtl+zh3RT48MxockM+
AJszY5ed5aLn9/X2BYZDAdhCjiQlloNCX/WKImYWgK0onyQNMVOALd+M+OBW
AMYdzCDB/osMfdZHjK8JBGJ73/GJVyyToWOKUzt1XyDGzy8vZr5EBgVJ77RB
nUBMrOScSN48GdLnagXLnAIxyV/XhfVnyWBwyNwD9wvEpFGo0OIUGZiti3Nn
EgIxud5KAa1vZEDBI00RDYGYgmg7/9gIGUKZTZuCPgRiypdH+MK+kGH2B6MD
cSIQU634xSs/RAZLm9GygKVATP0PO2/vABl8GZiHWjcDMe0jhL2+/WQocBLJ
280ahKFYdR7xPjKYRA7tu8kbhB2Vcth9tYsM0z8dEhcUgjAv0MY03pGh232b
9ymtIKzQeq8T81syTDrM8pOPB2Esaa8gr4UMpawrzxMvBWHqqpnf3V+TQdck
/KiNRxDm1OMhoNNMhsSdNxvYgoKwDg6C23AjGS58P/He73EQtlH0O7P4BRmi
JH4LRdQFYXLHPrT6UMlgb8/+YeNtEGY18eS/o3VkqJe1ur86FoRFBQaI89aQ
oYFysvTx7yCsQczCYLySDJ9L5YIUeIKxhRf7vSvKycD5YYceTSEYO7n69b1R
KRlEZz2jSl2CMb/E2g3hYjp/x/8+OcUGY88UY4hzhWQ4V5jZtFgdjI2+czCt
zyfDJnhre34JxrivYn6heWSIbX1Ytp/1HqbDwltslksG530NSwmW9zD3/O8f
CQ/IEIe1hsXV3MN6RjLlaRlkqEy0IG75hGDb7944F51GxzJe9ofGQrADQgYh
51PIsFyWvUUzCsWSzDaG1+LJEOl5Mn9NOQw7224RpXifDJQxf+GLsvexUEfF
+q1QMhzw4FR7WH4fq9vBMtF5jwxXZMOmBjQiMAG8TsspgAw8qzedTppFYoOV
vPO53mTYqVnBz/coGmMzWeBzu0mGMYcv8wwaMZjWwmtd/AYZCFp6TAXdMVgW
yTNj0JUMZcT2I6cY4rDO1wYtT1zIcHYFfeYzjMP+2kotezmT4ViDH++11DhM
4d+G6JErZDBm/pH3dCwOu5DVo8/jSIY18yu1g4zxWIxG8c2xS2Tof7FhwEWO
x2j9gbnPbOn+WBV4nT4ejy3dOPfurg0ZZjS4K2od4zGJ3Uq/DazJEC/75ceR
4HjMpIxFRug8GVgNM59y58RjgQajJjMWZGhf1WYi18Vj30Jin9wzI4Pg+PSF
+xPx2B6py32mpmTovH0Fba3HY4cBZ5A0IcNPzZ+5vBwJmKc1375FIzKkKle+
mhVNwB5vLJg3GpAhI53pvxSFBKwv9U1wpD4Z1m9eztfCE7CdqtnPzh2j+7Gx
N2bdMAFzuG7IvKpLhg8PzsfrX0nAVmUjKMk6ZNAkvhDS8krAwqdaDVRwMkj2
n1/qD07Aiq0Px3lokIGvoo5zIycB0xYMrNytRoYTZ9lytj1NwN71NfWVq5Ah
+IuBXfWLBOxC3OaqsTIZnIZmjli/TcCWDDQFF/eTQfYb1yeD4QQsiNlHK0ae
DO9G9L37fiRgPK9qrOXlyJCHuaOqnYnYY7///DvJZLAIrc/mEk3EDmoqPbpK
JEPWj5I4GfVErO2X62s2aTLc0vz1xvpsInauonSqSJIM3hu/Qgk+idicyxyL
vjgZfnmQfk5kJ2J3yGS5GRF63u3MFUXaEjGuCQejMCEyXBvren5kLRF78CDv
OlGADMTfPrGTckmY4vmx+De8ZGj8u90r1DEJa+YTr7bnIUOEMOXQ88Ik7HSP
Vf+O3WT49keYR2gpCZuIzlh/xEWGjx+kHx/VSca89AeEdDnIUJ4aHzmTlowx
M/JhY6x0/s//RJRvJGNpcNomgJkMVXMbQ+aOKZjsnfhAcUYyaBw/G/BwOAV7
odaV17Sdrl9eS9KZC6mY4X8cLdYMZHjJbF1g8D0V+1p2YmbzLwnGLXLZbMPS
sOvO4WxZf0hAPHlX008xHWMgtuzT+k2CXYUsiikz6VjC2A7jwVUS3OU0bC0o
z8Cksw+5+66QQKiYm0C9n4nVWPgnCiyTQDnjw8bHkCzs6N7GmrpFEvyKbB74
wpqDDXRtfDq7QIKkPi/yvvwHmFOk+savORIEr2ilfSx5iG0c9RJJnqHf/z3v
T3ZcLiba9PNi7zgJPvyn8MnjTh5W5rs/2GOMBCscK3+OBj/GdFSv5e8eIdHf
f/4flJPzMbvSmVnjQRKwqnZk5X4uxJ5kjHh0dpOgVIYjM+drKaZ5VjT56nsS
3Fl4pSikXoa93X2+jq2TBJHBneoZGc+wH+H9f463ksD2lcfHe9oV2AHvd/fe
NJIgwcBBWfpYNdZ0+kVKUzEJ9jVOtvBXUbGYP5m9V56QAIZsU7qNn2MX8u5w
8xSQYKTd+qvMwnPs7zIWcTmXBA48TlcYZRsw7QS4y51GgjSfn1PZz5owDs3c
58+TScARu/VMxYyGDY8FrtknkiDd0lbBcoOG3VY67E6NIUGYsIDcRj5gz7vf
2NuFkGD5cnVc7c5mLMKnIJcjmK5/w9GqeptmzFIi7GttAAnMNLK/H29oxmTb
Lgvb+pGARTB6LlToFfb7+nEL9jskGPJ+pP7A7xXWxk9JrvElwUY4i4rGr1dY
Go21x8abBFtupVXmrq8x9V1vDao9SBCuf5T11+U3GEtdSfgFNxL8Fzv559zM
G2zgQtQbFlcS7OlIi951tQXzLjNC1k4kYO5uYqZ4t2K1Rt3KTBdJwKiyu/9b
YTsW+qv8erk1CWgNSf/y1Duws9nxpZbnSVAkFzq2/W0H9uu7KfHZWRI4Crrd
FVl5i6lEfRS0MKLvfzaI5ePp99hOldqz2w1I0NfvlVy48B7rG0pJLD1OgtGD
/3xGw7qwx8He3WePkuDGengycXc3dkPOgnObHgl6n1oLW13oxnR71U+UHCLB
8S9JMZ4l3die24JhZxAJ+u1b3q9Od2OVHYMMxZr0+9MVNXSsP2BBHi8wM3X6
fh9cfTuY8gEzFcq6taVKAn/bpxPdXR+wn07WK6ZKJJAoPb64iXowRdbR6T8k
Emz7XvC2R6gXe3ps8r0RLwkKT96JG+zow4p1w9QleEhQ1l717eZWH1aAUR4t
c9PzdThvpVj5I/bwwLWbqRwkGJ5Uwc9lf8SyFXaNOLGRQNbalbCn7yOWQak4
rs1Cv+5+SmeCvR9LlT5dycVEgr1sKS0j+v1Ykvgv4bEdJOA6X8z0KrUfixdK
DanaRgLx2b7wxOl+LIZXYzHkHxGmO706TDU+YWHsd5tl/xChV/y/h7nfPmG3
1nY6eS4Toar2NSXU8DPmvVzQc3SJCPe7FQr7Sj5jngvHtQV/EKHmdmsDF+cg
5joetatplghxxYfqND8OYrZde2uZx4iQocPZvOPOMHa8UHpHZhcR7Kqbovu4
RrEjj1pcrr0jgpeWSnmw4Simm32lH70lAtOJ2w9P3B/FtBJLiyZaiKBue8J3
ZXUUU/BXMVFoIsK3s2UCnQNjmNytfipDAxHuJOxl/LznG0a+6SPVSyVC554l
hwdG3zDC1YZV7xoibIwM50a8+YbxmutlvywlwnjeYM4FGMf2mE4xJRUTIfXv
3ZrabRMYl1G4m+MTIpjbJ5viehMYy+HOw+yPiSB2qSNM5t0Exoi7Pv2SS4Q0
J+O1Ep5JbLsGN3/5A7oe/KUlz85PYpsKZnNmmUS4p/Q7P3RpEvtNWT1NSicC
VUNPNxybwlal0xp/pxBBtrNg7FLUFLYoNByXk0Dn61fosFtxGvvO67fhFkeE
sZgYBe/QaWyGW8L+cAwRVrzJPXYz09g3Jnu1mft0PFUdIlY9g+lIuKRGhhGB
47ErgZs0i+VoeK4phND5DURqqGfPYudc7tXdDCACd3aE4vnEOaz7w2O1Hd5E
YPVP6Nj/5DumMF+aWuBJBEioviJ4cAGL2lmzpu9BhAe2A8xJrQvYMbU3dXHX
iPA9nS/d4dcPrClrUk3Mngg97x/dftO0hInULqS+tCXCS1JRdNjen9itrl9r
9jZEUKxYPqXm8hNT3c5UX2JJBJy3dcZVchkrvUxU1zhFhN/ng97+yPkPS1e+
rG6G0/OCGY3H/VzFVg2up61pEaFSK4v3gcMaZubgvZ6hQYS3SzWjy0NrGHda
WP2YChFcy5Pao7vWsdC/herX5YhQoKkwe693A5vgK0/bQ6Hr+VUmosryD6ar
WL9eQyTCOr9xx7WJP9hfu7b6TUkipN8YfPbk3ybm2TajHiFABMar1mx7z/zD
esaW0uT5iCBqpq/nsvQPU/yzvt7NQ8+L/sMS/WMM+Lw8K5V/FxHCBKwGmmYZ
cLtEikY+IxGG1B4ciNbZjptccNaAZRkQu8kkZKvFiA91HGiJXJKBrI8K0smZ
jLij2l9T8x8ykOF9fveFv4z4be44lx+zMnBxcVtFyxsmvKC55oHImAy0HE76
+8CZBVfa779v5qsMvN4mIL/0iQVvyDxOrRqWgdbv1xdpR1nxHs+hnhMDMsCr
E+rWTmHD/xK3Mfl2ycBEo7bmJSYOPDyxI0HvnQxojrUfvRrEge9hSBLnfkvv
VyR0yoeBEyd/JmoUtsjAB/kzf15v58LNIg1dPjbKwIrty9Zkbm68eDG1R6lU
Bqa6qgcWHffgqla2Nn+LZOBouhyTXd0eHNpkv7cVykCXEssrMisP/jG3kfFi
ngwQrxfj1uU8OIPZuHpMhgzUN12dlObixSOh9M25NBng3j7BdsKJF+eT9zKV
SZGBT/IOnRtvePF9TKwuDfEy4K8neJlwjw83r1d4MBdO50PejIjZK4B/k16X
qw2VAVLexVieuwK4S/zL+sB7MuD497qB+7QAHuRs1iMQIAPW+iWF314K4mUi
txiPectAE20OG40RxncGvrma5yADzBkd7e/TxfF3n5V4bl2i81OI/PhujwSe
opzz3MRWBhLW77IwWErg5Akv1i0rGeCsW1Q7/10CNzpGLrQwk4FOeUzDW5KA
8z1MOrnfVAau83X9OuJBwEfXGVYZTWRAyMjoTPhrAu5R/FmvykAGzqhM+t25
JoWncEZ+4zwsAyMnda5UfZDGbRzX7k/o0PVVffHfMwUZnEy7pPQCp+clOaJB
P1oGf+GmHXBFUwbK22zknI2J+GjvgugrJRnoJezk+W+ahFMyTM75SNDz5HDu
jIOzHL683MBgLCYDP/EpdZ5xObzBgPJERkQGDHj3LVGt9+En/25b6+GXAe0P
qjjXOXnc42JVkvwuGag74zifdWU/rkUV197JSc+PaEnw0M/9+M49UeODbDKw
TaywqQBXxFNf2SuHM9H9p33mvvlOEW8g8nV/+ysNd2797l9cV8JD/IO8qX+k
gXiedV/7UWX85MAPsbjf0iCscTtpKFkZH73feg37JQ3eCcwzL9QO4IwLPuxp
36Xholn7h8dhKvjJqqGjRkPSMMrtknrmihruI1s2sTIgDaZVk41JvWr4o9yA
oKx+Ola7ulKho46vxso0zX+QhifcRW7PJDTwHJfrqhFt0lB/Y5xpYl0Tbxs/
1KvUQudze8MYeWrhy5Z73T+/koac36cbPvzUwo/qU0vJNGkoyOI2ef+fNr4o
s0O6tUYazF4beDvyIlwo++NL1yppeHzjR9LdxwjX2/vEhq9CGkKfX3EXFdbB
07YbZTqUSgOvGwgtlevgOiMpe3bmSYPDOFts/cIhPC5NdtuhOGkgv7RJHajU
w5/v+pszEy0NAYJCh7V5juAToV3acZHScD83RM/n5hFc/aanz0ioNNTKcb3N
RUfx0VNNi3fvSgPbpT7Jv/PHcLb2uGiZ29KgdnAgOMfqOK6ic0nunY807DqQ
dsG96zgersByWcRTGraOPWL5/EIfV2I3/frcma5HaoH5ZrkBbhUkfcfuijQw
ukTxe6oY4qG/VwXZHKVBXnZPs99zQ3xwOvPMOVtpOOxqdzvovREe9Hqyc81c
GuYUvB0m2U3wnru+L1SOSMORDtUrBjmmOOU4Z+jOw3T/uYo8uZdN8YA9uSZ9
OtJw72ajZt+x07hCYdvkDW1pYHF7EE9YP41HdvNzVx2QhhM6ZxqSXc7g3zJK
BoOU6H4ekb6/+e4MrumA8k33S4NthmYyWeksPvPbUXNZVhr0/XD5hc2zuJ5U
rb0SQRoEF2TtVost8MwF/f3bJKQhbsetNDPhc/hy3Zff3aLS8BuPe1UVfQ5/
aMgY6yYoDXvx7a5JPpb435tm1Gfc0qAD+sxw2QqvbVvmVPgnBT3zkYHs5y7i
nImhA383pSA+vzJ4T95F3N5aKO/dhhScbE49eOHHRXzP8iH1a6tScFU+VvdT
uC1+XTjernRBCrhTmUSH39nhLZPS8nfmpaC4sfFqEuESLlZev2YwKwVMd12Z
nvtcwjv1RqPmJ6RA5lTOXTuKPU523V8nOywFf2oPk15mOeD+6q8CNz5Lgc93
dpk7fx3w/u3mhh2fpECOLT+n28YRD0n1G3PqlYK4be5y1pTL+Dd4x17UIQXq
9bfOTHVdwTN5XC6SqFJw9knJMPW6C2626SDZVisFpaQM4tyqC84xafPtSrUU
zGclXfMLuIbfqT1tX/xMCry1g2f/ZbjiVue0rsgXSMG1pqH1s95u+F5dVcr7
PCkwrmveRnjjhnfK7p9zzZWCStlr/07udce1Nwku5VlSMCvERpytdcdFHrC5
HUiUgtX4o5VfOG/gfWE7lfripCBH11rd/fINPMpt66dnjBREpzzpzWy+gW8e
Wr5Re18K7hrt//Llric+PPHZWyNAChim5DLWWbzwLNkif3RNChL13s2r+fri
Zjx5OqPOUuB+6fmo05IvzrGZtS3wihR0UrqUW51u4XfexQU3X5KCRvIeu/2X
buNWbj5hRyylwG1YSfc/97v43nMex6fMpUCy3X3hxZ+7eOchF9awM1Lwvvlw
l3W4H67NczGyzUQKtH73qaQW+eOitcdiDY5JQcJFfu9zTIF4f84hk+96dD/K
l8/rnw3EY8K0dkfrSsFSya7lisJAfMtif+J7TAqY5R91shgH4V//8KWeUpGC
IPttt5LLg/GcQ1M55pL0fH2M3DH8JhRP4gu+tUNcCpo88kgjCmF45Lz42Wci
UlCByKkt6WG4T/I5TmYBKQg3ffC8+2Y4fmq283YtlxRgtkrfKUcj8ONNTuZ2
HFLAw36ny58WgeOJTAe42KTAXFWUcZtWJC6L6cw5MEqBageTcrF6FL4zvsqC
d5MAB7WVnR8ax+AbDiYqL38TwHyztM9iKAb/qbmw69oaAdxbXyXed4rFv04Q
W18vE8ArIjau6WgcXq+eoeo5SwDL9pkxp1vx+NXRgD29/QRQuuvv4ieVhNvV
iP7w6yNABX/SAOafhFtEPG+X7SGAynRHacpwEq6nshIQ9I4AMVwllANZybhY
+OVFpdf09W96S1f3p+J7rXe+/fKSANpmZaE26ak4u3JuwX0aAfbtrNTL25mG
rw8NWo89J8CB/em3RkbT8J79JzvjKgjAsPHyi1JFBt62c75Q+xkBbEO2FXvL
ZuK0z2HBM6UE6O+2jZnMz8RLg19q6jwhQATznIJ9XhYe8kmlaDGHAGRGpkfM
jTm4ur9w6MkoAmCHd7yi1OTiVoW+MYQIAsh+HEqOZniE+3d9SlkNI0ClevE/
OaNHeIt4UmFOMAH63JINZece4WbA0f7jFgEUUuc5Sw48xn1mnD80+xDAbedM
jO39x3gmd/vnFC8C4If/SXqPPsa/XQyZwz0I4Hf6WkBPQj7utm2LPdaJAExv
qq5asRTiSRSrvZcuEwDIdqsCToV43annImoOBCCouv937m0hvpXrJT9ykQC3
XTIzA5Oe4FG6iyf3WxBgdaH6Lr9mMf4keDS+6ygBYid+DCoPPMU7S/CMPD26
P9OypUfNyvDF3qxH3roEyD7CZWvYU4YflD5XJY4TYFm7ptOw7xn++vWHvuuq
BHh7QZ0naL0cn/m+/8vhAwQoi188/xqvwNl5Yyb5lQggsVCXKRFagZs6nFil
7SOA/uDDRReBSnyU8RU/tzQ9b4TqRm6DKnyngqTEhCQBXvcV7aBlVOGks/7k
enECeOyd6iuZr8JdC7Q0LgoTQLxvnNksvhrfPFptWb6HAI6MkT2O32tw/vD8
bJNtBGCuKBTZNVWPZ713yvq1JQlHLpBDq8youASvQmbGpiTEWVn7Kb2h4uRH
tWkTa5Jg25Gz8ankOa7Z0Jro80MSss3f8NTHNeBN26MSRL9LwgOJ5+KMuxrx
w/om8c2zktD55pKKc2wjbtg/EMMxKQks5/9GZ6c04dZLs/cfDklCrXCbw1sb
wL8dLAs/8lkSkMdwQlsh4I53PcLm+iWBM/6M0coS4K5sf+6p9EiC4y7W17Oh
L/EAaY6AtjZJ6GIP8up+2YznWSh4LdVIwuqhqss53m9w8oNlz+QqSXjS01JT
0vcGL52svaFZIQlRH+yn1Q604NUeyP1eqSTwhDyJnVhpwVuiTFwE8iQh3VP2
r3pkG36id+/VxoeSsP+p1fDUShveJfjZyS5HEmwuXBM4crEdHyiwvVyaLgl7
Z+qE5LU78FnwsNOJk4QbD783O7F24q7MaraT0ZIQsEK6aBHYiS8b/bGJiKTj
gYlmhT+d+MZgsHVfqCSE2Ne7l6+8wzl+JVlcuSsJZ7ZMd0//68L3U+pOxjlL
wk9GOUUh1IOPNmvfsr4iCamvOIQYwnrwBKvmfFlHSWhNrPm53NWDr8S+23xt
KwkLp0eFuRx68eer48W/LSRBbjn2aXBWH370NTfzpWOSoGsadnT48Cd83TpF
WfGIJIxY2+Tb5nzCi9aEL/zVlYSZWHkV8Y1POIccqSYVp++/ia03qmYA74nH
LnWq0vs9aFto0x7EL9g401SlJeFjoWOgcPwXnPv34tx2giRo6p4YTt3+FX+Z
cJOvW1wSfI1H/CtufsWlWwKuOQtLQsoETb/34gg+ty9V+MEeSdDgOjBAzR/F
vTZeebNskwRZT/eozhffcHKSft7HLQm4/kfUZXT7OP5Zvuv9o00JEO7e92Ll
xDiubTsog61LwJ51q+v7vo7j29uWet0XJWCXbPwurd2TeHSyqOLQFwkY+Sp2
e/fTafyhEaup75AE6LCq3TrPOYNXMv66wf9Zgu6/Wpvg9Rm8/2Zn3ek+CZiY
mXjEojaLS5y9jTo7JOCaijSX5ec5XJnrsq1zmwRE3PHUmj0yj+u1mAaztEhA
62FjbcHqedzpoGyr3ksJUPzsPumR/B2v5Pt8srFOAmBr50ilyw/89fvXbudr
JKA9+7bmj6kf+KfQ8oTflRJw57FV5IbdIr65GtavWiYBGw2u9caKS/iRTwcv
lD2WgK0S9O+yxk98IDXp2oN4CXj2flvv6Tv/4XPGAbFYrAR86Lk8G9j+H/6X
2aViKEoCSo/kn+viX8EJPod/8YdLwJB0dtqnuhX8qsXynTg/CTj8uUicnWkV
3xIwiQq8KgEJQn4uMV/Xce4PWmXiThJwOpCfMQn9xqXuk7obHSXg3bEA8p/c
3/jx31s8G7YSUCbLKcZwdQOP//w008NCAup2tKqd59rEpTPYSy4dkYC+xc+t
T7P/4TfxjGmOwxLgYdjpeYaNAbV8I0vX6kiAvKn/7OOjDOiy3NFsFm0J2P1n
u/3LlwyouCEg9qmyBDy8xPweb96GFEd+3VgTlwAHb6OXgz92oMDge+UPRSWg
+wXjbLv6TtRD4lnQF5YABdb1mN7gneiGm6JjFp8EPK3FXq6JMKLabVctDnFK
AMPL0LGB80zI6zj48v0Sh5yRJbVaLlYkEP9l+cqSOPw5k612wpkVUT9vXH0x
Lw5zetEzu1tZ0aaz6oWL38ShKSrokv49NhQUXaxb3CUOB03knKs5OVB0TxI7
XiwOVi2XkIT1LqQgXHkvLl8cancsCIi/24W6L3X9/fZQHM7deYIfEedGe36x
LoWlioN54cWU4QRulMbv3/fhnjh8h8xvm0G70WMrp2wHG3G4pqmzU/E+D3po
wOrGcl4cbG+sKwu086BMzSLdkrPiUHKi9HAz616UIDA7vWQkDrvr7X1vR+9F
gX1XlO9oi4NqJ5mxN4cXXTC80pogKA6HCA3ucbP8yFKLJUOVVxz4tp//+fGg
ADoj+8RlgFsc+l7YtGwPEUCGLDO7xVjE4arRGpuItCDSen3ZqmhVDALOSaD4
a0JIQPvyT1qvGBButI/k7BdFe+WYX9t1iUHtUYsXN6JE0S6hwhTGt2LA0mlp
ZjEnipjWp7QMmsVgqFt1t1WRGPpV5RjaXy4GuQ86VI2FJFCPnKPwQrQY7PlW
anLmpSR6L8T0I/a+GARmGAT8WJdE7awFoBwiBpXl6kBSIiCYnnTwuSMGh9+t
/Q7II6CyPIfyHVfFwGQ0e3IzVgpFCjscETouBqfWimYS7sug48c+7LQ5LAYR
wonZqR9kENMN7HUeLgb+9ruDfYWIKKCD97C8qhiwGuVGfy0jIi/fFh0dghiM
yGa98PhGQnafSNqOm6Jw65Izvs1bFknsSPpTvCYKearXvVney6IvCgwvFpdF
oa6gMZCPKIcsQgc0fGdFwUVZztP6sxwyUr2vFtUvCsnRRuc7DeWReuKccmW5
KPz1bNZoUFFEq01nl1dLRCExbK2M4qSIquaaK7QKRYE08t8+5RxFpKCbqfgm
WxSqgptChdiUkNRPA4WBCFH4mbL/4M1ZJcRl/JSyZS8K704dFOprPYA6bwnO
6l4UhY4vB3/VM6mg+wUhT8LOi4Lauo3K6aMqaOeWNWm3qSiUz44/K2tVQRul
XDLSSBQW5E+9V+pVRZNsbhInBEVhduz6wZ9c6mhz+ILGyF5RKCItnto0U0d7
nxmZenKLghQ1nLUpUx3pnZa7l8NM7/+mAb8qp4EeZU5NL/8SgdcFt9yx05ro
wj7rZ5k9IiDRnnHOqFUbeW0ZtCm+FwFZs6IKO0EMRXdrjr1pFwGb8NlBfRcM
NXgK8CyBCNQ1ZaYm78WRcGOvl94zEbBt7Bw+fx2hAaMT+EKkCIwsFtxtJx1C
S+Ia5kFhIvCGx91hw/wQYl4mufEHiwDxD6NqQfghdDCF8dGhWyLALfs23WP+
EEr6CowpV0RgsGpJ7E+tLjp1Xe0dfkQEfON2L1c56qGOOGmruC1heBm8cIVV
8Ti6oHWuWGtDGB4/V48ycjuOliej16d+CYP53LAkpeI4EtZaS8IWhGHbX32T
EhV95DLZ/m5uSBjeCT/5sql7AnFpXkdHqMLArF9ePnHXED2ayIteqhaGf8GP
nBTbDNHB2IGhzHJhaHHm1yTxGCGbiUM+y4XCwK2Wcl64xAiVx+yteJAiDEFZ
7WT98ZPo9DiVsHFDGA699NVYeG6CZqJ/uOVfF4b2qMPbmiZN0B11KZrJVWEg
Lk2aLHKfQo+jo84X2gmDHVfhDa8rp9Cqmk2S2SlhyK9qTpETMUVpUTuZnikI
w9F5tidfUk6jYVXj2UuzQjDIMx1UP3IWKYuaSFdMCMFS1eCZPyLmKHznKZut
ESGgGaeKvrc0Ryq9ph/T+oXAjXl9njRgjqLczr5890oIiBODT95+tkBYiXW6
Wo4QWMo7c+ttWKKkhAt999KFoJEn01v60Hk052uzqydJCHiZqj4UhJ9HKcdt
Q1wihYDpzF2TZEEr9GPS3j3XRwiWJQK/qxy2RjkSLvrsp4WgDlXpmdfaoBXm
a/csTgpBfvuXqskdF9GJxWu0fH0h0OCZurq+7yJabbyuqqMjBGu3t+dTAi4i
4/M3JG/KCwG740s2F1lbxJBy6/dXZiEw44qNOBdnh2zZ7xdVNggCmZTnP1Ho
gPakc+Am9YIgpPVcI/izA2omxvUsVAmCslpZagi7IyLopv4hlwiCgnvRaJ2b
Ixr3yTd6kC4IDvtUr06iy8hh6uXPSC9BuHL7nz3D8hXE53kklOIhCAWXo2bk
ZJ1Qy7Z2odZrgiD9T+dqi50TIop2H97uIAindM8lGHx0QtOnvyb7nBYE9j8R
Os9ozsjp5YaGg6IgnH38KWRPiQsSMvZ7v32fIIyX7b+YO+eCOoa3XXpIEoR/
1GmtUtlrSHadJWpITBDexc5LapReQ/MK/F9PcQrC8Kk49aM1ruha1oEgfE4A
FNYqrqxcd0Pu3i4d/I8FIKxEw0++ywNNHGowMH8gALLT02/WNzzQWQ6OdykZ
AiDYN5suSrqBNHNLunjjBUC34vgZr4AbaPvbuT4ePwHIX2Hyv6nmiRLEnEZ2
WQhAk1FFmlndTbRztv6i8WkB0Cq7/4Zj9ibyqmL5FnNSABgLHNgpwl7I8viT
Cc4jAuCAJ0TEBXghgsf0LLuyALCaj5xVMPFGlW8cVpg5BOCpjcPY4R2+SDqu
5uYxZgEwu+d4J17LF6VYMq6FbheA0s/7W096+qJbi49/M/7mB4rll1LhaV+k
KzixtWOKH9xuX0p16LmFel3sWBmAH6ptmEdCaXfQCo+N2PoNfgiauEk8cDsA
jdeu9Bld5wfqslb5mZwA1HMuIjLPmR/cjV7vqnsZgJ49qFk/acsPe/HEdDXW
QOQsx9Gbf5IfSAtKrBqZgWhUlxp2msIPiefdiBFvg1CnO8/Psq98sPyzNKTg
Ygh6sbeocOcgH9ic2Oi6EhWCiuvwC5Yf+cCkaDHzZn0ICvvr9Jaxkw/4ZzIn
r+8ORbr3Id+KygeOrtE3F1tCUf3Da5ZsSXzw8bYg0UonHOV3tb5y0OeDg4K7
jgldj0Q/BEZ72Y/Q6wnckJfMjUQH7dbHK3T44HUR5w+33kjUtkLeuaXGB6kX
ZBfn1aPQd8EIvRQiH1ySwvPOMkcjFXvDNy07+MArOd/VvjIGNa93t5CaeCH7
ZLCKqmQ8Yted7X9H5YVXzYOeO1A8MovcNn2jhhdmHl7O+G0Vj6ZElZmhlBe6
yjq2rNPjEdvhxGMWmbxQ23+cXXBvAjoVfaYt3IcX1AbW9hnuTkSjkoPts8q8
IFajL/ZQNhnNFza1KCnwAvl0tnisSTJalc975UvhBQ3v9xYvvJIRu6ZLI6sE
L/juipd88ioZHTTdKqdw8sLjHV1DXTYpKCqIkOY0vRd2l+iUquamIrVxZ8fZ
zL3QG+tvU3MkA8U8/rN9dude2LN7x9sdLA/Rf9125wIZ9kJiJZfnDvGHyOJv
+zPBTR4w/ae7j+/gQ0Q4m2Z14j8e8Jtii/a0f4hqmFVrS8Z4IFdTzZmn+SEa
dnZ1cm3iAdl9588OB+QiWaWxrv+8eeDkRGv2Xo481NrYkrU1twcsRU0fr5wu
QPKrzOG5/btB5uyJQ8snnyJmG4sCWjE3ID3/+8tBlWjnMTOfiwXcYFjdcEY+
vhJt329yYtsjbmBJF2dxeFCJtraO/dBN54YX3/0DOl5UopUctYMtYdyQO32B
nbRSiUa/8rV02nODpczf012XqhD1wsfJz2LccNDiqfwxVI1qj36ouyXEDW0c
W0HlhtWoWuHdfWE+bjD596+c07IaPdt6LW/NyQ0JKuQf5Z7VyABzmoe1XWCS
yh+SWVSNpBtJ7O8rdoHOhNaPHXtq0KeGxydmZHZBt81eg6rhGnSWSbXtmsgu
OMBo4sk7V4P6jN8c+W/PLrCU+HfLZa0G9Xyb1Nn6xwU+P5gvrO+uRZ0sJLW9
g1xgb/LnbcDRWtRsViSlE8MFTYJL5YxPa9GhHI3cN/e4IPDa32ex1Fr692C7
mMFtLlgWfjLM3FKLGm/NCZ69wgUsYrcSaF9r6fMhx+2iywV6LX55Hpx1qOz7
083UVU6YOcRmyOJYh+QP4rdEFzjB8HiLXaVbHSr1f7/2aJwTeEdYWo/crkNF
exaXn3ZzQtA4VY4SV4ceqyvOvirmhI37py5N19ehjHuVHxcvcILztuBYS6Z6
FCpSV3aslQO+3AvYEk6oR9RKw5FrTRywQuC9V5Jej74f/7YrqYYDqnpfTVNy
65HpTU730TwOOJ1cFb38rB6Jvb90wDeAA65Rz6xodNajOn/u+mINDmB1izAI
+VeP5ngLZroVOSD2ikhCKiMViZVqCa6ROGB3qw57KjsV3RtwvHWYjwO0Ry15
L/BTkYlSo/bwMjscj7n1i0uBioJbTa9tn2OHkYSPZ6MPUFGt9Uw2eYwdjhi3
W/9WpyKRCJ5/nl3s0HTrPH/GYSqa+eb0krOUHfwdxi9vmFORsO+/nwfy2OFy
/NqZb1ZUdHJXMsEygx1e8zyQc7GlomotCC4IZ4dPHe37hJ2pKCCJ7yhyYIf3
Hk3PvG5RUZVsqZeDFTv0n1h1P+dHRVNwqDDyNJ0fj/U0KYiKDBdcWAYOsUNi
P8dU+H0qEjz6qsNNjB0cfx3ZZptKvz5s8SeFl87v+S/dwgx6fY8fco0c7BDS
yJM3mE2vlyMYzfqHDWy7ylZZHtPXqz5r3L/MBjFiX5d2FNLXv9X7cWaWDWSx
Qt7vRVRUuXbd+NEnNqi6wBgY/IyKJqMZA9reswHribY7ypVUJCCdWf7jDX29
w26O99VUZPBccWxvIxvsLLgwd6aOivxMWnZrVbNBbtod5ToqFVVMnde1LWGD
zlEzVPSCiibu/PQIe8QGdqd+a91rpKITRSJ9vXFs9O+5yMpVoCKvJew6MZwN
pi04lcKaqShPzYbN158NtnbX7tnxmoq6/QLy33qxwZmb3JXOb6ho802ujpgr
Gyj1zTk0tVARmfPVkJsDG0iU/wjYaqWiM2YTXq+s2OB6xoFTcu1UVPaN+PSK
ARv4XTVTNHxLRYOU48df6LIBtuEMOp1UxOzuNM6pyQbc5prMUu+oSKU+wu+i
EhvoxH5X+Y+OL/4rEawis8GBUnGPivdUFHX0XTWjBBsY7j89Yt1FRdToH8YW
/GygeNc4aZ2Op/p2zRdzsYEYU9iDwG4q2iOiFPqXkQ1ur7kx/qZj/JKppMlf
Vog69IV24QMVXS2+0fBohRUcnx9qrKTjtJ9J5r/mWeG3DMPoCh2/Vq9dPjbO
Cvjs47/SPVS05P8pOmOQFQjyYl916Vi0dZ288IEVeg/Ma56k4xNcQq/ph0ag
5X9XwOjY64yWTQKwwo4TXqxl9HqPsqw2JupYoc42r5GFjrvG7yarPWMF/5HU
KiM6v03ZB4oRBaywYmtufJe+H7IHvB3OZoVhX9OlVPr+zahjjvuTWeFRz4+l
bLo+gQw7tgdFsYLLbraCWLqegzFH1Em3WSHrnpedWgcVMfU79vp6sEICmfTf
QhsVHRANd+10YgWS83/68XS/oko6HrtbsMLcbUvGB3S/65fn0WtjVhgrqypn
fUXPowbnEN8xVjhRbVxm+5KuX5vx7gZVVjjTOkH9TM+T8y73Ui55VmC7ml77
m5631LMJx2yl6XyFfcaYntP1mui7y8TDCrldFawzNfT53rcqcI6NFRLbG+69
qKIi/Rv81SXbWKHikT/pdgVdn22WcyZLLHBi9AehsZSK3h+/HZI3zQIeDDxX
8WIq+hObJbH6lQV0/F7WFdHnifyp8cXxfhb4r+2dnyF93szERs5mvmOBi6Xs
Cs0P6fPpwLC88JoFOG74p4nQ5/NpqWS0TgMLDO/2tbNKp+ujZf9qspgFZjIf
PoyJpyLloJAL6o9YoGgbnA2KpiKb9oLfEekswHgjbNGa/jyoN5/drxjOAtkp
MQe6AqjIydM165YDC3gWxSgUu1KRkCp5924rFoj4mhcR4kRFHb/GQgpNWcCP
MbRN356KZL3PXO9DLHDq3g7V2HNU+vlDW1dBiAX6Z1q8henPO2d/tpmx98zA
0eN94xk3vZ7OayufN8wQP19u18pKr8fg94GrgRmyKc32ndvp9YJ+PtcqYgad
A7ILD1fq0fy9gejkYGZYy+hdCf9Uj1wiCg7oqzND7+03vN0Z9UjE4OKTEQVm
iOWVnNuWWI862YVEvWSYIfTxUAApsh7ti45mytvDDFigSaXh7Xq0EOv5efM7
E1iXWLFlWtQj12Rd//JcJqhhP+K6wlmPrj/82sHPzgQZjHyWotfrUN/T7OWT
25ngfo1CxGv7OqT+wkoo9DcjyO7/03LBsg4x9A86rUwzwl9aBqPbkTqUwP6J
5cNrRtgYcrETFa5DtV5dRyP8GGFkNMVc900t2jSE5s2fO+l+nrm3uasWRfzO
fT42sAOueijX2AdWo8iqYO5H3tsg73WEU8NgOeoyz9uzobtFu5q0723+ajGq
ejQZyjr9m4bZTk+KZOUj+2f2rYzyv2hSWL2uRcBDxHDEXcxG+BetRqF9/Z7r
Q5Q5ePdmPesvGtUjU6bD6iHqYUyVujq1QrP/pjiSo/EQ6Vi1+3c/WKHdPxCm
MD7zAAmzKqhn7lmhEZwvser05aAeu7UniuvLtIh0Z8pAbhZyXd/BEDG1TBNa
+Zwy6J+FWGO4zcf7lmmN/Zto24UspEOlMKZULNM6G3RM64Sy0NNdVrZ/nJdp
DY3Z5wOTM1F4Awi2fPlJ27HFt8vqdgZCfBER518t0Xid1U20jdPQe86yWs7K
JVroDXkmdfk0ZMXY8432cImm9JhgLs2ehnxWBLWk/ZZolqdfPxBpTkUVPUXz
39WXaL8aavqekVPRUbHE9E2rRZqKoFN38o9kxMW9R0z3wALt62mL1XmHRPTg
v12kdyMzNLbxHZNFmlGoo406qfN8hlZ8+3G2+5dItJJ96XF10gzt3OVr+W4B
kejE8TrJLP0Z2rE55U+KrRFoNeuCyNWqadrDLIK5r8V9dPLo092sYVO0HsMl
l7zYUOQrbN59x3aK9uT6D/Ex9VD0eIkhdklrinbeQpKn6lsI2sgw4xhYmqQJ
3DyiKnkwBOUv/mEqtJyk/Skmp7CPBaPNtBObegoTtKEOrhwzi0BEcl15Xs8y
QZt2JPyrZwtEpodzfPeNj9OCPYaGFhoD0JOFn6s8aeO0mrkX2V3EAGSmm/7z
27ZxWoU9j+u/nX6oZH56KuDjGO2R0vcH96N8UT/E5688G6O1ZJbqGf71oZ/X
teyvRIzRUqKd8t2v+6CzOrFjxmiM9sOQR0zEwhttTz44LFY0SjM+1d9kp30T
Vd9hy/P9/ZVm9dfEZMzSHZVGhdc7Vn2l1U413JZYdEP5WUzvT1/7SsvKO11E
DHFDKQ3bf8uPfaG9NC7Xlb92Hflsbpz81jZM25fmk/BXzwW5cfjadwUN06Ra
2vxYAq4iJ5E13wbtYRqr/hTfsyZnZKn93+OU8iFaw3p9F88xJ6R9Z37jRNog
7ZJR5aupEEekEuXErW46SEusXk/2H3FA8lnTMjIcgzSR3SyDBMwBiTWMm/zz
/0xrFI00Ldppj/g6bR2/a3ym6bbPE9NdL6FdwyO3P/83QFMQswssHbZDDJtD
BVWXB2il3js29N7YonV2y4aHkgO0cg0xsXZki34KD3yIHvpEa6+Yz3Vtuoi+
afVtXjb+RAsP3ivAHmeDXt3uNBVR66eVPDWtv85nhRoiT1xh/fmRdkf667Ta
wfOoOrPt7mrxR5qt2Av5ayctUf6L10+6xT7SdgzkSeUnWKCct7pNjQN9NBlN
s9aOJnOUMgS9xQl9tNYo13s1P8+isD8NW/eY+mj5HaqWrC5nUAC71l4P6KWd
1dcm3asyQz7CVIrNrV5am+Nd5eltZshJq8ZM40cP7fiy54hLlSmyMzjgTHzS
Q/ukm1kbyWeKLM9X+PPY9dB2rKbMRAScQga3nxYvfPxAM+ysyP93xQTpRcrB
YOwHGjmpY3vZe2OknVn0sVX/A+3wl0NbeQMnkUoJab56xweao1B057NFIyT/
Ip/hUWM3zePr5cxUHiNEfCvFF+vdTcuRI/cI6BkisaFcuTtK3TThvskn0wEG
SGxV62npiS4afx6WxSV2AuX/EmH0m+2glbHqQZ2vHnIpyUplN+qgYY9zsMCn
h5GKrYhsenk7jX8WWzw8p4uaO4WNq73baCbN+sNDfofQ/aDMsUNDrbTCU7jS
834dZKIu7NmFt9K+3BV2yVPTQSN5QulzjC00yac9KvNkHBWcy5DzcXpD6+rs
3xUkgSHXXUJNjO9e00SPHHKro2gj1TfpJomKr2nGTj9ZT+lpoc1bguMSSa9o
v79UzjC7aaJXiuk3y9aaae2hWq/CSjVQxJQAi/b5Zlr1Pf9jrr/VkWlWWkZ7
00tahpTUxRNn1ZGgqYC8OeElTXS62yOzWQ2NMqfRJkKAtlNOPbUbU0PGt/c/
nuih0fJ2eLccaz2Ivk4ptP9Lb6L5HCzfbnThIHIxVfghZNtIS9CJ8hLcfhBt
NMrzHCQ30Nzd7aJ6KlRROEVe/dTic3q/N5vhLqqIL3mftUstlTa3S7ZPTUkV
5TPsCwq7W08bzHG4/mpLBam4yBU+0qujifx86rreq4KaP8l2NrLX0tbFB3Ii
nqkgk8OyPwd6qmnj3/0HeOJU0EgZhW8lvYoW39Tat8dTBbkKUbR22VbSamys
1mbPqaDNEPJFWXIFTcjHgfMrUkF7x43ZIr8+o/HuY93GK62ClJ6fNHvp8pTW
XEYMTNqpgk7GG+WsbRTTRsZmsnRGDiDnK4Yz8vef0L5bdJkOVhxAYchA2Z6/
gHZTu33Plu8B9JjvxJ2M/Dzak+wNZYLqAfRy4XhL94Fc2oW2l2eTR5VRw/1Y
Ca572bQ1ttjWO77KaFUtuvrWwzTaRVyM1rOphBSnIo5PNyTSzHhzHtlfVkJ9
5N3UwspomueIkcKHGkV0PIRjLGA+mMbwS57A2b4feb/ataf6uCdNXO/YYsCI
PFJSOcNwWs6DxnhS0ORPvjz6H8U/osA=
          "]], 
         LineBox[{{0.004435848449543597, 0.}, {0.00937100124497588, 0.}, {
          0.014145384281923006`, 0.}, {0.018919767318870132`, 0.}, {
          0.02369415035581726, 0.}, {0.028468533392764388`, 0.}, {
          0.03801729946665864, 0.}, {0.057114831614447144`, 0.}, {
          0.06188921465139427, 0.}, {0.0666635976883414, 0.}, {
          0.07621236376223565, 0.}, {0.08098674679918277, 0.}, {
          0.0857611298361299, 0.}, {0.09053551287307704, 0.}, {
          0.09530989591002416, 0.}}]}, 
        Annotation[#, 
         "Charting`Private`Tag$18164#1"]& ], {}}, {{}, {}, {}}}, {}, {}}, {
    Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], Automatic}, 
     GridLines -> {None, None}, FrameTicks -> {{Automatic, Automatic}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, DisplayFunction -> 
     Identity, DisplayFunction -> Identity, Ticks -> {Quiet[
        Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , Automatic}, 
     AxesOrigin -> NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}], 
     FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Quiet[
         Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{0, 0}, {0, 0}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "ClippingRange" -> {{{-13.815510274069974`, 
        0.09530989591002416}, {-2.604700156788498*^-14, 
        0.10086525858351018`}}, {{-13.815510274069974`, 
        0.09530989591002416}, {0., 0.10086525858351018`}}}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Part[#, 2]}& )}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(x\\), \\(2\\)]\\)dN/dx \"", 
         TraditionalForm], None}, {
        FormBox["\"x\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{-Log[1000000], 0.09531017980432493}, {
        0, 0.12}}, {{-13.815510557964274`, 0.09531017980432493}, {0, 0.12}}], 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"n=0\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                 RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.22222222222222227`, 0.22222222222222227`, 
                    0.22222222222222227`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.33333333333333337, 0.33333333333333337, \
0.33333333333333337]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                   Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.33333333333333337`, 0.33333333333333337`, 
                    0.33333333333333337`]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[
                  0.33333333333333337`, 0.33333333333333337`, 
                   0.33333333333333337`], Editable -> False, Selectable -> 
                  False]}], "]"}], "}"}], ",", 
           RowBox[{"{", #, "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.639076611805574*^9, 3.6390766683190613`*^9}, 
   3.6390767190461483`*^9, {3.6445839842947693`*^9, 3.644584014261587*^9}, 
   3.644586407561598*^9, 3.656974333286442*^9, 3.6569748645354233`*^9, 
   3.656974917386509*^9, 3.656980049533836*^9, {3.7258965615539093`*^9, 
   3.7258965954615498`*^9}, 
   3.726157299740905*^9},ExpressionUUID->"1e913aab-c891-4819-aadf-\
2f9233d8a091"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{840, 1005},
WindowMargins->{{Automatic, 0}, {Automatic, -1}},
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 27, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 209, 4, 92, "Title", "ExpressionUUID" -> \
"00cf4803-6d60-4869-b01e-89be371165d2"],
Cell[CellGroupData[{
Cell[814, 30, 678, 12, 69, "Subsection", "ExpressionUUID" -> \
"fa2c62c4-e5f0-4ba2-9772-0f700fb30a77"],
Cell[1495, 44, 573, 12, 106, "Text", "ExpressionUUID" -> \
"8a9520e0-c165-4356-877c-86c5b3e176cc"],
Cell[2071, 58, 10267, 276, 1208, "Text", "ExpressionUUID" -> \
"706c67f0-4ba3-4b4d-8bdc-f2391eccb4a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12375, 339, 474, 14, 68, "Section", "ExpressionUUID" -> \
"147d167a-40b5-4220-8f12-9ddd42c9d42c"],
Cell[12852, 355, 566, 16, 51, "Text", "ExpressionUUID" -> \
"f877de5e-042c-4131-a3e8-7581907ae2a3"],
Cell[CellGroupData[{
Cell[13443, 375, 16760, 474, 1034, "Input", "ExpressionUUID" -> \
"823b03b0-d97c-4bb1-b821-cd89dac6e730"],
Cell[30206, 851, 107920, 1887, 257, "Output", "ExpressionUUID" -> \
"f145e1e0-95ae-485f-8a31-e9cf236ef123"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[138175, 2744, 523, 14, 68, "Section", "ExpressionUUID" -> \
"70cfd546-a43a-461e-81c5-150e154e86c6"],
Cell[138701, 2760, 849, 22, 70, "Text", "ExpressionUUID" -> \
"222d28ed-06db-4940-9b6a-dc3f4cd51239"],
Cell[CellGroupData[{
Cell[139575, 2786, 17293, 492, 1034, "Input", "ExpressionUUID" -> \
"ee73126e-e183-4b54-a14f-8fdf385b30c9"],
Cell[156871, 3280, 169977, 2910, 257, "Output", "ExpressionUUID" -> \
"3a17b959-d286-41bc-8390-d8cb22136b52"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[326897, 6196, 532, 13, 68, "Section", "ExpressionUUID" -> \
"13b88807-aea3-4df3-8e3c-47d9623cd486"],
Cell[327432, 6211, 578, 14, 53, "Text", "ExpressionUUID" -> \
"8664e545-b68e-4425-ba8e-3d059a1d8129"],
Cell[CellGroupData[{
Cell[328035, 6229, 16498, 472, 1034, "Input", "ExpressionUUID" -> \
"37cfbac7-4a10-4970-9b69-3e844a028b3f"],
Cell[344536, 6703, 120337, 2095, 257, "Output", "ExpressionUUID" -> \
"b2095047-0ea2-4171-baa7-7af9d8343feb"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[464922, 8804, 573, 15, 68, "Section", "ExpressionUUID" -> \
"3d078262-5ed0-4d5a-ae7e-6de0c6f07a8b"],
Cell[465498, 8821, 1187, 28, 127, "Text", "ExpressionUUID" -> \
"37bc1077-7933-4ac8-b51e-0fdb159f0e9b"],
Cell[CellGroupData[{
Cell[466710, 8853, 4508, 135, 354, "Input", "ExpressionUUID" -> \
"1c4ae216-afd0-4fdb-bbc4-5a8e6a326263"],
Cell[471221, 8990, 26409, 474, 257, "Output", "ExpressionUUID" -> \
"57fc1499-099a-47b1-b160-ec82b890d272"]
}, Open  ]],
Cell[497645, 9467, 756, 20, 53, "Text", "ExpressionUUID" -> \
"2792ed7b-95db-4dc7-8bd4-3bd092109799"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498438, 9492, 625, 14, 68, "Section", "ExpressionUUID" -> \
"673ad48c-d40c-437a-b13a-8002f2e2295f"],
Cell[499066, 9508, 1342, 30, 80, "Text", "ExpressionUUID" -> \
"1c102689-3ccd-4f6a-8a2f-44bf00185d46"],
Cell[CellGroupData[{
Cell[500433, 9542, 4547, 134, 313, "Input", "ExpressionUUID" -> \
"149ae7aa-78df-4225-84af-78dc3e18f432"],
Cell[504983, 9678, 28962, 518, 257, "Output", "ExpressionUUID" -> \
"eec8ae7b-fbf8-442b-b889-ca217feb859e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[533994, 10202, 651, 18, 68, "Section", "ExpressionUUID" -> \
"8f94fea6-5425-446e-b8d4-f5e6ec68fc92"],
Cell[534648, 10222, 615, 17, 32, "Text", "ExpressionUUID" -> \
"253067c7-4248-4aca-8eb7-095df4447504"],
Cell[CellGroupData[{
Cell[535288, 10243, 16826, 475, 1034, "Input", "ExpressionUUID" -> \
"532e6a49-4a35-4ab8-a8c6-e25712d4f65b"],
Cell[552117, 10720, 109552, 1914, 257, "Output", "ExpressionUUID" -> \
"63b7eb60-4864-4d45-a81b-aaa053a936a6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[661718, 12640, 702, 19, 68, "Section", "ExpressionUUID" -> \
"2b087bd4-a0d5-4b80-b051-04c3b5272272"],
Cell[662423, 12661, 808, 18, 70, "Text", "ExpressionUUID" -> \
"32b45602-0eee-4cac-90e5-86f0280f8081"],
Cell[CellGroupData[{
Cell[663256, 12683, 16879, 476, 1034, "Input", "ExpressionUUID" -> \
"44eeced5-73f2-4ab2-aeee-d972455c02ab"],
Cell[680138, 13161, 114315, 1993, 257, "Output", "ExpressionUUID" -> \
"c8a700dc-8a07-4a4f-b908-d8d91d506d08"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[794502, 15160, 707, 19, 68, "Section", "ExpressionUUID" -> \
"c821a82b-f3ee-45f9-8f13-86f404efc518"],
Cell[795212, 15181, 789, 18, 70, "Text", "ExpressionUUID" -> \
"e788ce05-9c07-4fc3-915f-cdb356d563ae"],
Cell[CellGroupData[{
Cell[796026, 15203, 16857, 476, 1034, "Input", "ExpressionUUID" -> \
"f103cdd9-d1fd-4df2-b273-0bb8081557d8"],
Cell[812886, 15681, 126735, 2199, 253, "Output", "ExpressionUUID" -> \
"7378dbfb-008a-42b6-8970-8798f81c4bbf"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[939670, 17886, 703, 19, 68, "Section", "ExpressionUUID" -> \
"fcdd28e7-4c1d-4843-868e-85ee8632446c"],
Cell[940376, 17907, 662, 17, 51, "Text", "ExpressionUUID" -> \
"99cecbb0-545d-4048-88fc-158c0d34a966"],
Cell[CellGroupData[{
Cell[941063, 17928, 16878, 476, 1034, "Input", "ExpressionUUID" -> \
"0e604600-44bf-4f72-b86e-4502e1651db7"],
Cell[957944, 18406, 132009, 2286, 257, "Output", "ExpressionUUID" -> \
"62f66364-f1af-482f-b518-b82330078f99"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1090002, 20698, 709, 18, 68, "Section", "ExpressionUUID" -> \
"5c899bdf-8166-4f2c-8628-ba14b8953fde"],
Cell[1090714, 20718, 618, 14, 53, "Text", "ExpressionUUID" -> \
"4d8f3500-3f9c-4e42-93f5-3a4d466ed1bc"],
Cell[CellGroupData[{
Cell[1091357, 20736, 16534, 472, 1034, "Input", "ExpressionUUID" -> \
"549714b5-d728-4a06-9893-c99107eba91c"],
Cell[1107894, 21210, 119188, 2071, 257, "Output", "ExpressionUUID" -> \
"cc974da2-5156-492d-9961-26a6ebdad27e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1227131, 23287, 749, 20, 68, "Section", "ExpressionUUID" -> \
"9da068d9-2622-4cd2-ac76-e0be60146689"],
Cell[1227883, 23309, 1187, 28, 127, "Text", "ExpressionUUID" -> \
"e3b1d7c5-ff71-4ce6-80e9-6689b670c13d"],
Cell[CellGroupData[{
Cell[1229095, 23341, 4608, 136, 354, "Input", "ExpressionUUID" -> \
"0c93c203-037f-4004-a2c0-314f60f8f3d0"],
Cell[1233706, 23479, 27758, 496, 257, "Output", "ExpressionUUID" -> \
"60a56c7f-26b8-4fd2-8122-a51f60cee9a0"]
}, Open  ]],
Cell[1261479, 23978, 756, 20, 53, "Text", "ExpressionUUID" -> \
"eca7266f-16da-47dc-bece-e4460f01b852"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1262272, 24003, 799, 20, 68, "Section", "ExpressionUUID" -> \
"35a6760f-eb80-4ebe-a0f9-586a5f1ee84f"],
Cell[1263074, 24025, 507, 9, 49, "Text", "ExpressionUUID" -> \
"a50297c0-b2c5-4e4c-ba99-e4fdc273bdac"],
Cell[CellGroupData[{
Cell[1263606, 24038, 4566, 137, 354, "Input", "ExpressionUUID" -> \
"7cde9690-44b1-4324-b3d1-cf26241c3bbe"],
Cell[1268175, 24177, 30535, 544, 291, "Output", "ExpressionUUID" -> \
"1e913aab-c891-4819-aadf-2f9233d8a091"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

